@@ -1,9 +1,26 @@
 "Run all benchmarks"
 
-__author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2010-03-26 -- 2010-03-26"
-__copyright__ = "Copyright (C) 2010 Anders Logg"
-__license__  = "GNU LGPL version 2.1"
+# Copyright (C) 2010 Anders Logg
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Modified by Johannes Ring, 2011
+#
+# First added:  2010-03-26
+# Last changed: 2011-04-05
 
 import os, sys, time
 
@@ -14,8 +31,9 @@ def run_bench(arg, directory, files):
     # Skip directories not containing a benchmark
     bench_exec = "bench"
     if directory.endswith("cpp") and \
-           directory.split(os.path.sep)[-2] + "-bench" in files:
-        bench_exec = directory.split(os.path.sep)[-2] + "-bench"
+           "bench_" + directory.split(os.path.sep)[-2] in files:
+        bench_exec = "bench_" + directory.split(os.path.sep)[-2]
+
 
     if not bench_exec in files:
         return
