@@ -1,12 +1,26 @@
-// Copyright (C) 2010 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2010 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+//
+// First added:  2010-11-11
+// Last changed: 2010-11-29
 //
 // If run without command-line arguments, this benchmark iterates from
 // zero to MAX_NUM_THREADS. If a command-line argument --num_threads n
 // is given, the benchmark is run with the specified number of threads.
-//
-// First added:  2010-11-11
-// Last changed: 2010-11-29
 
 #include <cstdlib>
 
@@ -27,33 +41,33 @@ double bench(std::string form, const Mesh& mesh)
   info_underline("Benchmarking %s, num_threads = %d", form.c_str(), num_threads);
 
   // Create form
-  FunctionSpace *V(0), *W0(0), *W1(0), *W2(0), *W3(0), *W4(0);
-  Form* a(0);
-  Function *w0(0), *w1(0), *w2(0), *w3(0), *w4(0);
+  boost::shared_ptr<FunctionSpace> V, W0, W1, W2, W3, W4;
+  boost::shared_ptr<Form> a;
+  boost::shared_ptr<Function> w0, w1, w2, w3, w4;
   if (form == "Poisson")
   {
-    V = new Poisson::FunctionSpace(mesh);
-    a = new Poisson::BilinearForm(*V, *V);
+    V.reset(new Poisson::FunctionSpace(mesh));
+    a.reset(new Poisson::BilinearForm(V, V));
   }
   else if (form == "NavierStokes")
   {
-    V  = new NavierStokes::FunctionSpace(mesh);
-    W0 = new NavierStokes::Form_0_FunctionSpace_2(mesh);
-    W1 = new NavierStokes::Form_0_FunctionSpace_3(mesh);
-    W2 = new NavierStokes::Form_0_FunctionSpace_4(mesh);
-    W3 = new NavierStokes::Form_0_FunctionSpace_5(mesh);
-    W4 = new NavierStokes::Form_0_FunctionSpace_6(mesh);
-    a = new NavierStokes::BilinearForm(*V, *V);
-    w0 = new Function(*W0);
-    w1 = new Function(*W1);
-    w2 = new Function(*W2);
-    w3 = new Function(*W3);
-    w4 = new Function(*W4);
-    a->set_coefficient(0, *w0);
-    a->set_coefficient(1, *w1);
-    a->set_coefficient(2, *w2);
-    a->set_coefficient(3, *w3);
-    a->set_coefficient(4, *w4);
+    V.reset(new NavierStokes::FunctionSpace(mesh));
+    W0.reset(new NavierStokes::Form_0_FunctionSpace_2(mesh));
+    W1.reset(new NavierStokes::Form_0_FunctionSpace_3(mesh));
+    W2.reset(new NavierStokes::Form_0_FunctionSpace_4(mesh));
+    W3.reset(new NavierStokes::Form_0_FunctionSpace_5(mesh));
+    W4.reset(new NavierStokes::Form_0_FunctionSpace_6(mesh));
+    a.reset(new NavierStokes::BilinearForm(*V, *V));
+    w0.reset(new Function(*W0));
+    w1.reset(new Function(*W1));
+    w2.reset(new Function(*W2));
+    w3.reset(new Function(*W3));
+    w4.reset(new Function(*W4));
+    a->set_coefficient(0, w0);
+    a->set_coefficient(1, w1);
+    a->set_coefficient(2, w2);
+    a->set_coefficient(3, w3);
+    a->set_coefficient(4, w4);
   }
 
   // Create STL matrix
@@ -72,20 +86,6 @@ double bench(std::string form, const Mesh& mesh)
   // Write summary
   summary(true);
 
-  // Cleanup
-  delete V;
-  delete W0;
-  delete W1;
-  delete W2;
-  delete W3;
-  delete W4;
-  delete w0;
-  delete w1;
-  delete w2;
-  delete w3;
-  delete w4;
-  delete a;
-
   info("");
 
   return t;
@@ -104,9 +104,9 @@ int main(int argc, char* argv[])
   //parameters["linear_algebra_backend"] = "Epetra";
 
   // Create mesh
-  UnitCube mesh(SIZE, SIZE, SIZE);
-  mesh.color("vertex");
-  mesh.renumber_by_color();
+  UnitCube old_mesh(SIZE, SIZE, SIZE);
+  old_mesh.color("vertex");
+  Mesh mesh = old_mesh.renumber_by_color();
 
   // Test cases
   std::vector<std::string> forms;
@@ -116,7 +116,7 @@ int main(int argc, char* argv[])
   // If parameter num_threads has been set, just run once
   if (parameters["num_threads"].change_count() > 0)
   {
-    for (int i = 0; i < forms.size(); i++)
+    for (unsigned int i = 0; i < forms.size(); i++)
       bench(forms[i], mesh);
   }
 
@@ -133,7 +133,7 @@ int main(int argc, char* argv[])
       parameters["num_threads"] = num_threads;
 
       // Iterate over forms
-      for (int i = 0; i < forms.size(); i++)
+      for (unsigned int i = 0; i < forms.size(); i++)
       {
         // Run test case
         const double t = bench(forms[i], mesh);
