@@ -6,10 +6,25 @@ the timings function of time (date plot). It also creates a web page
 index.html for easy viewing of the generated plots.
 """
 
-__author__ = "Johannes Ring <johannr@simula.no>"
-__date__ = "2010-04-06 -- 2010-04-13"
-__copyright__ = "Copyright (C) 2010 Johannes Ring"
-__license__  = "GNU LGPL version 2.1"
+# Copyright (C) 2010 Johannes Ring
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2010-04-06
+# Last changed: 2010-04-13
 
 import os
 import re
