@@ -1,5 +1,19 @@
-// Copyright (C) 2006-2009 Johan Jansson and Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2006-2009 Johan Jansson and Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells 2008
 //
@@ -152,5 +166,12 @@ int main()
   mesh.move(u);
   plot(mesh, "Deformed mesh");
 
+  // Write boundary condition facets markers ton VTK format
+  MeshFunction<dolfin::uint> facet_markers(mesh, 2, 0);
+  left.mark(facet_markers, 1);
+  right.mark(facet_markers, 2);
+  File facet_file("facet_markers.pvd");
+  facet_file << facet_markers;
+
  return 0;
 }
