@@ -3,28 +3,28 @@
 # Run all stiff test problems.
 
 echo Running test problem 1
-./demo 1 > log-1
+./stiff-demo 1 > log-1
 
 echo Running test problem 2
-./demo 2 > log-2
+./stiff-demo 2 > log-2
 
 echo Running test problem 3
-./demo 3 > log-3
+./stiff-demo 3 > log-3
 
 echo Running test problem 4
-./demo 4 > log-4
+./stiff-demo 4 > log-4
 
 echo Running test problem 5
-./demo 5 > log-5
+./stiff-demo 5 > log-5
 
 echo Running test problem 6
-./demo 6 > log-6
+./stiff-demo 6 > log-6
 
 echo Running test problem 7
-./demo 7 > log-7
+./stiff-demo 7 > log-7
 
 echo Running test problem 8
-./demo 8 > log-8
+./stiff-demo 8 > log-8
 
 echo Running test problem 9
-./demo 9 > log-9
+./stiff-demo 9 > log-9
