@@ -1,8 +1,22 @@
-// Copyright (C) 2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2009 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2009-11-11
-// Last changed: 2011-02-04
+// Last changed: 2011-02-25
 //
 // This program demonstrates the use of the TimeSeries
 // class for storing a series of meshes and vectors.
@@ -47,8 +61,8 @@ int main()
   }
 
   // Retrieve mesh and vector at some point in time
-  series.retrieve(mesh, 0.3);
-  series.retrieve(x, 0.3);
+  series.retrieve(mesh, 0.29);
+  series.retrieve(x, 0.31, false);
 
   // Plot mesh
   plot(mesh);
