@@ -4,11 +4,25 @@ in Dolfin using Epetra matrices, the AztecOO CG solver and ML
 AMG preconditioner
 """
 
-__author__ = "Kent-Andre Mardal (kent-and@simula.no)"
-__date__ = "2008-04-24"
-__copyright__ = "Copyright (C) 2008 Kent-Andre Mardal"
-
-
+# Copyright (C) 2008 Kent-Andre Mardal
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2008-04-24
+# Last changed: 2008-04-24
 
 from dolfin import *
 
@@ -30,12 +44,12 @@ class DirichletBoundary(SubDomain):
         return bool(on_boundary and x[0] < DOLFIN_EPS)
 
 # Define variational problem
-v = TestFunction(V)
 u = TrialFunction(V)
+v = TestFunction(V)
 f = Expression("500.0 * exp(-(pow(x[0] - 0.5, 2) + pow(x[1] - 0.5, 2)) / 0.02)")
 
-a = dot(grad(v), grad(u))*dx
-L = v*f*dx
+a = dot(grad(u), grad(v))*dx
+L = f*v*dx
 
 # Define boundary condition
 u0 = Constant(0)
