@@ -1,8 +1,22 @@
 // Copyright (C) 2010 Marie E. Rognes
-// Licensed under the GNU LGPL Version 3.0 or any later version
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2010-08-19
-// Last changed: 2011-02-17
+// Last changed: 2011-03-23
 
 #ifndef __ERROR_CONTROL_H
 #define __ERROR_CONTROL_H
@@ -63,7 +77,7 @@ namespace dolfin
     ///     double
     ///         error estimate
     double estimate_error(const Function& u,
-                          std::vector<const BoundaryCondition*> bcs);
+           const std::vector<boost::shared_ptr<const BoundaryCondition> > bcs);
 
     /// Compute error indicators
     ///
@@ -129,7 +143,7 @@ namespace dolfin
     ///     bcs (std::vector<const _BoundaryCondition_*>)
     ///         the primal boundary conditions
     void compute_dual(Function& z,
-                      std::vector<const BoundaryCondition*> bcs);
+         const std::vector<boost::shared_ptr<const BoundaryCondition> > bcs);
 
     /// Compute extrapolation with boundary conditions
     ///
@@ -140,7 +154,7 @@ namespace dolfin
     ///     bcs (std::vector<const _BoundaryCondition_*>)
     ///         the dual boundary conditions
     void compute_extrapolation(const Function& z,
-                               std::vector<const BoundaryCondition*> bcs);
+         const std::vector<boost::shared_ptr<const BoundaryCondition> > bcs);
 
     friend const dolfin::ErrorControl& dolfin::adapt(const ErrorControl& ec,
                                                boost::shared_ptr<const Mesh> refined_mesh);
@@ -170,13 +184,11 @@ namespace dolfin
 
     bool _is_linear;
 
-    // Pointers to other function spaces (FIXME: Only out-of-scope
-    // motivated)
+    // Pointers to other function spaces
     boost::shared_ptr<const FunctionSpace> _E;
     boost::shared_ptr<const FunctionSpace> _C;
 
-    // Pointers to other functions (FIXME: Only out-of-scope
-    // motivated)
+    // Pointers to other functions
     boost::shared_ptr<Function> _cell_cone;
     boost::shared_ptr<Function> _R_T;
     boost::shared_ptr<SpecialFacetFunction> _R_dT;
