@@ -1,8 +1,22 @@
 // Copyright (C) 2011 Marie E. Rognes
-// Licensed under the GNU LGPL Version 3.0 or any later version
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2011-01-04
-// Last changed: 2011-02-21
+// Last changed: 2011-03-15
 
 #include <dolfin/fem/UFC.h>
 #include <dolfin/mesh/Cell.h>
@@ -116,10 +130,8 @@ void LocalAssembler::assemble_exterior_facet(arma::mat& A,
   const uint M = A.n_rows;
   const uint N = A.n_cols;
   for (uint i=0; i < M; i++)
-  {
     for (uint j=0; j < N; j++)
       A(i, j) += ufc.A[N*i + j];
-  }
 }
 //------------------------------------------------------------------------------
 void LocalAssembler::assemble_interior_facet(arma::mat& A,
@@ -161,8 +173,13 @@ void LocalAssembler::assemble_interior_facet(arma::mat& A,
   // Stuff upper left quadrant (corresponding to this cell) into A
   const uint M = A.n_rows;
   const uint N = A.n_cols;
-  for (uint i=0; i < M; i++)
-    for (uint j=0; j < N; j++)
-      A(i, j) += ufc.macro_A[2*N*i + j]; // FIXME: row/col swap for vectors!
+
+  if (N == 1)
+    for (uint i=0; i < M; i++)
+      A(i, 0) = ufc.macro_A[i];
+  else
+    for (uint i=0; i < M; i++)
+      for (uint j=0; j < N; j++)
+        A(i, j) += ufc.macro_A[2*N*i + j];
 }
 //------------------------------------------------------------------------------
