@@ -1,8 +1,22 @@
-// Copyright (C) 2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2009 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2009-11-11
-// Last changed: 2011-02-16
+// Last changed: 2011-03-31
 
 #ifndef __TIME_SERIES_H
 #define __TIME_SERIES_H
@@ -46,7 +60,7 @@ namespace dolfin
     void store(const Mesh& mesh, double t);
 
     /// Retrieve vector at given time
-    void retrieve(GenericVector& vector, double t) const;
+    void retrieve(GenericVector& vector, double t, bool interpolate=true) const;
 
     /// Retrieve mesh at given time
     void retrieve(Mesh& mesh, double t) const;
@@ -70,11 +84,31 @@ namespace dolfin
     /// Return informal string representation (pretty-print)
     std::string str(bool verbose) const;
 
+    /// Default parameter values
+    static Parameters default_parameters()
+    {
+      Parameters p("time_series");
+      p.add("clear_on_write", true);
+      return p;
+    }
+
   private:
 
     // Check if values are strictly increasing
     static bool increasing(const std::vector<double>& times);
 
+    // Find index closest to given time
+    static uint find_closest_index(double t,
+                                   const std::vector<double>& times,
+                                   std::string series_name,
+                                   std::string type_name);
+
+    // Find index pair closest to given time
+    static std::pair<uint, uint> find_closest_pair(double t,
+                                                   const std::vector<double>& times,
+                                                   std::string series_name,
+                                                   std::string type_name);
+
     // Name of series
     std::string _name;
 
@@ -85,9 +119,6 @@ namespace dolfin
     // True if series has been cleared
     bool _cleared;
 
-    // True if series is reversed
-    bool _reversed;
-
   };
 
 }
