@@ -1,21 +1,41 @@
-// Copyright (C) 2010 Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2010-2011 Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Anders Logg, 2010-2011.
 // Modified by Marie E. Rognes, 2011.
 //
 // First added:  2010-02-10
-// Last changed: 2011-02-23
+// Last changed: 2011-04-04
+
+#include <map>
 
 #include <boost/shared_ptr.hpp>
 
-#include <dolfin/common/NoDeleter.h>
-#include <dolfin/mesh/LocalMeshRefinement.h>
+#include <dolfin/common/types.h>
+
 #include <dolfin/mesh/Mesh.h>
 #include <dolfin/mesh/MeshEntity.h>
 #include <dolfin/mesh/MeshFunction.h>
-#include <dolfin/mesh/UniformMeshRefinement.h>
+#include <dolfin/mesh/Facet.h>
+#include <dolfin/mesh/Cell.h>
+#include <dolfin/refinement/LocalMeshRefinement.h>
+#include <dolfin/refinement/UniformMeshRefinement.h>
 #include <dolfin/function/FunctionSpace.h>
+#include <dolfin/function/SubSpace.h>
 #include <dolfin/function/GenericFunction.h>
 #include <dolfin/function/Function.h>
 #include <dolfin/fem/FiniteElement.h>
@@ -23,6 +43,7 @@
 #include <dolfin/fem/Form.h>
 #include <dolfin/fem/DirichletBC.h>
 #include <dolfin/fem/VariationalProblem.h>
+#include <dolfin/plot/plot.h>
 #include "ErrorControl.h"
 #include "SpecialFacetFunction.h"
 #include "adapt.h"
@@ -40,7 +61,6 @@ void set_parent_child(const T& parent, boost::shared_ptr<T> child)
   _parent.set_child(child);
   child->set_parent(reference_to_no_delete_pointer(_parent));
 }
-
 //-----------------------------------------------------------------------------
 const dolfin::Mesh& dolfin::adapt(const Mesh& mesh)
 {
@@ -114,26 +134,15 @@ const dolfin::FunctionSpace& dolfin::adapt(const FunctionSpace& space,
     return space.child();
   }
 
-  // Get DofMap (GenericDofMap does not know about ufc::dofmap)
-  const DofMap* dofmap = dynamic_cast<const DofMap*>(&space.dofmap());
-  if (!dofmap)
-  {
-    dolfin_debug("FunctionSpace is defined by a non-standard dofmap.");
-    error("Unable to refine function space.");
-  }
-
-  // Create new copies of UFC finite element and dofmap
-  boost::shared_ptr<ufc::finite_element> ufc_element(space.element().ufc_element()->create());
-  boost::shared_ptr<ufc::dofmap> ufc_dofmap(dofmap->ufc_dofmap()->create());
-
   // Create DOLFIN finite element and dofmap
-  boost::shared_ptr<const FiniteElement> refined_element(new FiniteElement(ufc_element));
-  boost::shared_ptr<const DofMap> refined_dofmap(new DofMap(ufc_dofmap, *refined_mesh));
+  boost::shared_ptr<const FiniteElement>
+    refined_element(space.element().create());
+  boost::shared_ptr<const GenericDofMap>
+    refined_dofmap(space.dofmap().copy(*refined_mesh));
 
   // Create new function space
-  boost::shared_ptr<FunctionSpace> refined_space(new FunctionSpace(refined_mesh,
-                                                                   refined_element,
-                                                                   refined_dofmap));
+  boost::shared_ptr<FunctionSpace>
+    refined_space(new FunctionSpace(refined_mesh, refined_element, refined_dofmap));
 
   // Set parent / child
   set_parent_child(space, refined_space);
@@ -154,7 +163,8 @@ const dolfin::Function& dolfin::adapt(const Function& function,
   // Refine function space
   boost::shared_ptr<const FunctionSpace> space = function.function_space_ptr();
   adapt(*space, refined_mesh);
-  boost::shared_ptr<const FunctionSpace> refined_space = space->child_shared_ptr();
+  boost::shared_ptr<const FunctionSpace>
+    refined_space = space->child_shared_ptr();
 
   // Create new function on refined space and interpolate
   boost::shared_ptr<Function> refined_function(new Function(refined_space));
@@ -177,8 +187,10 @@ const dolfin::Form& dolfin::adapt(const Form& form,
   }
 
   // Get data
-  std::vector<boost::shared_ptr<const FunctionSpace> > spaces = form.function_spaces();
-  std::vector<boost::shared_ptr<const GenericFunction> > coefficients = form.coefficients();
+  std::vector<boost::shared_ptr<const FunctionSpace> >
+    spaces = form.function_spaces();
+  std::vector<boost::shared_ptr<const GenericFunction> >
+    coefficients = form.coefficients();
   boost::shared_ptr<const ufc::form> ufc_form = form.ufc_form_shared_ptr();
 
   // Refine function spaces
@@ -190,13 +202,13 @@ const dolfin::Form& dolfin::adapt(const Form& form,
     refined_spaces.push_back(space.child_shared_ptr());
   }
 
-
   // Refine coefficients
   std::vector<boost::shared_ptr<const GenericFunction> > refined_coefficients;
   for (uint i = 0; i < coefficients.size(); i++)
   {
     // Try casting to Function
-    const Function* function = dynamic_cast<const Function*>(coefficients[i].get());
+    const Function*
+      function = dynamic_cast<const Function*>(coefficients[i].get());
 
     // If we have a Function, refine
     if (function != 0)
@@ -218,6 +230,26 @@ const dolfin::Form& dolfin::adapt(const Form& form,
   /// Attach mesh
   refined_form->set_mesh(refined_mesh);
 
+  // Attached refined sub domains
+  const MeshFunction<uint>* cell_domains = form.cell_domains_shared_ptr().get();
+  if (cell_domains)
+  {
+    adapt(*cell_domains, refined_mesh);
+    refined_form->cell_domains = cell_domains->child_shared_ptr();
+  }
+  const MeshFunction<uint>* exterior_domains = form.exterior_facet_domains_shared_ptr().get();
+  if (exterior_domains)
+  {
+    adapt(*exterior_domains, refined_mesh);
+    refined_form->exterior_facet_domains = exterior_domains->child_shared_ptr();
+  }
+  const MeshFunction<uint>* interior_domains = form.interior_facet_domains_shared_ptr().get();
+  if (interior_domains)
+  {
+    adapt(*interior_domains, refined_mesh);
+    refined_form->interior_facet_domains = interior_domains->child_shared_ptr();
+  }
+
   // Set parent / child
   set_parent_child(form, refined_form);
 
@@ -235,35 +267,34 @@ const dolfin::VariationalProblem& dolfin::adapt(const VariationalProblem& proble
   }
 
   // Get data
-  boost::shared_ptr<const Form> form_0 = problem.form_0_shared_ptr();
-  boost::shared_ptr<const Form> form_1 = problem.form_1_shared_ptr();
-  std::vector<boost::shared_ptr<const BoundaryCondition> > bcs = problem.bcs_shared_ptr();
+  boost::shared_ptr<const Form> form_0 = problem.form_0();
+  boost::shared_ptr<const Form> form_1 = problem.form_1();
+  std::vector<boost::shared_ptr<const BoundaryCondition> > bcs = problem.bcs();
 
   // Refine forms
   adapt(*form_0, refined_mesh);
   adapt(*form_1, refined_mesh);
 
   // Refine bcs
+  const FunctionSpace& S(problem.trial_space());
   std::vector<boost::shared_ptr<const BoundaryCondition> > refined_bcs;
   for (uint i = 0; i < bcs.size(); i++)
   {
     const DirichletBC* bc = dynamic_cast<const DirichletBC*>(bcs[i].get());
     if (bc != 0)
     {
-      adapt(*bc, refined_mesh);
+      adapt(*bc, refined_mesh, S);
       refined_bcs.push_back(bc->child_shared_ptr());
-    } else
+    }
+    else
       error("Refinement of bcs only implemented for DirichletBCs!");
   }
 
-  // FIXME: Skipping mesh functions
-
   // Create new problem
   boost::shared_ptr<VariationalProblem>
     refined_problem(new VariationalProblem(form_0->child_shared_ptr(),
                                            form_1->child_shared_ptr(),
-                                           refined_bcs,
-                                           0, 0, 0));
+                                           refined_bcs));
 
   // Set parent / child
   set_parent_child(problem, refined_problem);
@@ -272,39 +303,53 @@ const dolfin::VariationalProblem& dolfin::adapt(const VariationalProblem& proble
 }
 //-----------------------------------------------------------------------------
 const dolfin::DirichletBC& dolfin::adapt(const DirichletBC& bc,
-                                         boost::shared_ptr<const Mesh> refined_mesh)
+                                         boost::shared_ptr<const Mesh> refined_mesh,
+                                         const FunctionSpace& S)
 {
   // Skip refinement if already refined
   if (bc.has_child())
   {
-    dolfin_debug("DirichletBC has already been refined, returning child problem.");
+    dolfin_debug("DirichletBC has already been refined, returning child.");
     return bc.child();
   }
 
+  boost::shared_ptr<const FunctionSpace> W = bc.function_space_ptr();
+  boost::shared_ptr<const FunctionSpace> V;
+
   // Refine function space
-  boost::shared_ptr<const FunctionSpace> V = bc.function_space_ptr();
-  adapt(*V, refined_mesh);
+  const std::vector<uint> component = W->component();
+  if (component.size() == 0)
+  {
+    adapt(*W, refined_mesh);
+    V = W->child_shared_ptr();
+  }
+  else
+  {
+    adapt(S, refined_mesh);
+    V.reset(new SubSpace(S.child(), component));
+  }
 
-  // Extract but keep sub-domain
-  boost::shared_ptr<const SubDomain> domain = bc.user_sub_domain_ptr();
+  // Extract markers
+  const std::vector<std::pair<uint, uint> >& markers = bc.markers();
 
-  // Refine value
-  const Function* g = dynamic_cast<const Function*>(bc.value_ptr().get());
+  // Create refined markers
+  std::vector<std::pair<uint, uint> > refined_markers;
+  adapt_markers(refined_markers, *refined_mesh, markers, W->mesh());
+
+  // Extract value
+  const Function* g = dynamic_cast<const Function*>(bc.value().get());
 
   // Create refined boundary condition
   boost::shared_ptr<DirichletBC> refined_bc;
   if (g != 0)
   {
     adapt(*g, refined_mesh);
-    refined_bc.reset(new DirichletBC(V->child_shared_ptr(),
-                                     g->child_shared_ptr(),
-                                     domain));
-  } else
-  {
-    refined_bc.reset(new DirichletBC(V->child_shared_ptr(),
-                                     bc.value_ptr(),
-                                     domain));
+    refined_bc.reset(new DirichletBC(V, g->child_shared_ptr(),
+                                     refined_markers));
   }
+  else
+    refined_bc.reset(new DirichletBC(V, bc.value(), refined_markers));
+
   // Set parent / child
   set_parent_child(bc, refined_bc);
 
@@ -349,3 +394,130 @@ const dolfin::ErrorControl& dolfin::adapt(const ErrorControl& ec,
   return *refined_ec;
 }
 //-----------------------------------------------------------------------------
+const dolfin::MeshFunction<dolfin::uint>&
+dolfin::adapt(const MeshFunction<uint>& mesh_function,
+              boost::shared_ptr<const Mesh> refined_mesh)
+{
+  // Skip refinement if already refined
+  if (mesh_function.has_child())
+  {
+    dolfin_debug("MeshFunction has already been refined, returning child");
+    return mesh_function.child();
+  }
+
+  const Mesh& mesh = mesh_function.mesh();
+  const uint dim = mesh.topology().dim();
+
+  // Extract parent map from data of refined mesh
+  boost::shared_ptr<MeshFunction<unsigned int> > parent;
+  if (mesh_function.dim() == dim)
+    parent = refined_mesh->data().mesh_function("parent_cell");
+  else if (mesh_function.dim() == (dim - 1))
+    parent = refined_mesh->data().mesh_function("parent_facet");
+  else
+    dolfin_not_implemented();
+
+  // Check that parent map exists
+  if (!parent.get())
+    error("Unable to extract information about parent mesh entites");
+
+  // Define an unused value as 'undefined'. MER: This will hence
+  // increase with the number of iterations. Not sure if that is good
+  // or bad.
+  uint max_value = 0;
+  for (uint i = 0; i < mesh_function.size(); i++)
+  {
+    if (mesh_function[i] > max_value)
+      max_value = mesh_function[i];
+  }
+  const uint undefined = max_value + 1;
+
+  // Map values of mesh function into refined mesh function
+  boost::shared_ptr<MeshFunction<uint> >
+    refined_mesh_function(new MeshFunction<uint>(*refined_mesh,
+                                                 mesh_function.dim()));
+  for (uint i = 0; i < refined_mesh_function->size(); i++)
+  {
+    const uint parent_index = (*parent)[i];
+    if (parent_index < mesh_function.size())
+      (*refined_mesh_function)[i] = mesh_function[parent_index];
+    else
+      (*refined_mesh_function)[i] = undefined;
+  }
+
+  // Set parent / child relations
+  set_parent_child(mesh_function, refined_mesh_function);
+
+  // Return refined mesh function
+  return *refined_mesh_function;
+}
+//-----------------------------------------------------------------------------
+void dolfin::adapt_markers(std::vector<std::pair<uint, uint> >& refined_markers,
+                           const Mesh& refined_mesh,
+                           const std::vector<std::pair<uint, uint> >& markers,
+                           const Mesh& mesh)
+{
+
+  // Extract parent map from data of refined mesh
+  boost::shared_ptr<MeshFunction<unsigned int> > parent_cells = \
+    refined_mesh.data().mesh_function("parent_cell");
+  boost::shared_ptr<MeshFunction<unsigned int> > parent_facets = \
+    refined_mesh.data().mesh_function("parent_facet");
+
+  // Check that parent maps exist
+  if (!parent_cells.get() || !parent_facets.get())
+    error("Unable to extract information about parent mesh entites");
+
+  // Create map (parent_cell, parent_local_facet) -> [(child_cell,
+  // child_local_facet), ...] for boundary facets
+  std::pair<uint, uint> child;
+  std::pair<uint, uint> parent;
+  std::map< std::pair<uint, uint>,
+    std::vector< std::pair<uint, uint> > > children;
+
+  const uint D = mesh.topology().dim();
+  for (FacetIterator facet(refined_mesh); !facet.end(); ++facet)
+  {
+    // Ignore interior facets
+    if (facet->num_entities(D) == 2)
+      continue;
+
+    // Extract cell and local facet number
+    Cell cell(refined_mesh, facet->entities(D)[0]);
+    const uint local_facet = cell.index(*facet);
+
+    child.first = cell.index();
+    child.second = local_facet;
+
+    // Extract parent cell
+    Cell parent_cell(mesh, (*parent_cells)[cell]);
+
+    // Extract (global) index of parent facet
+    // Add assert here.
+    const uint parent_facet_index = (*parent_facets)[*facet];
+
+    // Extract local number of parent facet wrt parent cell
+    Facet parent_facet(mesh, parent_facet_index);
+    const uint parent_local_facet = parent_cell.index(parent_facet);
+
+    parent.first = parent_cell.index();
+    parent.second = parent_local_facet;
+
+    // Add this (cell, local_facet) to list of child facets
+    children[parent].push_back(child);
+
+  }
+
+  // Use above map to construct refined markers
+  std::vector<std::pair<uint, uint> >  child_facets;
+  std::vector<std::pair<uint, uint> >::const_iterator it;
+  for (it = markers.begin(); it != markers.end(); ++it)
+  {
+    child_facets = children[*it];
+    for (uint k = 0; k < child_facets.size(); k++)
+    {
+      refined_markers.push_back(child_facets[k]);
+    }
+  }
+}
+//-----------------------------------------------------------------------------
