@@ -1,11 +1,25 @@
-// Copyright (C) 2010 Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2010 Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Anders Logg, 2010-2011.
 // Modified by Marie E. Rognes, 2011.
 //
 // First added:  2010-02-10
-// Last changed: 2011-02-16
+// Last changed: 2011-03-14
 //
 // This file defines free functions for refinement/adaption of meshes,
 // function spaces, functions etc.
@@ -13,6 +27,8 @@
 #ifndef __DOLFIN_ADAPT_H
 #define __DOLFIN_ADAPT_H
 
+#include <vector>
+
 namespace dolfin
 {
 
@@ -53,11 +69,22 @@ namespace dolfin
   const Function& adapt(const Function& function,
                         boost::shared_ptr<const Mesh> refined_mesh);
 
+  /// Refine mesh function<uint> based on mesh
+  const MeshFunction<dolfin::uint>& adapt(const MeshFunction<uint>& mesh_function,
+                                  boost::shared_ptr<const Mesh> refined_mesh);
+
   //--- Refinement of boundary conditions ---
 
   /// Refine Dirichlet bc based on refined mesh
   const DirichletBC& adapt(const DirichletBC& bc,
-                           boost::shared_ptr<const Mesh> refined_mesh);
+                           boost::shared_ptr<const Mesh> refined_mesh,
+                           const FunctionSpace& S);
+
+  /// Helper function for refinement of boundary conditions
+  void adapt_markers(std::vector<std::pair<uint, uint> >& refined_markers,
+                     const Mesh& refined_mesh,
+                     const std::vector<std::pair<uint, uint> >& markers,
+                     const Mesh& mesh);
 
   //--- Refinement of forms ---
 
@@ -75,6 +102,7 @@ namespace dolfin
   const ErrorControl& adapt(const ErrorControl& ec,
                             boost::shared_ptr<const Mesh> refined_mesh);
 
+
 }
 
 #endif
