@@ -3,6 +3,8 @@
 
 // DOLFIN adaptivity interface
 
+#include <dolfin/adaptivity/ErrorControl.h>
 #include <dolfin/adaptivity/TimeSeries.h>
+#include <dolfin/adaptivity/adapt.h>
 
 #endif
