@@ -1,5 +1,19 @@
-// Copyright (C) 2008 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2008 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2008-08-11
 // Last changed: 2008-09-13
@@ -10,6 +24,7 @@
 #include <dolfin/la/solve.h>
 #include <dolfin/la/Vector.h>
 #include <dolfin/log/log.h>
+#include <dolfin/mesh/BoundaryMesh.h>
 #include <dolfin/mesh/Mesh.h>
 #include <dolfin/mesh/MeshData.h>
 #include <dolfin/mesh/MeshEntity.h>
@@ -22,7 +37,7 @@
 using namespace dolfin;
 
 //-----------------------------------------------------------------------------
-void HarmonicSmoothing::move(Mesh& mesh, const Mesh& new_boundary)
+void HarmonicSmoothing::move(Mesh& mesh, const BoundaryMesh& new_boundary)
 {
   // Choose form and function space
   FunctionSpace* V = 0;
@@ -56,10 +71,9 @@ void HarmonicSmoothing::move(Mesh& mesh, const Mesh& new_boundary)
   Vector b(N);
 
   // Get array of dofs for boundary vertices
-  const MeshFunction<uint>* vertex_map = new_boundary.data().mesh_function("vertex map");
-  assert(vertex_map);
-  const uint num_dofs = vertex_map->size();
-  const uint* dofs = vertex_map->values();
+  const MeshFunction<unsigned int>& vertex_map = new_boundary.vertex_map();
+  const uint num_dofs = vertex_map.size();
+  const uint* dofs = vertex_map.values();
 
   // Modify matrix (insert 1 on diagonal)
   A.ident(num_dofs, dofs);
