@@ -1,5 +1,19 @@
-// Copyright (C) 2008-2009 Solveig Bruvoll and Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2008-2009 Solveig Bruvoll and Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2008-05-02
 // Last changed: 2009-01-12
@@ -14,6 +28,7 @@
 namespace dolfin
 {
 
+  class BoundaryMesh;
   class Mesh;
   class Vertex;
 
@@ -27,13 +42,13 @@ namespace dolfin
     enum InterpolationType {interpolation_lagrange, interpolation_hermite};
 
     /// Move coordinates of mesh according to new boundary coordinates
-    static void move(Mesh& mesh,const Mesh& new_boundary,
+    static void move(Mesh& mesh,const BoundaryMesh& new_boundary,
                      InterpolationType type);//=interpolation_lagrange);
 
   private:
 
     // Transfinite meanvalue interpolation
-    static void mean_value(double* new_x, uint dim, const Mesh& new_boundary,
+    static void mean_value(double* new_x, uint dim, const BoundaryMesh& new_boundary,
                           Mesh& mesh, const MeshFunction<uint>& vertex_map,
                           const Vertex& vertex, double** ghat, InterpolationType type);
 
@@ -49,12 +64,12 @@ namespace dolfin
                         Mesh& mesh, const MeshFunction<uint>& vertex_map,
                         const MeshFunction<uint>& cell_map);
 
-    static void hermite_function(double** ghat, uint dim, const Mesh& new_boundary,
+    static void hermite_function(double** ghat, uint dim, const BoundaryMesh& new_boundary,
                                  Mesh& mesh,
                                  const MeshFunction<uint>& vertex_map,
                                  const MeshFunction<uint>& cell_map);
 
-    static void integral(double* new_x, uint dim, const Mesh& new_boundary,
+    static void integral(double* new_x, uint dim, const BoundaryMesh& new_boundary,
                     Mesh& mesh, const MeshFunction<uint>& vertex_map,
                     const Vertex& vertex);
 
