@@ -1,5 +1,19 @@
-// Copyright (C) 2009-2010 Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2009-2010 Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Anders Logg, 2010.
 //
@@ -17,8 +31,11 @@
 #include <dolfin/common/constants.h>
 #include <dolfin/common/types.h>
 #include <dolfin/log/dolfin_log.h>
+#include <dolfin/common/real.h>
+
 #include "NoDeleter.h"
 
+
 namespace dolfin
 {
 
@@ -80,9 +97,7 @@ namespace dolfin
           s << i << ": " << (*this)[i] << std::endl;
       }
       else
-      {
         s << "<Array<T> of size " << size() << ">";
-      }
 
       return s.str();
     }
