@@ -1,10 +1,24 @@
-// Copyright (C) 2008-2011 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2008-2011 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Benjamin Kehlet, 2008.
 //
 // First added:  2008-10-02
-// Last changed: 2011-01-24
+// Last changed: 2011-03-17
 //
 // This file provides utilities for working with variable-precision
 // floating-point numbers. It defines a datatype "real" which defaults
@@ -114,9 +128,6 @@ namespace dolfin
   /// Compute pi
   real real_pi();
 
-  /// Compute matrix exponential using Pade approximation og degree p
-  void real_mat_exp(uint n, real* res, const real* A, const uint p=6);
-
   // FIXME: Add description
   double real_frexp(int* exp, const real& x);
 
@@ -126,7 +137,7 @@ namespace dolfin
 
   /// Logarithmic function (note: not full precision!)
   inline real real_log(const real& x)
-  { return to_real(log(to_double(x))); }
+  { return to_real(std::log(to_double(x))); }
 
   // Get computed epsilon
   inline const real& real_epsilon()
@@ -225,18 +236,5 @@ namespace dolfin
     for (uint i=0; i < n; ++i)
       A[i*n+i] = value;
   }
-
-  // Matrix multiplication res = A*B
-  void real_mat_prod(uint n, real* res, const real* A, const real* B);
-
-  // Matrix multiplication A = A * B
-  void real_mat_prod_inplace(uint n, real* A, const real* B);
-
-  // Matrix vector product y = Ax
-  void real_mat_vector_prod(uint n, real* y, const real* A, const real* x);
-
-  // Matrix power A = B^q
-  void real_mat_pow(uint n, real* A, const real* B, uint q);
-
 }
 #endif
