@@ -1,12 +1,26 @@
-// Copyright (C) 2007-2010 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2007-2010 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells, 2007-2009
 // Modified by Ola Skavhaug, 2007-2009
 // Modified by Kent-Andre Mardal, 2008
 //
 // First added:  2007-01-17
-// Last changed: 2011-02-21
+// Last changed: 2011-04-13
 
 #include <dolfin/log/dolfin_log.h>
 #include <dolfin/common/Timer.h>
@@ -36,12 +50,7 @@ void Assembler::assemble(GenericTensor& A,
                          bool reset_sparsity,
                          bool add_values)
 {
-  // Extract boundary indicators (if any)
-  MeshFunction<uint>* exterior_facet_domains
-    = a.mesh().data().mesh_function("exterior facet domains");
-
-  // Assemble
-  assemble(A, a, 0, exterior_facet_domains, 0, reset_sparsity, add_values);
+  assemble(A, a, 0, 0, 0, reset_sparsity, add_values);
 }
 //-----------------------------------------------------------------------------
 void Assembler::assemble(GenericTensor& A,
@@ -71,7 +80,9 @@ void Assembler::assemble(GenericTensor& A,
   }
 
   // Assemble
-  assemble(A, a, cell_domains, facet_domains, facet_domains, reset_sparsity, add_values);
+  assemble(A, a,
+           cell_domains, facet_domains, facet_domains,
+           reset_sparsity, add_values);
 
   // Delete domains
   delete cell_domains;
@@ -92,17 +103,35 @@ void Assembler::assemble(GenericTensor& A,
   // treating empty mesh functions as null pointers for the PyDOLFIN
   // interface.
 
+  // Get cell domains
+  if (!cell_domains || cell_domains->size() == 0)
+  {
+    cell_domains = a.cell_domains_shared_ptr().get();
+    if (!cell_domains)
+      cell_domains = a.mesh().data().mesh_function("cell_domains").get();
+  }
+
+  // Get exterior facet domains
+  if (!exterior_facet_domains || exterior_facet_domains->size() == 0)
+  {
+    exterior_facet_domains = a.exterior_facet_domains_shared_ptr().get();
+    if (!exterior_facet_domains)
+      exterior_facet_domains = a.mesh().data().mesh_function("exterior_facet_domains").get();
+  }
+
+  // Get interior facet domains
+  if (!interior_facet_domains || interior_facet_domains->size() == 0)
+  {
+    interior_facet_domains = a.interior_facet_domains_shared_ptr().get();
+    if (!interior_facet_domains)
+      interior_facet_domains = a.mesh().data().mesh_function("interior_facet_domains").get();
+  }
+
   // Check whether we should call the multi-core assembler
   #ifdef HAS_OPENMP
   const uint num_threads = parameters["num_threads"];
   if (num_threads > 0)
   {
-    //MulticoreAssembler::assemble(A, a,
-    //                             cell_domains,
-    //                             exterior_facet_domains,
-    //                             interior_facet_domains,
-    //                             reset_sparsity, add_values, num_threads);
-
     OpenMpAssembler::assemble(A, a,
                               cell_domains,
                               exterior_facet_domains,
@@ -240,15 +269,12 @@ void Assembler::assemble_exterior_facets(GenericTensor& A,
   mesh.init(D - 1, D);
   assert(mesh.ordered());
 
-  // Extract exterior (non shared) facets markers
-  const MeshFunction<uint>* exterior_facets = mesh.data().mesh_function("exterior facets");
-
   // Assemble over exterior facets (the cells of the boundary)
   Progress p(AssemblerTools::progress_message(A.rank(), "exterior facets"), mesh.num_facets());
   for (FacetIterator facet(mesh); !facet.end(); ++facet)
   {
     // Only consider exterior facets
-    if (facet->num_entities(D) == 2 || (exterior_facets && !(*exterior_facets)[*facet]))
+    if (!facet->exterior())
     {
       p++;
       continue;
@@ -328,11 +354,11 @@ void Assembler::assemble_interior_facets(GenericTensor& A,
   assert(mesh.ordered());
 
   // Get interior facet directions (if any)
-  MeshFunction<uint>* facet_orientation = mesh.data().mesh_function("facet orientation");
+  boost::shared_ptr<MeshFunction<unsigned int> > facet_orientation = mesh.data().mesh_function("facet orientation");
   if (facet_orientation && facet_orientation->dim() != D - 1)
   {
     error("Expecting facet orientation to be defined on facets (not dimension %d).",
-          facet_orientation);
+          facet_orientation->dim());
   }
 
   // Assemble over interior facets (the facets of the mesh)
@@ -340,7 +366,7 @@ void Assembler::assemble_interior_facets(GenericTensor& A,
   for (FacetIterator facet(mesh); !facet.end(); ++facet)
   {
     // Only consider interior facets
-    if (!facet->interior())
+    if (facet->exterior())
     {
       p++;
       continue;
@@ -361,7 +387,7 @@ void Assembler::assemble_interior_facets(GenericTensor& A,
       continue;
 
     // Get cells incident with facet
-    std::pair<const Cell, const Cell> cells = facet->adjacent_cells(facet_orientation);
+    std::pair<const Cell, const Cell> cells = facet->adjacent_cells(facet_orientation.get());
     const Cell& cell0 = cells.first;
     const Cell& cell1 = cells.second;
 
