@@ -1,12 +1,26 @@
-// Copyright (C) 2007-2008 Anders Logg and Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2007-2008 Anders Logg and Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Kristian Oelgaard, 2008
 // Modified by Martin Sandve Alnes, 2008
 // Modified by Johan Hake, 2009
 //
 // First added:  2007-04-10
-// Last changed: 2011-02-17
+// Last changed: 2011-04-13
 
 #include <boost/assign/list_of.hpp>
 
@@ -45,11 +59,11 @@ DirichletBC::DirichletBC(const FunctionSpace& V, const GenericFunction& g,
   : BoundaryCondition(V),
     Hierarchical<DirichletBC>(*this),
     g(reference_to_no_delete_pointer(g)),
-    _method(method), user_sub_domain(reference_to_no_delete_pointer(sub_domain))
+    _method(method), _user_sub_domain(reference_to_no_delete_pointer(sub_domain))
 {
   check();
   parameters = default_parameters();
-  init_from_sub_domain(user_sub_domain);
+  init_from_sub_domain(_user_sub_domain);
 }
 //-----------------------------------------------------------------------------
 DirichletBC::DirichletBC(boost::shared_ptr<const FunctionSpace> V,
@@ -58,11 +72,11 @@ DirichletBC::DirichletBC(boost::shared_ptr<const FunctionSpace> V,
                          std::string method)
   : BoundaryCondition(V),
     Hierarchical<DirichletBC>(*this),
-    g(g), _method(method), user_sub_domain(sub_domain)
+    g(g), _method(method), _user_sub_domain(sub_domain)
 {
   check();
   parameters = default_parameters();
-  init_from_sub_domain(user_sub_domain);
+  init_from_sub_domain(_user_sub_domain);
 }
 //-----------------------------------------------------------------------------
 DirichletBC::DirichletBC(const FunctionSpace& V, const GenericFunction& g,
@@ -80,7 +94,7 @@ DirichletBC::DirichletBC(const FunctionSpace& V, const GenericFunction& g,
 //-----------------------------------------------------------------------------
 DirichletBC::DirichletBC(boost::shared_ptr<const FunctionSpace> V,
                          boost::shared_ptr<const GenericFunction> g,
-                         const MeshFunction<uint>& sub_domains,
+                         boost::shared_ptr<const MeshFunction<uint> > sub_domains,
                          uint sub_domain,
                          std::string method)
   : BoundaryCondition(V),
@@ -89,7 +103,7 @@ DirichletBC::DirichletBC(boost::shared_ptr<const FunctionSpace> V,
 {
   check();
   parameters = default_parameters();
-  init_from_mesh_function(sub_domains, sub_domain);
+  init_from_mesh_function(*sub_domains, sub_domain);
 }
 //-----------------------------------------------------------------------------
 DirichletBC::DirichletBC(const FunctionSpace& V, const GenericFunction& g,
@@ -115,18 +129,6 @@ DirichletBC::DirichletBC(boost::shared_ptr<const FunctionSpace> V,
   init_from_mesh(sub_domain);
 }
 //-----------------------------------------------------------------------------
-DirichletBC::DirichletBC(const FunctionSpace& V, const GenericFunction& g,
-                         const std::vector<std::pair<uint, uint> >& markers,
-                         std::string method)
-  : BoundaryCondition(V),
-    Hierarchical<DirichletBC>(*this),
-    g(reference_to_no_delete_pointer(g)), _method(method),
-    facets(markers)
-{
-  check();
-  parameters = default_parameters();
-}
-//-----------------------------------------------------------------------------
 DirichletBC::DirichletBC(boost::shared_ptr<const FunctionSpace> V,
                          boost::shared_ptr<const GenericFunction> g,
                          const std::vector<std::pair<uint, uint> >& markers,
@@ -159,7 +161,7 @@ const DirichletBC& DirichletBC::operator= (const DirichletBC& bc)
   _function_space = bc._function_space;
   g = bc.g;
   _method = bc._method;
-  user_sub_domain = bc.user_sub_domain;
+  _user_sub_domain = bc._user_sub_domain;
   facets = bc.facets;
 
   // Call assignment operator for base class
@@ -306,26 +308,19 @@ void DirichletBC::zero_columns(GenericMatrix& A, GenericVector& b, double diag_v
   b.apply("add");
 }
 //-----------------------------------------------------------------------------
-const std::vector<std::pair<dolfin::uint, dolfin::uint> >& DirichletBC::markers()
+const std::vector<std::pair<dolfin::uint, dolfin::uint> >& DirichletBC::markers() const
 {
   return facets;
 }
 //-----------------------------------------------------------------------------
-const GenericFunction& DirichletBC::value() const
-{
-  return *g;
-}
-//-----------------------------------------------------------------------------
-boost::shared_ptr<const GenericFunction> DirichletBC::value_ptr() const
+boost::shared_ptr<const GenericFunction> DirichletBC::value() const
 {
   return g;
 }
 //-----------------------------------------------------------------------------
-boost::shared_ptr<const SubDomain> DirichletBC::user_sub_domain_ptr() const
+boost::shared_ptr<const SubDomain> DirichletBC::user_sub_domain() const
 {
-  if (!user_sub_domain)
-    error("No user subdomain defined");
-  return user_sub_domain;
+  return _user_sub_domain;
 }
 //-----------------------------------------------------------------------------
 bool DirichletBC::is_compatible(GenericFunction& v) const
@@ -409,9 +404,7 @@ void DirichletBC::homogenize()
   }
 
   const uint value_dim = g->value_dimension(0);
-  std::vector<double> values;
-  for (uint i = 0; i < value_dim; i ++)
-    values.push_back(0.0);
+  std::vector<double> values(value_dim, 0.0);
   boost::shared_ptr<Constant> zero(new Constant(values));
   set_value(zero);
 }
@@ -467,7 +460,7 @@ void DirichletBC::apply(GenericMatrix* A,
       values[i] = x_values[i] - values[i];
   }
 
-  info(PROGRESS, "Applying boundary conditions to linear system.");
+  log(PROGRESS, "Applying boundary conditions to linear system.");
 
   // Modify RHS vector (b[i] = value) and apply changes
   if (b)
@@ -715,7 +708,7 @@ void DirichletBC::compute_bc_geometric(Map& boundary_values,
   const GenericDofMap& dofmap = _function_space->dofmap();
 
   // Initialize facets, needed for geometric search
-  info(TRACE, "Computing facets, needed for geometric application of boundary conditions.");
+  log(TRACE, "Computing facets, needed for geometric application of boundary conditions.");
   mesh.init(mesh.topology().dim() - 1);
 
   // Iterate over facets
@@ -777,7 +770,7 @@ void DirichletBC::compute_bc_pointwise(Map& boundary_values,
 {
   assert(_function_space);
   assert(g);
-  assert(user_sub_domain);
+  assert(_user_sub_domain);
 
   // Get mesh and dofmap
   const Mesh& mesh = _function_space->mesh();
@@ -803,7 +796,7 @@ void DirichletBC::compute_bc_pointwise(Map& boundary_values,
     for (uint i = 0; i < dofmap.cell_dimension(cell->index()); ++i)
     {
       // Check if the coordinates are part of the sub domain (calls user-defined 'indside' function)
-      if (!user_sub_domain->inside(data.array_coordinates[i], false))
+      if (!_user_sub_domain->inside(data.array_coordinates[i], false))
         continue;
 
       if (!already_interpolated)
