@@ -1,11 +1,25 @@
-// Copyright (C) 2007-2010 Anders Logg and Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2007-2010 Anders Logg and Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Kristian Oelgaard, 2007
 // Modified by Johan Hake, 2009
 //
 // First added:  2007-04-10
-// Last changed: 2011-02-17
+// Last changed: 2011-04-13
 //
 // FIXME: This class needs some cleanup, in particular collecting
 // FIXME: all data from different representations into a common
@@ -85,7 +99,6 @@ namespace dolfin
   public:
 
     typedef boost::unordered_map<uint, double> Map;
-    //typedef std::map<uint, double> Map;
 
     /// Create boundary condition for subdomain
     DirichletBC(const FunctionSpace& V,
@@ -102,13 +115,15 @@ namespace dolfin
     /// Create boundary condition for subdomain specified by index
     DirichletBC(const FunctionSpace& V,
                 const GenericFunction& g,
-                const MeshFunction<uint>& sub_domains, uint sub_domain,
+                const MeshFunction<unsigned int>& sub_domains,
+                uint sub_domain,
                 std::string method="topological");
 
     /// Create boundary condition for subdomain specified by index
     DirichletBC(boost::shared_ptr<const FunctionSpace> V,
                 boost::shared_ptr<const GenericFunction> g,
-                const MeshFunction<uint>& sub_domains, uint sub_domain,
+                boost::shared_ptr<const MeshFunction<unsigned int> > sub_domains,
+                uint sub_domain,
                 std::string method="topological");
 
     /// Create boundary condition for boundary data included in the mesh
@@ -123,13 +138,6 @@ namespace dolfin
                 uint sub_domain,
                 std::string method="topological");
 
-    /// Create boundary condition for subdomain by boundary markers
-    /// (cells, local facet numbers)
-    DirichletBC(const FunctionSpace& V,
-                const GenericFunction& g,
-                const std::vector<std::pair<uint, uint> >& markers,
-                std::string method="topological");
-
     /// Create boundary condition for subdomain by boundary markers
     /// (cells, local facet numbers)
     DirichletBC(boost::shared_ptr<const FunctionSpace> V,
@@ -177,17 +185,13 @@ namespace dolfin
 
     /// Return boundary markers (facets stored as pairs of cells and local
     /// facet numbers)
-    const std::vector<std::pair<uint, uint> >& markers();
+    const std::vector<std::pair<uint, uint> >& markers() const;
 
     /// Return boundary value g
-    const GenericFunction& value() const;
-
-    /// Return shared pointer to boundary value g
-    /// Testing multiline comment
-    boost::shared_ptr<const GenericFunction> value_ptr() const;
+    boost::shared_ptr<const GenericFunction> value() const;
 
     //// Return shared pointer to sub-domain
-    boost::shared_ptr<const SubDomain> user_sub_domain_ptr() const;
+    boost::shared_ptr<const SubDomain> user_sub_domain() const;
 
     /// Check if given function is compatible with boundary condition
     /// (checking only vertex values)
@@ -265,7 +269,7 @@ namespace dolfin
     static const std::set<std::string> methods;
 
     // User defined sub domain
-    boost::shared_ptr<const SubDomain> user_sub_domain;
+    boost::shared_ptr<const SubDomain> _user_sub_domain;
 
     // Boundary facets, stored as pairs (cell, local facet number)
     std::vector<std::pair<uint, uint> > facets;
