@@ -1,12 +1,26 @@
-// Copyright (C) 2007-2011 Anders Logg and Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2007-2011 Anders Logg and Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Martin Alnes, 2008
 // Modified by Kent-Andre Mardal, 2009
 // Modified by Ola Skavhaug, 2009
 //
 // First added:  2007-03-01
-// Last changed: 2011-02-23
+// Last changed: 2011-04-13
 
 #ifndef __DOF_MAP_H
 #define __DOF_MAP_H
@@ -15,6 +29,7 @@
 #include <memory>
 #include <utility>
 #include <vector>
+#include <boost/scoped_ptr.hpp>
 #include <boost/shared_ptr.hpp>
 #include <boost/unordered_map.hpp>
 #include <ufc.h>
@@ -31,28 +46,31 @@ namespace dolfin
 
   /// This class handles the mapping of degrees of freedom. It builds
   /// a dof map based on a ufc::dofmap on a specific mesh. It will
-  /// reorder the dofs when running in parallel.
-  ///
-  /// If ufc_offset != 0, then the dof map provides a view into a
-  /// larger dof map. A dof map which is a view, can be 'collapsed'
-  /// such that the dof indices are contiguous.
+  /// reorder the dofs when running in parallel. Sub-dofmaps, both
+  /// views and copies, are supported.
 
   class DofMap : public GenericDofMap
   {
   public:
 
-    /// Create dof map on mesh
-    DofMap(boost::shared_ptr<ufc::dofmap> ufc_dofmap,
-           Mesh& dolfin_mesh);
+    /// Create dof map on mesh (data is not shared)
+    DofMap(boost::shared_ptr<const ufc::dofmap> ufc_dofmap, Mesh& mesh);
 
-    /// Create dof map on mesh (const mesh version)
-    DofMap(boost::shared_ptr<ufc::dofmap> ufc_dofmap,
-           const Mesh& dolfin_mesh);
+    /// Create dof map on mesh ((data is not shared), const mesh version)
+    DofMap(boost::shared_ptr<const ufc::dofmap> ufc_dofmap, const Mesh& mesh);
+
+    /// Copy constructor
+    DofMap(const DofMap& dofmap);
 
   private:
 
-    /// Create dof map on mesh with a std::vector dof map
-    DofMap(boost::shared_ptr<ufc::dofmap> ufc_dofmap, const UFCMesh& ufc_mesh);
+    /// Create a sub-dofmap (a view) from parent_dofmap
+    DofMap(const DofMap& parent_dofmap, const std::vector<uint>& component,
+           const Mesh& mesh, bool distributed);
+
+    /// Create a collapsed dofmap from parent_dofmap
+    DofMap(boost::unordered_map<uint, uint>& collapsed_map,
+           const DofMap& dofmap_view, const Mesh& mesh, bool distributed);
 
   public:
 
@@ -69,6 +87,8 @@ namespace dolfin
     /// Return the dimension of the global finite element function space
     unsigned int global_dimension() const;
 
+    // FIXME: Rename this function, 'cell_dimension' sounds confusing
+
     /// Return the dimension of the local finite element function space on a
     // cell
     unsigned int cell_dimension(uint cell_index) const;
@@ -115,13 +135,16 @@ namespace dolfin
     /// Tabulate the coordinates of all dofs on a cell (DOLFIN cell version)
     void tabulate_coordinates(double** coordinates, const Cell& cell) const;
 
+    /// Create a copy of the dof map
+    DofMap* copy(const Mesh& mesh) const;
+
     /// Extract sub dofmap component
     DofMap* extract_sub_dofmap(const std::vector<uint>& component,
-                               const Mesh& dolfin_mesh) const;
+                               const Mesh& mesh) const;
 
     /// Create a "collapsed" dofmap (collapses a sub-dofmap)
-    DofMap* collapse(std::map<uint, uint>& collapsed_map,
-                     const Mesh& dolfin_mesh) const;
+    DofMap* collapse(boost::unordered_map<uint, uint>& collapsed_map,
+                     const Mesh& mesh) const;
 
     /// Return the set of dof indices
     boost::unordered_set<dolfin::uint> dofs() const;
@@ -132,51 +155,42 @@ namespace dolfin
     /// Return informal string representation (pretty-print)
     std::string str(bool verbose) const;
 
+  private:
+
+    // Friends
+    friend class DofMapBuilder;
+
     // Recursively extract UFC sub-dofmap and compute offset
-    static ufc::dofmap* extract_sub_dofmap(const ufc::dofmap& ufc_dofmap,
+    static ufc::dofmap* extract_ufc_sub_dofmap(const ufc::dofmap& ufc_dofmap,
                                             uint& offset,
                                             const std::vector<uint>& component,
                                             const ufc::mesh ufc_mesh,
                                             const Mesh& dolfin_mesh);
 
-    /// Return ufc::dofmap
-    boost::shared_ptr<const ufc::dofmap> ufc_dofmap() const
-    { return _ufc_dofmap; }
-
-  private:
-
-    /// Friends
-    friend class DofMapBuilder;
-
-    // Build dofmap from the UFC dofmap
-    void build(const Mesh& dolfin_mesh, const UFCMesh& ufc_mesh);
-
-    /// Initialize the UFC dofmap
-    static void init_ufc_dofmap(ufc::dofmap& dofmap,
-                                const ufc::mesh ufc_mesh,
+    // Initialize the UFC dofmap
+    static void init_ufc_dofmap(ufc::dofmap& dofmap, const ufc::mesh ufc_mesh,
                                 const Mesh& dolfin_mesh);
 
     // Local-to-global dof map (dofs for cell dofmap[i])
     std::vector<std::vector<dolfin::uint> > dofmap;
 
-    // Map from UFC dof numbering to renumbered dof (ufc_dof, actual_dof)
-    std::map<dolfin::uint, uint> ufc_map_to_dofmap;
-
     // UFC dof map
-    boost::shared_ptr<ufc::dofmap> _ufc_dofmap;
+    boost::scoped_ptr<ufc::dofmap> _ufc_dofmap;
+
+    // Map from UFC dof numbering to renumbered dof (ufc_dof, actual_dof)
+    boost::unordered_map<dolfin::uint, uint> ufc_map_to_dofmap;
+
+    // UFC dof map offset
+    unsigned int ufc_offset;
 
     // Ownership range (dofs in this range are owned by this process)
     std::pair<uint, uint> _ownership_range;
 
-    // Owner (process) of dofs in this local dof map that do not belong to
+    // Owner (process) of dofs in local dof map that do not belong to
     // this process
     boost::unordered_map<uint, uint> _off_process_owner;
 
-    // UFC dof map offset (this is greater than zero when the dof map is a view,
-    // i.e. a sub-dofmap that has not been collapsed)
-    unsigned int ufc_offset;
-
-    // True iff sub-dofmap
+    // True iff sub-dofmap (a view, i.e. not collapsed)
     bool _is_view;
 
     // True iff running in parallel
