@@ -1,5 +1,19 @@
-// Copyright (C) 2008 Anders Logg and Ola Skavhaug.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2008 Anders Logg and Ola Skavhaug
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Niclas Jansson 2009.
 //
@@ -17,8 +31,9 @@ namespace dolfin
 {
 
   class DofMap;
-  class UFC;
   class Mesh;
+  class UFC;
+  class UFCMesh;
 
   /// Documentation of class
 
@@ -39,11 +54,15 @@ namespace dolfin
 
   public:
 
-    /// Build dof map
-    static void parallel_build(DofMap& dofmap, const Mesh& mesh);
+    static void build(DofMap& dofmap, const Mesh& dolfin_mesh,
+                      const UFCMesh& ufc_mesh, bool distributed);
+
 
   private:
 
+    // Build distributed dof map
+    static void build_distributed(DofMap& dofmap, const Mesh& mesh);
+
     static void compute_ownership(set& owned_dofs, set& shared_owned_dofs,
                                   set& shared_unowned_dofs,
                                   const DofMap& dofmap,
