@@ -1,13 +1,28 @@
-// Copyright (C) 2007-2008 Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2007-2008 Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Anders Logg, 2008-2011.
 // Modified by Martin Alnes, 2008.
 //
 // First added:  2007-12-10
-// Last changed: 2011-02-03
+// Last changed: 2011-03-23
 
 #include <string>
+#include <boost/scoped_ptr.hpp>
 #include <dolfin/common/NoDeleter.h>
 #include <dolfin/fem/FiniteElement.h>
 #include <dolfin/function/Function.h>
@@ -26,8 +41,8 @@ using namespace dolfin;
 //-----------------------------------------------------------------------------
 Form::Form(uint rank, uint num_coefficients)
   : Hierarchical<Form>(*this),
-    _function_spaces(rank),
-    _coefficients(num_coefficients)
+    cell_domains(*this), exterior_facet_domains(*this), interior_facet_domains(*this),
+    _function_spaces(rank), _coefficients(num_coefficients)
 {
   // Do nothing
 }
@@ -36,29 +51,12 @@ Form::Form(boost::shared_ptr<const ufc::form> ufc_form,
            std::vector<boost::shared_ptr<const FunctionSpace> > function_spaces,
            std::vector<boost::shared_ptr<const GenericFunction> > coefficients)
   : Hierarchical<Form>(*this),
-    _ufc_form(ufc_form),
-    _function_spaces(function_spaces),
-    _coefficients(coefficients)
+    cell_domains(*this), exterior_facet_domains(*this), interior_facet_domains(*this),
+    _ufc_form(ufc_form), _function_spaces(function_spaces), _coefficients(coefficients)
 {
   // Do nothing
 }
 //-----------------------------------------------------------------------------
-Form::Form(const ufc::form& ufc_form,
-           const std::vector<const FunctionSpace*>& function_spaces,
-           const std::vector<const GenericFunction*>& coefficients)
-  : Hierarchical<Form>(*this),
-    _function_spaces(function_spaces.size()),
-    _coefficients(coefficients.size())
-{
-  for (uint i = 0; i < function_spaces.size(); i++)
-    _function_spaces[i] = reference_to_no_delete_pointer(*function_spaces[i]);
-
-  for (uint i = 0; i < coefficients.size(); i++)
-    _coefficients[i] = reference_to_no_delete_pointer(*coefficients[i]);
-
-  _ufc_form = reference_to_no_delete_pointer(ufc_form);
-}
-//-----------------------------------------------------------------------------
 Form::~Form()
 {
   // Do nothing
@@ -76,9 +74,34 @@ dolfin::uint Form::num_coefficients() const
   return _ufc_form->num_coefficients();
 }
 //-----------------------------------------------------------------------------
-void Form::set_mesh(const Mesh& mesh)
+std::vector<dolfin::uint> Form::coloring(uint entity_dim) const
 {
-  _mesh = reference_to_no_delete_pointer(mesh);
+  warning("Form::coloring does not properly consider form type.");
+
+  // Get mesh from first function space
+  assert(_function_spaces[0]);
+  const Mesh& mesh = _function_spaces[0]->mesh();
+  const uint cell_dim = mesh.topology().dim();
+
+  std::vector<uint> _coloring;
+  if (entity_dim == cell_dim)
+  {
+    _coloring.push_back(cell_dim);
+    _coloring.push_back(0);
+    _coloring.push_back(cell_dim);
+  }
+  else if (entity_dim == cell_dim - 1)
+  {
+    _coloring.push_back(cell_dim - 1);
+    _coloring.push_back(cell_dim);
+    _coloring.push_back(0);
+    _coloring.push_back(cell_dim);
+    _coloring.push_back(cell_dim - 1);
+  }
+  else
+    error("Coloring for other than cell or facet assembly not supported.");
+
+  return _coloring;
 }
 //-----------------------------------------------------------------------------
 void Form::set_mesh(boost::shared_ptr<const Mesh> mesh)
@@ -95,8 +118,10 @@ const Mesh& Form::mesh() const
   // Extract meshes from function spaces
   std::vector<const Mesh*> meshes;
   for (uint i = 0; i < _function_spaces.size(); i++)
+  {
     if (_function_spaces[i])
       meshes.push_back(&_function_spaces[i]->mesh());
+  }
 
   // Add common mesh if any
   if (_mesh)
@@ -123,8 +148,10 @@ const Mesh& Form::mesh() const
 
   // Check that all meshes are the same
   for (uint i = 1; i < meshes.size(); i++)
+  {
     if (meshes[i] != meshes[i - 1])
       error("Unable to extract mesh from form (nonmatching meshes for function spaces).");
+  }
 
   // Return first mesh
   assert(meshes[0]);
@@ -147,12 +174,6 @@ std::vector<boost::shared_ptr<const FunctionSpace> > Form::function_spaces() con
   return _function_spaces;
 }
 //-----------------------------------------------------------------------------
-void Form::set_coefficient(uint i, const GenericFunction& coefficient)
-{
-  assert(i < _coefficients.size());
-  _coefficients[i] = reference_to_no_delete_pointer(coefficient);
-}
-//-----------------------------------------------------------------------------
 void Form::set_coefficient(uint i,
                            boost::shared_ptr<const GenericFunction> coefficient)
 {
@@ -160,50 +181,32 @@ void Form::set_coefficient(uint i,
   _coefficients[i] = coefficient;
 }
 //-----------------------------------------------------------------------------
-void Form::set_coefficient(std::string name,
-                           const GenericFunction& coefficient)
-{
-  set_coefficient(coefficient_number(name), coefficient);
-}
-//-----------------------------------------------------------------------------
 void Form::set_coefficient(std::string name,
                            boost::shared_ptr<const GenericFunction> coefficient)
 {
   set_coefficient(coefficient_number(name), coefficient);
 }
 //-----------------------------------------------------------------------------
-void Form::set_coefficients(std::map<std::string, const GenericFunction*> coefficients)
-{
-  std::map<std::string, const GenericFunction*>::iterator it;
-  for (it = coefficients.begin(); it != coefficients.end(); ++it)
-    set_coefficient(it->first, *it->second);
-}
-//-----------------------------------------------------------------------------
 void Form::set_coefficients(std::map<std::string, boost::shared_ptr<const GenericFunction> > coefficients)
 {
   std::map<std::string, boost::shared_ptr<const GenericFunction> >::iterator it;
   for (it = coefficients.begin(); it != coefficients.end(); ++it)
-    set_coefficient(it->first, *it->second);
+    set_coefficient(it->first, it->second);
 }
 //-----------------------------------------------------------------------------
-const GenericFunction& Form::coefficient(uint i) const
+boost::shared_ptr<const GenericFunction> Form::coefficient(uint i) const
 {
   assert(i < _coefficients.size());
-  return *_coefficients[i];
+  return _coefficients[i];
 }
 //-----------------------------------------------------------------------------
-const GenericFunction& Form::coefficient(std::string name) const
+boost::shared_ptr<const GenericFunction> Form::coefficient(std::string name) const
 {
   return coefficient(coefficient_number(name));
 }
 //-----------------------------------------------------------------------------
 std::vector<boost::shared_ptr<const GenericFunction> > Form::coefficients() const
 {
-  //std::vector<const GenericFunction*> V;
-  //for (uint i = 0; i < _coefficients.size(); ++i)
-  //V.push_back(_coefficients[i].get());
-  //return V;
-
   return _coefficients;
 }
 //-----------------------------------------------------------------------------
@@ -222,6 +225,42 @@ std::string Form::coefficient_name(uint i) const
   return name.str();
 }
 //-----------------------------------------------------------------------------
+boost::shared_ptr<const MeshFunction<dolfin::uint> >
+Form::cell_domains_shared_ptr() const
+{
+  return _cell_domains;
+}
+//-----------------------------------------------------------------------------
+boost::shared_ptr<const MeshFunction<dolfin::uint> >
+Form::exterior_facet_domains_shared_ptr() const
+{
+  return _exterior_facet_domains;
+}
+//-----------------------------------------------------------------------------
+boost::shared_ptr<const MeshFunction<dolfin::uint> >
+Form::interior_facet_domains_shared_ptr() const
+{
+  return _interior_facet_domains;
+}
+//-----------------------------------------------------------------------------
+void Form::set_cell_domains
+(boost::shared_ptr<const MeshFunction<uint> > cell_domains)
+{
+  _cell_domains = cell_domains;
+}
+//-----------------------------------------------------------------------------
+void Form::set_exterior_facet_domains
+(boost::shared_ptr<const MeshFunction<uint> > exterior_facet_domains)
+{
+  _exterior_facet_domains = exterior_facet_domains;
+}
+//-----------------------------------------------------------------------------
+void Form::set_interior_facet_domains
+(boost::shared_ptr<const MeshFunction<uint> > interior_facet_domains)
+{
+  _interior_facet_domains = interior_facet_domains;
+}
+//-----------------------------------------------------------------------------
 const ufc::form& Form::ufc_form() const
 {
   assert(_ufc_form);
@@ -237,23 +276,27 @@ void Form::check() const
 {
   // Check that the number of argument function spaces is correct
   if (_ufc_form->rank() != _function_spaces.size())
+  {
     error("Form expects %d FunctionSpace(s), %d provided.",
           _ufc_form->rank(), _function_spaces.size());
+  }
 
   // Check that the number of coefficient function spaces is correct
   if (_ufc_form->num_coefficients() != _coefficients.size())
-    error("Form expects %d coefficient function(s), %d provided.",
+  {
+   error("Form expects %d coefficient function(s), %d provided.",
           _ufc_form->num_coefficients(), _coefficients.size());
+  }
 
   // Check argument function spaces
   for (uint i = 0; i < _function_spaces.size(); ++i)
   {
-    std::auto_ptr<ufc::finite_element> element(_ufc_form->create_finite_element(i));
+    boost::scoped_ptr<ufc::finite_element> element(_ufc_form->create_finite_element(i));
     assert(element.get());
     if (element->signature() != _function_spaces[i]->element().signature())
     {
-      info(ERROR, "Expected element: %s", element->signature());
-      info(ERROR, "Input element:    %s", _function_spaces[i]->element().signature().c_str());
+      log(ERROR, "Expected element: %s", element->signature());
+      log(ERROR, "Input element:    %s", _function_spaces[i]->element().signature().c_str());
       error("Wrong type of function space for argument %d.", i);
     }
   }
