@@ -1,5 +1,19 @@
-// Copyright (C) 2010-2011 Anders Logg and Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2010-2011 Anders Logg and Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2010-05-26
 // Last changed: 2011-02-23
@@ -79,13 +93,16 @@ namespace dolfin
     virtual void tabulate_coordinates(double** coordinates,
                                       const Cell& cell) const = 0;
 
+    /// Create a copy of the dof map
+    virtual GenericDofMap* copy(const Mesh& mesh) const = 0;
+
     /// Extract sub dofmap component
     virtual GenericDofMap* extract_sub_dofmap(const std::vector<uint>& component,
-                                              const Mesh& dolfin_mesh) const = 0;
+                                              const Mesh& mesh) const = 0;
 
-    /// Create a "collapsed" a dofmap (collapses a sub-dofmap)
-    virtual GenericDofMap* collapse(std::map<uint, uint>& collapsed_map,
-                                    const Mesh& dolfin_mesh) const = 0;
+    /// Create a "collapsed" a dofmap (collapses from a sub-dofmap view)
+    virtual GenericDofMap* collapse(boost::unordered_map<uint, uint>& collapsed_map,
+                                    const Mesh& mesh) const = 0;
 
     /// Return the set of dof indices
     virtual boost::unordered_set<dolfin::uint> dofs() const = 0;
