@@ -1,12 +1,26 @@
-// Copyright (C) 2010-2011 Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2010-2011 Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells, 2007-2009
 // Modified by Ola Skavhaug, 2007-2009
 // Modified by Kent-Andre Mardal, 2008
 //
 // First added:  2010-11-10
-// Last changed: 2011-02-21
+// Last changed: 2011-03-10
 
 #ifdef HAS_OPENMP
 
@@ -43,12 +57,7 @@ void OpenMpAssembler::assemble(GenericTensor& A,
                                bool reset_sparsity,
                                bool add_values)
 {
-  // Extract boundary indicators (if any)
-  MeshFunction<uint>* exterior_facet_domains
-    = a.mesh().data().mesh_function("exterior facet domains");
-
-  // Assemble
-  assemble(A, a, 0, exterior_facet_domains, 0, reset_sparsity, add_values);
+  assemble(A, a, 0, 0, 0, reset_sparsity, add_values);
 }
 //-----------------------------------------------------------------------------
 void OpenMpAssembler::assemble(GenericTensor& A,
@@ -59,6 +68,9 @@ void OpenMpAssembler::assemble(GenericTensor& A,
                                bool reset_sparsity,
                                bool add_values)
 {
+  if (MPI::num_processes() > 1)
+    error("OpenMpAssembler has not been tested in combination with MPI.");
+
   //warning("OpenMpAssembler is experimental.");
 
   // All assembler functions above end up calling this function, which
@@ -114,9 +126,8 @@ void OpenMpAssembler::assemble_cells(GenericTensor& A,
   if (domains && domains->size() > 0)
     error("Sub-domains not yet handled by OpenMpAssembler.");
 
-  // Extract mesh and color
+  // Extract mesh
   const Mesh& mesh = a.mesh();
-  mesh.color("vertex");
 
   // FIXME: Check that UFC copy constructor is dealing with copying pointers correctly
   // Dummy UFC object since each thread needs to created its own UFC object
@@ -136,20 +147,15 @@ void OpenMpAssembler::assemble_cells(GenericTensor& A,
   // Vector to hold dof map for a cell
   std::vector<const std::vector<uint>* > dofs(form_rank);
 
-  // FIXME: Pass or determine coloring type
-  // Define graph type
-  std::vector<uint> coloring_type;
-  coloring_type.push_back(mesh.topology().dim());
-  coloring_type.push_back(0);
-  coloring_type.push_back(mesh.topology().dim());
+  // Color mesh
+  std::vector<uint> coloring_type = a.coloring(mesh.topology().dim());
+  mesh.color(coloring_type);
 
   // Get coloring data
   std::map<const std::vector<uint>,
            std::pair<MeshFunction<uint>, std::vector<std::vector<uint> > > >::const_iterator mesh_coloring;
-  mesh_coloring = mesh.data().coloring.find(coloring_type);
-
-  // Check that requested coloring has been computed
-  if (mesh_coloring == mesh.data().coloring.end())
+  mesh_coloring = mesh.parallel_data().coloring.find(coloring_type);
+  if (mesh_coloring == mesh.parallel_data().coloring.end())
     error("Requested mesh coloring has not been computed. Cannot used multithreaded assembly.");
 
   // Get coloring data
@@ -231,9 +237,8 @@ void OpenMpAssembler::assemble_cells_and_exterior_facets(GenericTensor& A,
   // Set number of OpenMP threads (from parameter systems)
   omp_set_num_threads(parameters["num_threads"]);
 
-  // Extract mesh and colors
+  // Extract mesh
   const Mesh& mesh = a.mesh();
-  mesh.color("vertex");
 
   // Compute facets and facet - cell connectivity if not already computed
   const uint D = mesh.topology().dim();
@@ -251,9 +256,6 @@ void OpenMpAssembler::assemble_cells_and_exterior_facets(GenericTensor& A,
   const ufc::cell_integral* cell_integral = ufc.cell_integrals[0].get();
   const ufc::exterior_facet_integral* facet_integral = ufc.exterior_facet_integrals[0].get();
 
-  // Extract exterior (non shared) facets markers
-  const MeshFunction<uint>* exterior_facets = mesh.data().mesh_function("exterior facets");
-
   // Collect pointers to dof maps
   std::vector<const GenericDofMap*> dofmaps;
   for (uint i = 0; i < form_rank; ++i)
@@ -264,18 +266,14 @@ void OpenMpAssembler::assemble_cells_and_exterior_facets(GenericTensor& A,
 
   // FIXME: Pass or determine coloring type
   // Define graph type
-  std::vector<uint> coloring_type;
-  coloring_type.push_back(mesh.topology().dim());
-  coloring_type.push_back(0);
-  coloring_type.push_back(mesh.topology().dim());
+  std::vector<uint> coloring_type = a.coloring(mesh.topology().dim());
+  mesh.color(coloring_type);
 
   // Get coloring data
   std::map<const std::vector<uint>,
            std::pair<MeshFunction<uint>, std::vector<std::vector<uint> > > >::const_iterator mesh_coloring;
-  mesh_coloring = mesh.data().coloring.find(coloring_type);
-
-  // Check that requested coloring has been computed
-  if (mesh_coloring == mesh.data().coloring.end())
+  mesh_coloring = mesh.parallel_data().coloring.find(coloring_type);
+  if (mesh_coloring == mesh.parallel_data().coloring.end())
     error("Requested mesh coloring has not been computed. Cannot used multithreaded assembly.");
 
   // Get coloring data
@@ -338,7 +336,7 @@ void OpenMpAssembler::assemble_cells_and_exterior_facets(GenericTensor& A,
       for (FacetIterator facet(cell); !facet.end(); ++facet)
       {
         // Only consider exterior facets
-        if (facet->num_entities(D) == 2 || (exterior_facets && !(*exterior_facets)[*facet]))
+        if (!facet->exterior())
         {
           p++;
           continue;
@@ -395,12 +393,7 @@ void OpenMpAssembler::assemble_interior_facets(GenericTensor& A,
   const Mesh& mesh = a.mesh();
 
   // Color mesh
-  std::vector<dolfin::uint> coloring_type;
-  coloring_type.push_back(mesh.topology().dim() - 1);
-  coloring_type.push_back(mesh.topology().dim());
-  coloring_type.push_back(0);
-  coloring_type.push_back(mesh.topology().dim());
-  coloring_type.push_back(mesh.topology().dim()-1);
+  std::vector<uint> coloring_type = a.coloring(mesh.topology().dim() - 1);
   mesh.color(coloring_type);
 
   // Dummy UFC object since each thread needs to created its own UFC object
@@ -426,20 +419,20 @@ void OpenMpAssembler::assemble_interior_facets(GenericTensor& A,
   assert(mesh.ordered());
 
   // Get interior facet directions (if any)
-  MeshFunction<uint>* facet_orientation = mesh.data().mesh_function("facet orientation");
+  boost::shared_ptr<MeshFunction<unsigned int> > facet_orientation = mesh.data().mesh_function("facet orientation");
   if (facet_orientation && facet_orientation->dim() != mesh.topology().dim() - 1)
   {
     error("Expecting facet orientation to be defined on facets (not dimension %d).",
-          facet_orientation);
+          facet_orientation->dim());
   }
 
   // Get coloring data
   std::map<const std::vector<uint>,
            std::pair<MeshFunction<uint>, std::vector<std::vector<uint> > > >::const_iterator mesh_coloring;
-  mesh_coloring = mesh.data().coloring.find(coloring_type);
+  mesh_coloring = mesh.parallel_data().coloring.find(coloring_type);
 
   // Check that requested coloring has been computed
-  if (mesh_coloring == mesh.data().coloring.end())
+  if (mesh_coloring == mesh.parallel_data().coloring.end())
     error("Requested mesh coloring has not been computed. Cannot used multithreaded assembly.");
 
   // Get coloring data
@@ -467,7 +460,7 @@ void OpenMpAssembler::assemble_interior_facets(GenericTensor& A,
       const Facet facet(mesh, index);
 
       // Only consider interior facets
-      if (!facet.interior())
+      if (facet.exterior())
       {
         p++;
         continue;
@@ -488,13 +481,13 @@ void OpenMpAssembler::assemble_interior_facets(GenericTensor& A,
         continue;
 
       // Get cells incident with facet
-      std::pair<const Cell, const Cell> cells = facet.adjacent_cells(facet_orientation);
+      std::pair<const Cell, const Cell> cells = facet.adjacent_cells(facet_orientation.get());
       const Cell& cell0 = cells.first;
       const Cell& cell1 = cells.second;
 
       // Get local index of facet with respect to each cell
-      uint local_facet0 = cell0.index(facet);
-      uint local_facet1 = cell1.index(facet);
+      const uint local_facet0 = cell0.index(facet);
+      const uint local_facet1 = cell1.index(facet);
 
       // Update to current pair of cells
       ufc.update(cell0, local_facet0, cell1, local_facet1);
@@ -511,11 +504,13 @@ void OpenMpAssembler::assemble_interior_facets(GenericTensor& A,
 
         // Copy cell dofs into macro dof vector
         std::copy(cell_dofs0.begin(), cell_dofs0.end(), macro_dofs[i].begin());
-        std::copy(cell_dofs1.begin(), cell_dofs1.end(), macro_dofs[i].begin() + cell_dofs0.size());
+        std::copy(cell_dofs1.begin(), cell_dofs1.end(),
+                  macro_dofs[i].begin() + cell_dofs0.size());
       }
 
       // Tabulate exterior interior facet tensor on macro element
-      integral->tabulate_tensor(ufc.macro_A.get(), ufc.macro_w, ufc.cell0, ufc.cell1,
+      integral->tabulate_tensor(ufc.macro_A.get(), ufc.macro_w,
+                                ufc.cell0, ufc.cell1,
                                 local_facet0, local_facet1);
 
       // Add entries to global tensor
