@@ -1,10 +1,24 @@
-// Copyright (C) 2008-20010 Kent-Andre Mardal and Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2008-2010 Kent-Andre Mardal and Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Anders Logg, 2008-2009.
 //
 // First added:  2009-06-22
-// Last changed: 2011-02-21
+// Last changed: 2011-03-17
 
 #include <dolfin/log/dolfin_log.h>
 #include <dolfin/common/Timer.h>
@@ -64,7 +78,7 @@ void SystemAssembler::assemble(GenericMatrix& A, GenericVector& b,
                                bool reset_sparsity, bool add_values)
 {
   Timer timer("Assemble system");
-  info(PROGRESS, "Assembling linear system and applying boundary conditions...");
+  log(PROGRESS, "Assembling linear system and applying boundary conditions...");
 
   const Mesh& mesh = a.mesh();
 
@@ -202,9 +216,6 @@ void SystemAssembler::cell_wise_assembly(GenericMatrix& A, GenericVector& b,
   mesh.init(D - 1, D);
   assert(mesh.ordered());
 
-  // Extract exterior (non shared) facets markers
-  const MeshFunction<uint>* exterior_facets = mesh.data().mesh_function("exterior facets");
-
   // Form ranks
   const uint a_rank = a.rank();
   const uint L_rank = L.rank();
@@ -247,12 +258,10 @@ void SystemAssembler::cell_wise_assembly(GenericMatrix& A, GenericVector& b,
     // Compute exterior facet integral if present
     if (A_ufc.form.num_exterior_facet_domains() > 0 || b_ufc.form.num_exterior_facet_domains() > 0)
     {
-      const uint D = mesh.topology().dim();
       for (FacetIterator facet(*cell); !facet.end(); ++facet)
       {
-        // Assemble if we have an external facet
-        const bool interior_facet = facet->num_entities(D) == 2 || (exterior_facets && !(*exterior_facets)[*facet]);
-        if (!interior_facet)
+        // Assemble if we have an exterior facet
+        if (facet->exterior())
         {
           const uint local_facet = cell->index(*facet);
           if (A_ufc.form.num_exterior_facet_domains() > 0)
@@ -357,7 +366,8 @@ void SystemAssembler::facet_wise_assembly(GenericMatrix& A, GenericVector& b,
         b_ufc.macro_A[i] = 0.0;
 
       // Assemble interior facet and neighbouring cells if needed
-      assemble_interior_facet(A, b, A_ufc, b_ufc, a, L, cell0, cell1, *facet, data, boundary_values);
+      assemble_interior_facet(A, b, A_ufc, b_ufc, a, L, cell0, cell1, *facet,
+                              data, boundary_values);
     }
     else // Exterior facet
     {
@@ -384,7 +394,8 @@ void SystemAssembler::facet_wise_assembly(GenericMatrix& A, GenericVector& b,
       data.zero_cell();
 
       // Assemble exterior facet and attached cells if needed
-      assemble_exterior_facet(A, b, A_ufc, b_ufc, a, L, cell, *facet, data, boundary_values);
+      assemble_exterior_facet(A, b, A_ufc, b_ufc, a, L, cell, *facet, data,
+                              boundary_values);
     }
     p++;
   }
@@ -420,8 +431,8 @@ void SystemAssembler::compute_tensor_on_one_interior_facet(const Form& a,
 }
 //-----------------------------------------------------------------------------
 inline void SystemAssembler::apply_bc(double* A, double* b,
-                      const DirichletBC::Map& boundary_values,
-                      const std::vector<const std::vector<uint>* >& global_dofs)
+                     const DirichletBC::Map& boundary_values,
+                     const std::vector<const std::vector<uint>* >& global_dofs)
 {
   // Get local dimensions
   const uint m = (global_dofs[0])->size();
@@ -542,13 +553,16 @@ void SystemAssembler::assemble_interior_facet(GenericMatrix& A, GenericVector& b
 
   // Tabulate dofs for each dimension on macro element
   std::copy(a0_dofs0.begin(), a0_dofs0.end(), a_macro_dofs[0].begin());
-  std::copy(a0_dofs1.begin(), a0_dofs1.end(), a_macro_dofs[0].begin() + a0_dofs0.size());
+  std::copy(a0_dofs1.begin(), a0_dofs1.end(),
+            a_macro_dofs[0].begin() + a0_dofs0.size());
 
   std::copy(a1_dofs0.begin(), a1_dofs0.end(), a_macro_dofs[1].begin());
-  std::copy(a1_dofs1.begin(), a1_dofs1.end(), a_macro_dofs[1].begin() + a1_dofs0.size());
+  std::copy(a1_dofs1.begin(), a1_dofs1.end(),
+            a_macro_dofs[1].begin() + a1_dofs0.size());
 
   std::copy(L_dofs0.begin(), L_dofs0.end(), L_macro_dofs[0].begin());
-  std::copy(L_dofs1.begin(), L_dofs1.end(), L_macro_dofs[0].begin() + L_dofs0.size());
+  std::copy(L_dofs1.begin(), L_dofs1.end(),
+            L_macro_dofs[0].begin() + L_dofs0.size());
 
   // Modify local matrix/element for Dirichlet boundary conditions
   std::vector<const std::vector<uint>* > _a_macro_dofs(2);
