@@ -1,5 +1,19 @@
-// Copyright (C) 2007-2011 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2007-2011 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Ola Skavhaug, 2009.
 // Modified by Garth N. Wells, 2010.
@@ -18,6 +32,7 @@
 #include <dolfin/mesh/MeshEntity.h>
 #include <dolfin/mesh/MeshFunction.h>
 #include <dolfin/mesh/Mesh.h>
+#include <dolfin/mesh/ParallelData.h>
 #include <dolfin/fem/ufcexp.h>
 
 namespace dolfin
@@ -57,6 +72,8 @@ namespace dolfin
       // Clear old data
       clear();
 
+      const Mesh& mesh = cell.mesh();
+
       // Set cell shape
       switch (cell.type())
       {
@@ -77,10 +94,10 @@ namespace dolfin
       }
 
       // Set topological dimension
-      topological_dimension = cell.mesh().topology().dim();
+      topological_dimension = mesh.topology().dim();
 
       // Set geometric dimension
-      geometric_dimension = cell.mesh().geometry().dim();
+      geometric_dimension = mesh.geometry().dim();
 
       // Allocate arrays for local entity indices
       entity_indices = new uint*[topological_dimension + 1];
@@ -98,12 +115,13 @@ namespace dolfin
 
       // Get global entity indices (if any)
       global_entities.resize(topological_dimension + 1);
+      const ParallelData& parallel_data = mesh.parallel_data();
       for (uint d = 0; d <= topological_dimension; ++d)
       {
-        std::stringstream name;
-        name << "global entity indices " << d;
-        // This pointer may be zero, in which case local entity indices are used
-        global_entities[d] = cell.mesh().data().mesh_function(name.str());
+        if (parallel_data.have_global_entity_indices(d))
+          global_entities[d] = &(parallel_data.global_entity_indices(d));
+        else
+          global_entities[d] = 0;
       }
 
       // Allocate vertex coordinates
@@ -210,7 +228,7 @@ namespace dolfin
     uint num_higher_order_vertices;
 
     // Mappings from local to global entity indices (if any)
-    std::vector<MeshFunction<uint>*> global_entities;
+    std::vector<const MeshFunction<uint>* > global_entities;
 
     // Number of cell entities of dimension d at initialisation
     std::vector<uint> num_cell_entities;
