@@ -1,5 +1,19 @@
-// Copyright (C) 2007-2011 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2007-2011 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells, 2008, 2009.
 // Modified by Johan Hake, 2009.
@@ -48,9 +62,9 @@ namespace dolfin
   /// Assemble tensor on sub domains
   void assemble(GenericTensor& A,
                 const Form& a,
-                const MeshFunction<uint>* cell_domains,
-                const MeshFunction<uint>* exterior_facet_domains,
-                const MeshFunction<uint>* interior_facet_domains,
+                const MeshFunction<unsigned int>* cell_domains,
+                const MeshFunction<unsigned int>* exterior_facet_domains,
+                const MeshFunction<unsigned int>* interior_facet_domains,
                 bool reset_sparsity=true,
                 bool add_values=false);
 
@@ -86,9 +100,9 @@ namespace dolfin
                        const Form& a,
                        const Form& L,
                        const std::vector<const DirichletBC*>& bcs,
-                       const MeshFunction<uint>* cell_domains,
-                       const MeshFunction<uint>* exterior_facet_domains,
-                       const MeshFunction<uint>* interior_facet_domains,
+                       const MeshFunction<unsigned int>* cell_domains,
+                       const MeshFunction<unsigned int>* exterior_facet_domains,
+                       const MeshFunction<unsigned int>* interior_facet_domains,
                        const GenericVector* x0,
                        bool reset_sparsities=true,
                        bool add_values=false);
@@ -108,9 +122,9 @@ namespace dolfin
 
   /// Assemble scalar on sub domains
   double assemble(const Form& a,
-                  const MeshFunction<uint>* cell_domains,
-                  const MeshFunction<uint>* exterior_facet_domains,
-                  const MeshFunction<uint>* interior_facet_domains,
+                  const MeshFunction<unsigned int>* cell_domains,
+                  const MeshFunction<unsigned int>* exterior_facet_domains,
+                  const MeshFunction<unsigned int>* interior_facet_domains,
                   bool reset_sparsity=true,
                   bool add_values=false);
 
