@@ -1,14 +1,27 @@
-// Copyright (C) 2006-2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2006-2009 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Martin Sandve Alnes, 2008.
-// Modified by Garth N. Wells, 2009.
+// Modified by Garth N. Wells, 2009-2011.
 //
 // First added:  2006-02-09
-// Last changed: 2009-10-05
+// Last changed: 2011-05-15
 
 #include <dolfin/log/log.h>
-#include <dolfin/mesh/Mesh.h>
 #include "Constant.h"
 
 using namespace dolfin;
@@ -97,8 +110,7 @@ Constant::operator double() const
   return _values[0];
 }
 //-----------------------------------------------------------------------------
-void Constant::eval(Array<double>& values, const Array<double>& x,
-                    const ufc::cell& cell) const
+void Constant::eval(Array<double>& values, const Array<double>& x) const
 {
   // Copy values
   for (uint j = 0; j < _values.size(); j++)
