@@ -1,12 +1,26 @@
-// Copyright (C) 2003-2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2003-2009 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells, 2005-2010.
 // Modified by Martin Sandve Alnes, 2008.
 // Modified by Andre Massing, 2009.
 //
 // First added:  2003-11-28
-// Last changed: 2011-02-21
+// Last changed: 2011-03-15
 
 #include <algorithm>
 #include <map>
@@ -26,6 +40,7 @@
 #include <dolfin/la/DefaultFactory.h>
 #include <dolfin/log/log.h>
 #include <dolfin/mesh/Vertex.h>
+#include <dolfin/mesh/Point.h>
 #include <dolfin/parameter/GlobalParameters.h>
 #include "Expression.h"
 #include "FunctionSpace.h"
@@ -39,15 +54,22 @@ Function::Function(const FunctionSpace& V)
     _function_space(reference_to_no_delete_pointer(V)),
     allow_extrapolation(dolfin::parameters["allow_extrapolation"])
 {
+  // Check that we don't have a subspace
+  if (V.component().size() > 0)
+    error("Cannot create Functions using subspaces. Consider collapsing FunctionSpace");
+
   // Initialize vector
   init_vector();
 }
 //-----------------------------------------------------------------------------
 Function::Function(boost::shared_ptr<const FunctionSpace> V)
-  : Hierarchical<Function>(*this),
-    _function_space(V),
+  : Hierarchical<Function>(*this), _function_space(V),
     allow_extrapolation(dolfin::parameters["allow_extrapolation"])
 {
+  // Check that we don't have a subspace
+  if (V->component().size() > 0)
+    error("Cannot create Functions using subspaces. Consider collapsing FunctionSpace");
+
   // Initialize vector
   init_vector();
 }
@@ -58,28 +80,40 @@ Function::Function(const FunctionSpace& V, GenericVector& x)
     _vector(reference_to_no_delete_pointer(x)),
     allow_extrapolation(dolfin::parameters["allow_extrapolation"])
 {
+  // Check that we don't have a subspace
+  if (V.component().size() > 0)
+    error("Cannot create Functions using subspaces. Consider collapsing FunctionSpace");
+
   // Assertion uses '<=' to deal with sub-functions
   assert(V.dofmap().global_dimension() <= x.size());
 }
 //-----------------------------------------------------------------------------
 Function::Function(boost::shared_ptr<const FunctionSpace> V,
                    boost::shared_ptr<GenericVector> x)
-  : Hierarchical<Function>(*this),
-    _function_space(V),
-    _vector(x),
+  : Hierarchical<Function>(*this), _function_space(V), _vector(x),
     allow_extrapolation(dolfin::parameters["allow_extrapolation"])
 {
+  // We do not check for a subspace since this constructor is used for creating
+  // subfunctions
+
   // Assertion uses '<=' to deal with sub-functions
   assert(V->dofmap().global_dimension() <= x->size());
 }
 //-----------------------------------------------------------------------------
 Function::Function(boost::shared_ptr<const FunctionSpace> V,
                    GenericVector& x)
-  : Hierarchical<Function>(*this),
-    _function_space(V),
+  : Hierarchical<Function>(*this), _function_space(V),
     _vector(reference_to_no_delete_pointer(x)),
     allow_extrapolation(dolfin::parameters["allow_extrapolation"])
 {
+  // Check that we don't have a subspace
+  if (V->component().size() > 0)
+    error("Cannot create Functions using subspaces. Consider collapsing FunctionSpace");
+
+  // Check that we don't have a subspace
+  if (V->component().size() > 0)
+    error("Cannot create Functions using subspaces. Consider collapsing FunctionSpace");
+
   // Assertion uses '<=' to deal with sub-functions
   assert(V->dofmap().global_dimension() <= x.size());
 }
@@ -89,6 +123,10 @@ Function::Function(const FunctionSpace& V, std::string filename)
     _function_space(reference_to_no_delete_pointer(V)),
     allow_extrapolation(dolfin::parameters["allow_extrapolation"])
 {
+  // Check that we don't have a subspace
+  if (V.component().size() > 0)
+    error("Cannot create Functions using subspaces. Consider collapsing FunctionSpace");
+
   // Initialize vector
   init_vector();
 
@@ -103,10 +141,13 @@ Function::Function(const FunctionSpace& V, std::string filename)
 //-----------------------------------------------------------------------------
 Function::Function(boost::shared_ptr<const FunctionSpace> V,
                    std::string filename)
-  : Hierarchical<Function>(*this),
-    _function_space(V),
+  : Hierarchical<Function>(*this), _function_space(V),
     allow_extrapolation(dolfin::parameters["allow_extrapolation"])
 {
+  // Check that we don't have a subspace
+  if (V->component().size() > 0)
+    error("Cannot create Functions using subspaces. Consider collapsing FunctionSpace");
+
   // Create vector
   DefaultFactory factory;
   _vector.reset(factory.create_vector());
@@ -151,7 +192,6 @@ const Function& Function::operator= (const Function& v)
 {
   assert(v._vector);
 
-
   // Make a copy of all the data, or if v is a sub-function, then we collapse
   // the dof map and copy only the relevant entries from the vector of v.
   if (v._vector->size() == v._function_space->dim())
@@ -164,21 +204,16 @@ const Function& Function::operator= (const Function& v)
   }
   else
   {
-
-    // Create collapsed dof map
-    const GenericDofMap& v_dofmap = v._function_space->dofmap();
-    std::map<uint, uint> collapsed_map;
-    boost::shared_ptr<GenericDofMap> collapsed_dofmap(v_dofmap.collapse(collapsed_map, v._function_space->mesh()));
-
-    // Create new FunctionsSpapce
-    _function_space = v._function_space->collapse_sub_space(collapsed_dofmap);
+    // Create new collapase FunctionsSpapce
+    boost::unordered_map<uint, uint> collapsed_map;
+    _function_space = v._function_space->collapse(collapsed_map);
 
     // FIXME: This assertion doesn't work in parallel
     //assert(collapsed_map.size() == _function_space->dofmap().global_dimension());
     //assert(collapsed_map.size() == _function_space->dofmap().local_dimension());
 
     // Get row indices of original and new vectors
-    std::map<uint, uint>::const_iterator entry;
+    boost::unordered_map<uint, uint>::const_iterator entry;
     std::vector<uint> new_rows(collapsed_map.size());
     Array<uint> old_rows(collapsed_map.size());
     uint i = 0;
@@ -194,7 +229,7 @@ const Function& Function::operator= (const Function& v)
 
     // Initial new vector (global)
     init_vector();
-    assert(_vector->size() == collapsed_dofmap->global_dimension());
+    assert(_vector->size() == _function_space->dofmap().global_dimension());
 
     // Set values in vector
     this->_vector->set(&gathered_values[0], collapsed_map.size(), &new_rows[0]);
@@ -379,14 +414,65 @@ void Function::eval(Array<double>& values, const Array<double>& x,
 {
   assert(_function_space);
 
-  // Check if UFC cell comes from mesh, otherwise redirect to point-based evaluation
+  // Check if UFC cell comes from mesh, otherwise redirect to
+  // evaluate on non-matching cell
   if (ufc_cell.mesh_identifier == (int) _function_space->mesh().id())
   {
     const Cell cell(_function_space->mesh(), ufc_cell.index);
     eval(values, x, cell, ufc_cell);
   }
   else
-    eval(values, x);
+    non_matching_eval(values, x, ufc_cell);
+}
+//-----------------------------------------------------------------------------
+void Function::non_matching_eval(Array<double>& values,
+                                 const Array<double>& x,
+                                 const ufc::cell& ufc_cell) const
+{
+  assert(_function_space);
+
+  const double* _x = x.data().get();
+  const uint dim = _function_space->mesh().geometry().dim();
+  const Point point(dim, _x);
+
+  // Alternative 1: Find cell that point (x) intersects
+  int id = _function_space->mesh().any_intersected_entity(point);
+
+  if (id == -1 && !allow_extrapolation)
+    error("Unable to evaluate function at given point (not inside domain). Set parameter 'allow_extrapolation' to true to allow extrapolation'.");
+
+  // Alternative 2: Compute closest cell to point (x)
+  if (id == -1 && allow_extrapolation && dim == 2)
+    id = _function_space->mesh().closest_cell(point);
+
+  // Alternative 3: Compute cell that contains barycenter of ufc_cell
+  // NB: This is slightly heuristic, but should work well for
+  // evaluation of points on refined meshes
+  if (id == -1 && allow_extrapolation)
+  {
+    // Extract vertices of ufc_cell
+    const double * const * vertices = ufc_cell.coordinates;
+
+    Point barycenter;
+    for (uint i = 0; i <= dim; i++)
+    {
+      Point vertex(dim, vertices[i]);
+      barycenter += vertex;
+    }
+    barycenter /= (dim + 1);
+    id = _function_space->mesh().any_intersected_entity(barycenter);
+  }
+
+  // Throw error if all alternatives failed.
+  if (id == -1)
+    error("Cannot evaluate function at given point. No matching cell found.");
+
+  // Create cell that contains point
+  const Cell cell(_function_space->mesh(), id);
+  const UFCCell new_ufc_cell(cell);
+
+  // Call evaluate function
+  eval(values, x, cell, new_ufc_cell);
 }
 //-----------------------------------------------------------------------------
 void Function::restrict(double* w,
@@ -398,7 +484,8 @@ void Function::restrict(double* w,
   assert(_function_space);
 
   // Check if we are restricting to an element of this function space
-  if (_function_space->has_element(element) && _function_space->has_cell(dolfin_cell))
+  if (_function_space->has_element(element)
+      && _function_space->has_cell(dolfin_cell))
   {
     // Get dofmap for cell
     const GenericDofMap& dofmap = _function_space->dofmap();
