@@ -1,5 +1,19 @@
-// Copyright (C) 2003-2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2003-2009 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells, 2005-2010.
 // Modified by Kristian B. Oelgaard, 2007.
@@ -7,7 +21,7 @@
 // Modified by Andre Massing, 2009.
 //
 // First added:  2003-11-28
-// Last changed: 2011-01-31
+// Last changed: 2011-03-15
 
 #ifndef __FUNCTION_H
 #define __FUNCTION_H
@@ -140,7 +154,12 @@ namespace dolfin
     virtual uint value_dimension(uint i) const;
 
     /// Evaluate function for given data
-    virtual void eval(Array<double>& values, const Array<double>& x, const ufc::cell& cell) const;
+    virtual void eval(Array<double>& values, const Array<double>& x,
+                      const ufc::cell& cell) const;
+
+    /// Evaluate function for given data
+    void non_matching_eval(Array<double>& values, const Array<double>& x,
+                           const ufc::cell& ufc_cell) const;
 
     /// Restrict function to local cell (compute expansion coefficients w)
     virtual void restrict(double* w,
