@@ -1,5 +1,19 @@
-// Copyright (C) 2003-2005 Johan Hoffman and Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2003-2005 Johan Hoffman and Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells 2005, 2010.
 // Modified by Rolv E. Bredesen 2008.
@@ -108,11 +122,10 @@ void PythonFile::operator<<(const Sample& sample)
   counter2++;
 }
 //-----------------------------------------------------------------------------
-void PythonFile::operator<<(const std::tr1::tuple<uint, real, real*>& sample)
-{
-  const uint& n = std::tr1::get<0>(sample);
-  const real& t = std::tr1::get<1>(sample);
-  const real* u = std::tr1::get<2>(sample);
+void PythonFile::operator<<(const std::pair<real, RealArrayRef> sample)
+{  
+  const real& t      = sample.first;
+  const Array<real>& u = sample.second;
 
   // First time
   if ( counter2 == 0 )
@@ -125,7 +138,7 @@ void PythonFile::operator<<(const std::tr1::tuple<uint, real, real*>& sample)
     fp << "t = fromfile('" << filename_t << "', sep=' ')" << std::endl;
     fp << "u = fromfile('" << filename_u << "', sep=' ')" << std::endl;
     fp << std::endl;
-    fp << "u.shape = len(u) //" << n << ", " << n << std::endl;
+    fp << "u.shape = len(u) //" << u.size() << ", " << u.size() << std::endl;
     fp << std::endl;
     fp.close();
   }
@@ -151,7 +164,7 @@ void PythonFile::operator<<(const std::tr1::tuple<uint, real, real*>& sample)
   fp_t << std::setprecision(prec) << t << std::endl;
 
   // Save solution
-  for (uint i=0; i<n; ++i)
+  for (uint i=0; i < u.size(); ++i)
     fp_u << std::setprecision(prec) << u[i] << " ";
   fp_u << std::endl;
 
