@@ -1,5 +1,19 @@
-// Copyright (C) 2005-2009 Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2005-2009 Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Anders Logg 2006.
 // Modified by NIclas Jansson 2009.
@@ -38,7 +52,7 @@ namespace dolfin
 
     void write(const Function& u, double time);
 
-    std::string init(const Mesh& mesh) const;
+    std::string init(const Mesh& mesh, uint dim) const;
 
     void finalize(std::string vtu_filename, double time);
 
@@ -73,20 +87,8 @@ namespace dolfin
     // Strip path from file
     std::string strip_path(std::string file) const;
 
-    // Compute base64 encoded stream for VTK
-    template<typename T>
-    void encode_stream(std::stringstream& stream, const std::vector<T>& data) const;
-
   private:
 
-    // Compute base64 encoded stream for VTK
-    template<typename T>
-    void encode_inline_base64(std::stringstream& stream, const std::vector<T>& data) const;
-
-    // Compute compressed base64 encoded stream for VTK
-    template<typename T>
-    void encode_inline_compressed_base64(std::stringstream& stream, const std::vector<T>& data) const;
-
     // Most recent position in pvd file
     std::ios::pos_type mark;
 
