@@ -1,10 +1,24 @@
-// Copyright (C) 2009 Ola Skavhaug.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2009 Ola Skavhaug
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells, 2009.
 //
-// First added: 2009-03-03
-// Last changed: 2010-04-05
+// First added:  2009-03-03
+// Last changed: 2011-03-31
 
 #include <libxml/relaxng.h>
 
@@ -94,7 +108,7 @@ void XMLFile::validate(const std::string filename)
                                      stderr);
   ret = xmlRelaxNGValidateDoc(validator, document);
   if (ret == 0)
-    info(DBG, "%s validates", filename.c_str());
+    log(DBG, "%s validates", filename.c_str());
   else if ( ret < 0 )
     error("%s failed to load", filename.c_str());
   else
