@@ -1,5 +1,19 @@
 // Copyright (C) 2009 Ola Skavhaug
-// Licensed under the GNU LGPL Version 2.1.
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2009-03-10
 // Last changed: 2009-09-08
@@ -26,8 +40,8 @@ namespace dolfin
     XMLMeshFunction(MeshFunction<int>& imf, XMLFile& parser);
     XMLMeshFunction(MeshFunction<int>& imf, XMLFile& parser, uint size, uint dim);
 
-    XMLMeshFunction(MeshFunction<uint>& umf, XMLFile& parser);
-    XMLMeshFunction(MeshFunction<uint>& umf, XMLFile& parser, uint size, uint dim);
+    XMLMeshFunction(MeshFunction<unsigned int>& umf, XMLFile& parser);
+    XMLMeshFunction(MeshFunction<unsigned int>& umf, XMLFile& parser, uint size, uint dim);
 
     XMLMeshFunction(MeshFunction<double>& dmf, XMLFile& parser);
     XMLMeshFunction(MeshFunction<double>& dmf, XMLFile& parser, uint size, uint dim);
@@ -40,7 +54,7 @@ namespace dolfin
 
     /// Write to file
     static void write(const MeshFunction<int>& mf, std::ostream& outfile, uint indentation_level=0, bool write_mesh=true);
-    static void write(const MeshFunction<uint>& mf, std::ostream& outfile, uint indentation_level=0, bool write_mesh=true);
+    static void write(const MeshFunction<unsigned int>& mf, std::ostream& outfile, uint indentation_level=0, bool write_mesh=true);
     static void write(const MeshFunction<double>& mf, std::ostream& outfile, uint indentation_level=0, bool write_mesh=true);
 
   private:
