@@ -1,9 +1,24 @@
-// Copyright (C) 2008 Kent-Andre Mardal.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2008 Kent-Andre Mardal
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells, 2009.
+// Modified by Anders Logg, 2011.
 //
-// Last changed: 2010-04-19
+// Last changed: 2011-03-24
 
 #ifdef HAS_TRILINOS
 
@@ -40,6 +55,7 @@ const std::map<std::string, int> EpetraKrylovSolver::methods
                               ("gmres",    AZ_gmres)
                               ("tfqmr",    AZ_tfqmr)
                               ("bicgstab", AZ_bicgstab);
+
 //-----------------------------------------------------------------------------
 Parameters EpetraKrylovSolver::default_parameters()
 {
@@ -101,9 +117,17 @@ void EpetraKrylovSolver::set_operators(const GenericMatrix& A,
   assert(this->P);
 }
 //-----------------------------------------------------------------------------
+const GenericMatrix& EpetraKrylovSolver::get_operator() const
+{
+  if (!A)
+    error("Operator for linear solver has not been set.");
+  return *A;
+}
+//-----------------------------------------------------------------------------
 dolfin::uint EpetraKrylovSolver::solve(GenericVector& x,
                                        const GenericVector& b)
 {
+  check_dimensions(get_operator(), x, b);
   return solve(x.down_cast<EpetraVector>(), b.down_cast<EpetraVector>());
 }
 //-----------------------------------------------------------------------------
@@ -121,7 +145,7 @@ dolfin::uint EpetraKrylovSolver::solve(EpetraVector& x, const EpetraVector& b)
 
   // Write a message
   if (parameters["report"])
-    info(PROGRESS, "Solving linear system of size %d x %d (Epetra Krylov solver).", M, N);
+    log(PROGRESS, "Solving linear system of size %d x %d (Epetra Krylov solver).", M, N);
 
   // Reinitialize solution vector if necessary
   if (x.size() != M)
@@ -183,6 +207,7 @@ dolfin::uint EpetraKrylovSolver::solve(EpetraVector& x, const EpetraVector& b)
 dolfin::uint EpetraKrylovSolver::solve(const GenericMatrix& A, GenericVector& x,
                                        const GenericVector& b)
 {
+  check_dimensions(A, x, b);
   return solve(A.down_cast<EpetraMatrix>(), x.down_cast<EpetraVector>(),
                b.down_cast<EpetraVector>());
 }
