@@ -1,5 +1,19 @@
-// Copyright (C) 2008 Martin Sandve Alnes, Kent-Andre Mardal and Johannes Ring.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2008 Martin Sandve Alnes, Kent-Andre Mardal and Johannes Ring
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Anders Logg, 2008.
 // Modified by Garth N. Wells, 2008-2010.
@@ -151,10 +165,15 @@ EpetraMatrix* EpetraMatrix::copy() const
 //-----------------------------------------------------------------------------
 dolfin::uint EpetraMatrix::size(uint dim) const
 {
-  assert(A);
-  const int M = A->NumGlobalRows();
-  const int N = A->NumGlobalCols();
-  return (dim == 0 ? M : N);
+  assert(dim < 2);
+  if (A)
+  {
+    const int M = A->NumGlobalRows();
+    const int N = A->NumGlobalCols();
+    return (dim == 0 ? M : N);
+  }
+  else
+    return 0;
 }
 //-----------------------------------------------------------------------------
 std::pair<dolfin::uint, dolfin::uint> EpetraMatrix::local_range(uint dim) const
