@@ -1,10 +1,24 @@
-// Copyright (C) 2008 Martin Sandve Alnes, Kent-Andre Mardal and Johannes Ring.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2008 Martin Sandve Alnes, Kent-Andre Mardal and Johannes Ring
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells, 2008-2010.
 //
 // First added:  2008-04-21
-// Last changed: 2011-01-14
+// Last changed: 2011-05-11
 
 #ifdef HAS_TRILINOS
 
@@ -17,7 +31,7 @@
 #include <Epetra_FEVector.h>
 #include <Epetra_Export.h>
 #include <Epetra_Import.h>
-#include <Epetra_Map.h>
+#include <Epetra_BlockMap.h>
 #include <Epetra_MultiVector.h>
 #include <Epetra_MpiComm.h>
 #include <Epetra_SerialComm.h>
@@ -53,7 +67,7 @@ EpetraVector::EpetraVector(boost::shared_ptr<Epetra_FEVector> x) : x(x)
   // Do nothing
 }
 //-----------------------------------------------------------------------------
-EpetraVector::EpetraVector(const Epetra_Map& map)
+EpetraVector::EpetraVector(const Epetra_BlockMap& map)
 {
   x.reset(new Epetra_FEVector(map));
 }
@@ -87,7 +101,7 @@ void EpetraVector::resize(uint N)
     resize(range, ghost_indices);
   }
   else
-    error("Epetra vector type unkown.");
+    error("Epetra vector type unknown.");
 }
 //-----------------------------------------------------------------------------
 void EpetraVector::resize(std::pair<uint, uint> range)
@@ -106,7 +120,7 @@ void EpetraVector::resize(std::pair<uint, uint> range,
   ghost_global_to_local.clear();
 
   // Pointer to Epetra map
-  boost::scoped_ptr<Epetra_Map> epetra_map;
+  boost::scoped_ptr<Epetra_BlockMap> epetra_map;
 
   // Epetra factory and serial communicator
   const EpetraFactory& f = EpetraFactory::instance();
@@ -123,13 +137,13 @@ void EpetraVector::resize(std::pair<uint, uint> range,
       error("Serial EpetraVectors do not suppprt ghost points.");
 
     // Create map
-    epetra_map.reset(new Epetra_Map(-1, local_size, 0, serial_comm));
+    epetra_map.reset(new Epetra_BlockMap(-1, local_size, 1, 0, serial_comm));
   }
   else
   {
     // Create map
     Epetra_MpiComm mpi_comm = f.get_mpi_comm();
-    epetra_map.reset(new Epetra_Map(-1, local_size, 0, mpi_comm));
+    epetra_map.reset(new Epetra_BlockMap(-1, local_size, 1, 0, mpi_comm));
 
     // Build global-to-local map for ghost indices
     for (uint i = 0; i < ghost_indices.size(); ++i)
@@ -142,8 +156,8 @@ void EpetraVector::resize(std::pair<uint, uint> range,
   // Create local ghost vector
   const int num_ghost_entries = ghost_indices.size();
   const int* ghost_entries = reinterpret_cast<const int*>(&ghost_indices[0]);
-  Epetra_Map ghost_map(num_ghost_entries, num_ghost_entries,
-                       ghost_entries, 0, serial_comm);
+  Epetra_BlockMap ghost_map(num_ghost_entries, num_ghost_entries,
+                            ghost_entries, 1, 0, serial_comm);
   x_ghost.reset(new Epetra_Vector(ghost_map));
 }
 //-----------------------------------------------------------------------------
@@ -209,7 +223,7 @@ void EpetraVector::apply(std::string mode)
 
     // Create map for y
     const int* _non_local_indices = reinterpret_cast<const int*>(&non_local_indices[0]);
-    Epetra_Map target_map(-1, non_local_indices.size(), _non_local_indices, 0, mpi_comm);
+    Epetra_BlockMap target_map(-1, non_local_indices.size(), _non_local_indices, 1, 0, mpi_comm);
 
     // Create vector y (view of non_local_values)
     Epetra_Vector y(View, target_map, &non_local_values[0]);
@@ -384,7 +398,7 @@ void EpetraVector::gather(GenericVector& y,
 
   // Create map for y
   const int* _indices = reinterpret_cast<const int*>(indices.data().get());
-  Epetra_Map target_map(indices.size(), indices.size(), _indices, 0, serial_comm);
+  Epetra_BlockMap target_map(indices.size(), indices.size(), _indices, 1, 0, serial_comm);
 
   // Reset vector y
   _y.reset(target_map);
@@ -415,7 +429,7 @@ void EpetraVector::gather(Array<double>& x, const Array<uint>& indices) const
     x[i] = (_y)[0][i];
 }
 //-----------------------------------------------------------------------------
-void EpetraVector::reset(const Epetra_Map& map)
+void EpetraVector::reset(const Epetra_BlockMap& map)
 {
   // Clear ghost data
   x_ghost.reset();
