@@ -1,8 +1,22 @@
-// Copyright (C) 2010 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2010 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2010-02-23
-// Last changed: 2010-04-22
+// Last changed: 2011-03-17
 
 #include <boost/scoped_array.hpp>
 #include <dolfin/common/constants.h>
@@ -34,7 +48,7 @@ void GenericMatrix::ident_zeros()
   }
 
   // Write a message
-  info("Found %d zero row(s), inserting ones on the diagonal.", zero_rows.size());
+  log(TRACE, "Found %d zero row(s), inserting ones on the diagonal.", zero_rows.size());
 
   // Insert one on the diagonal for rows with only zeros. Note that we
   // are not calling ident() since that fails in PETSc if nothing
