@@ -1,5 +1,19 @@
-// Copyright (C) 2006-2010 Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2006-2010 Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Anders Logg, 2006-2010.
 // Modified by Kent-Andre Mardal, 2008.
@@ -167,9 +181,8 @@ namespace dolfin
     /// Return sum of vector
     virtual double sum() const = 0;
 
-    /// Return sum of selected rows in vector. Repeated entries only summed once.
-    virtual double sum(const Array<uint>& rows) const
-    { error("GenericVector::sum(const Array<uint>& rows) not implemented by backend"); return 0.0; }
+    /// Return sum of selected rows in vector. Repeated entries are only summed once.
+    virtual double sum(const Array<uint>& rows) const = 0;
 
     /// Multiply vector by given number
     virtual const GenericVector& operator*= (double a) = 0;
