@@ -1,11 +1,25 @@
-// Copyright (C) 2008-2009 Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2008-2009 Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Dag Lindbo, 2008.
 // Modified by Anders Logg, 2008.
 //
 // First added:  2008-07-16
-// Last changed: 2009-09-08
+// Last changed: 2011-03-28
 
 #ifdef HAS_MTL4
 
@@ -45,6 +59,9 @@ namespace dolfin
     /// Set operator (matrix) and preconditioner matrix
     void set_operators(const GenericMatrix& A, const GenericMatrix& P);
 
+    /// Get operator (matrix)
+    const GenericMatrix& get_operator() const;
+
     /// Solve linear system Ax = b and return number of iterations
     uint solve(GenericVector& x, const GenericVector& b);
 
@@ -62,7 +79,10 @@ namespace dolfin
 
   private:
 
-    /// Operator (the matrix)
+    /// Operator (the matrix) as GenericMatrix
+    boost::shared_ptr<const GenericMatrix> AA;
+
+    /// Operator (the matrix) as MTL4Matrix
     boost::shared_ptr<const MTL4Matrix> A;
 
     /// Matrix used to construct the preconditoner
