@@ -1,11 +1,25 @@
-// Copyright (C) 2008 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2008 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Johan Hake, 2010.
 // Modified by Garth N. Wells, 2010.
 //
 // First added:  2008-05-10
-// Last changed: 2010-07-16
+// Last changed: 2011-03-24
 
 #include "KrylovSolver.h"
 #include "LUSolver.h"
@@ -48,10 +62,18 @@ void LinearSolver::set_operators(const GenericMatrix& A, const GenericMatrix& P)
   solver->set_operators(A, P);
 }
 //-----------------------------------------------------------------------------
+const GenericMatrix& LinearSolver::get_operator() const
+{
+  assert(solver);
+  return solver->get_operator();
+}
+//-----------------------------------------------------------------------------
 dolfin::uint LinearSolver::solve(const GenericMatrix& A, GenericVector& x,
                                  const GenericVector& b)
 {
   assert(solver);
+  check_dimensions(A, x, b);
+
   solver->parameters.update(parameters);
   return solver->solve(A, x, b);
 }
@@ -59,8 +81,9 @@ dolfin::uint LinearSolver::solve(const GenericMatrix& A, GenericVector& x,
 dolfin::uint LinearSolver::solve(GenericVector& x, const GenericVector& b)
 {
   assert(solver);
+  check_dimensions(get_operator(), x, b);
+
   solver->parameters.update(parameters);
   return solver->solve(x, b);
 }
 //-----------------------------------------------------------------------------
-
