@@ -1,11 +1,25 @@
-// Copyright (C) 2004-2009 Anders Logg and Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2004-2009 Anders Logg and Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells, 2006-2010.
 // Modified by Ola Skavhaug 2008.
 //
 // First added:  2004-06-19
-// Last changed: 2010-07-16
+// Last changed: 2011-03-24
 
 #ifndef __LINEAR_SOLVER_H
 #define __LINEAR_SOLVER_H
@@ -41,6 +55,9 @@ namespace dolfin
     /// Set the operator (matrix) and preconitioner matrix
     void set_operators(const GenericMatrix& A, const GenericMatrix& P);
 
+    /// Get the operator (matrix)
+    const GenericMatrix& get_operator() const;
+
     /// Solve linear system Ax = b
     uint solve(const GenericMatrix& A, GenericVector& x, const GenericVector& b);
 
