@@ -1,11 +1,25 @@
-// Copyright (C) 2005-2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2005-2009 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells, 2009-2010.
 // Modified by Niclas Jansson, 2009.
 //
 // First added:  2005
-// Last changed: 2010-04-05
+// Last changed: 2011-03-24
 
 #ifdef HAS_PETSC
 
@@ -126,10 +140,18 @@ void PETScLUSolver::set_operator(const PETScMatrix& A)
   assert(this->A);
 }
 //-----------------------------------------------------------------------------
+const GenericMatrix& PETScLUSolver::get_operator() const
+{
+  if (!A)
+    error("Operator for linear solver has not been set.");
+  return *A;
+}
+//-----------------------------------------------------------------------------
 dolfin::uint PETScLUSolver::solve(GenericVector& x, const GenericVector& b)
 {
   assert(_ksp);
   assert(A);
+  check_dimensions(get_operator(), x, b);
 
   // Downcast matrix and vectors
   const PETScVector& _b = b.down_cast<PETScVector>();
@@ -173,6 +195,7 @@ dolfin::uint PETScLUSolver::solve(GenericVector& x, const GenericVector& b)
 dolfin::uint PETScLUSolver::solve(const GenericMatrix& A, GenericVector& x,
                                   const GenericVector& b)
 {
+  check_dimensions(A, x, b);
   return solve(A.down_cast<PETScMatrix>(), x.down_cast<PETScVector>(),
                b.down_cast<PETScVector>());
 }
@@ -317,8 +340,8 @@ void PETScLUSolver::pre_report(const PETScMatrix& A) const
 
   if (report && dolfin::MPI::process_number() == 0)
   {
-    info(PROGRESS, "Solving linear system of size %d x %d (PETSc LU solver, %s).",
-         A.size(0), A.size(1), solver_type);
+    log(PROGRESS, "Solving linear system of size %d x %d (PETSc LU solver, %s).",
+        A.size(0), A.size(1), solver_type);
   }
 }
 //-----------------------------------------------------------------------------
