@@ -1,11 +1,26 @@
-// Copyright (C) 2004-2007 Johan Hoffman, Johan Jansson and Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2004-2007 Johan Hoffman, Johan Jansson and Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells 2005-2010.
 // Modified by Martin Sandve Alnes 2008
+// Modified by Johannes Ring, 2011.
 //
 // First added:  2004
-// Last changed: 2011-01-14
+// Last changed: 2011-05-11
 
 #ifdef HAS_PETSC
 
@@ -47,7 +62,7 @@ const std::map<std::string, NormType> PETScVector::norm_types
 PETScVector::PETScVector(std::string type)
 {
   if (type != "global" && type != "local")
-    error("PETSc vector type unkown.");
+    error("PETSc vector type unknown.");
 
   // Empty ghost indices vector
   const std::vector<uint> ghost_indices;
