@@ -1,12 +1,26 @@
-// Copyright (C) 2005-2011 Garth N. Wells.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2005-2011 Garth N. Wells
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Ola Skavhaug, 2008.
 // Modified by Anders Logg, 2008-2009.
 // Modified by Marie Rognes, 2009.
 //
 // First added:  2005-08-31
-// Last changed: 2011-02-02
+// Last changed: 2011-03-17
 
 #ifdef HAS_SLEPC
 
@@ -139,8 +153,8 @@ void SLEPcEigenSolver::solve(uint n)
 
   const EPSType eps_type = 0;
   EPSGetType(eps, &eps_type);
-  info(PROGRESS, "Eigenvalue solver (%s) converged in %d iterations.",
-       eps_type, num_iterations);
+  log(PROGRESS, "Eigenvalue solver (%s) converged in %d iterations.",
+      eps_type, num_iterations);
 }
 //-----------------------------------------------------------------------------
 void SLEPcEigenSolver::get_eigenvalue(double& lr, double& lc) const
