@@ -1,12 +1,26 @@
-// Copyright (C) 2003-2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2003-2011 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Thanks to Jim Tilander for many helpful hints.
 //
 // Modified by Ola Skavhaug, 2007, 2009.
 //
 // First added:  2003-03-13
-// Last changed: 2009-07-02
+// Last changed: 2011-04-11
 
 #ifndef __LOGGER_H
 #define __LOGGER_H
@@ -30,10 +44,10 @@ namespace dolfin
     ~Logger();
 
     /// Print message
-    void info(std::string msg, int log_level = INFO) const;
+    void log(std::string msg, int log_level=INFO) const;
 
     /// Print underlined message
-    void info_underline(std::string msg, int log_level = INFO) const;
+    void log_underline(std::string msg, int log_level=INFO) const;
 
     /// Print warning
     void warning(std::string msg) const;
@@ -42,7 +56,7 @@ namespace dolfin
     void error(std::string msg) const;
 
     /// Begin task (increase indentation level)
-    void begin(std::string msg, int log_level = PROGRESS);
+    void begin(std::string msg, int log_level=INFO);
 
     /// End task (decrease indentation level)
     void end();
@@ -57,7 +71,7 @@ namespace dolfin
     std::ostream& get_output_stream() { return *logstream; }
 
     /// Turn logging on or off
-    void logging(bool active);
+    void set_log_active(bool active);
 
     /// Return true iff logging is active
     inline bool is_active() { return active; }
