@@ -1,5 +1,19 @@
-// Copyright (C) 2003-2010 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2003-2010 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Thanks to Jim Tilander for many helpful hints.
 //
@@ -7,7 +21,7 @@
 // Modified by Ola Skavhaug, 2009.
 //
 // First added:  2003-03-14
-// Last changed: 2010-06-28
+// Last changed: 2011-04-07
 
 #include <dolfin/common/constants.h>
 #include <dolfin/common/timing.h>
@@ -35,7 +49,8 @@ Progress::Progress(std::string title, unsigned int n)
 }
 //-----------------------------------------------------------------------------
 Progress::Progress(std::string title)
-  : title(title), n(0), i(0), p_step(0.1), t_step(0.5), p(0), t(0),
+  : title(title), n(0), i(0), p_step(0.1), t_step(0.5), c_step(1),
+    p(0), t(0), tc(0),
     always(false), finished(false), displayed(false), counter(0)
 {
   // LogManager::logger.progress(title, 0.0);
