@@ -1,5 +1,19 @@
-// Copyright (C) 2003-2005 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2003-2005 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2003-06-12
 // Last changed: 2009-09-08
@@ -7,7 +21,7 @@
 #ifndef __LAGRANGE_H
 #define __LAGRANGE_H
 
-#include <dolfin/log/dolfin_log.h>
+#include <dolfin/log/Event.h>
 #include <dolfin/common/types.h>
 #include <dolfin/common/real.h>
 #include <dolfin/common/Variable.h>
@@ -22,10 +36,14 @@ namespace dolfin
   ///   p.set(0, 0.0);
   ///   p.set(1, 1.0);
   ///
+  /// It is the callers reponsibility that the points are distinct.
+  ///
   /// This creates a Lagrange polynomial (actually two Lagrange polynomials):
   ///
   ///   p(0,x) = 1 - x   (one at x = 0, zero at x = 1)
   ///   p(1,x) = x       (zero at x = 0, one at x = 1)
+  ///
+
 
   class Lagrange : public Variable
   {
@@ -67,15 +85,20 @@ namespace dolfin
     /// Return informal string representation (pretty-print)
     std::string str(bool verbose) const;
 
-  private:
-
+  private:    
     void init();
 
     unsigned int q;
     unsigned int n;
+
+    // Counts the number of time set has been called to determine when
+    // init should be called
+    uint counter;
+
     real* points;
     real* constants;
 
+    Event instability_detected;
   };
 
 }
