@@ -1,5 +1,19 @@
-// Copyright (C) 2006-2010 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2006-2010 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Johan Hoffman 2006.
 // Modified by Andre Massing 2009.
@@ -66,11 +80,11 @@ namespace dolfin
     { return _mesh->type().facet_area(*this, facet); }
 
     /// Order entities locally
-    void order(MeshFunction<uint>* global_vertex_indices)
+    void order(const MeshFunction<uint>* global_vertex_indices)
     { _mesh->type().order(*this, global_vertex_indices); }
 
     /// Check if entities are ordered
-    bool ordered(MeshFunction<uint>* global_vertex_indices)
+    bool ordered(const MeshFunction<uint>* global_vertex_indices) const
     { return _mesh->type().ordered(*this, global_vertex_indices); }
 
   };
