@@ -1,5 +1,19 @@
-// Copyright (C) 2006-2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2006-2009 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Kristoffer Selim, 2008.
 // Modified by Andre Massing, 2010.
@@ -9,15 +23,15 @@
 
 #include <algorithm>
 #include <dolfin/log/dolfin_log.h>
-#include "PointCell.h"
-#include "IntervalCell.h"
-#include "TriangleCell.h"
-#include "TetrahedronCell.h"
-#include "Vertex.h"
-#include "CellType.h"
 #include "Cell.h"
-#include "Point.h"
+#include "CellType.h"
+#include "IntervalCell.h"
 #include "MeshFunction.h"
+#include "Point.h"
+#include "PointCell.h"
+#include "TetrahedronCell.h"
+#include "TriangleCell.h"
+#include "Vertex.h"
 
 using namespace dolfin;
 
@@ -29,11 +43,11 @@ namespace dolfin
   {
   public:
 
-    GlobalSort(const MeshFunction<uint>* global_vertex_indices) : g(global_vertex_indices) {}
+    GlobalSort(const MeshFunction<uint>& global_vertex_indices) : g(global_vertex_indices) {}
 
-    bool operator() (const uint& l, const uint& r) { return (*g)[l] < (*g)[r]; }
+    bool operator() (const uint& l, const uint& r) { return g[l] < g[r]; }
 
-    const MeshFunction<uint>* g;
+    const MeshFunction<uint>& g;
 
   };
 
@@ -109,7 +123,7 @@ std::string CellType::type2string(Type type)
 }
 //-----------------------------------------------------------------------------
 bool CellType::ordered(const Cell& cell,
-                       MeshFunction<uint>* global_vertex_indices) const
+                       const MeshFunction<uint>* global_vertex_indices) const
 {
   // Get mesh topology
   const MeshTopology& topology = cell.mesh().topology();
@@ -168,7 +182,7 @@ void CellType::sort_entities(uint num_vertices,
   // Two cases here, either sort vertices directly (when running in serial)
   // or sort based on the global indices (when running in parallel)
 
-  if (global_vertex_indices == 0)
+  if (!global_vertex_indices)
   {
     // Serial case, just sort
     std::sort(vertices, vertices + num_vertices);
@@ -176,7 +190,7 @@ void CellType::sort_entities(uint num_vertices,
   else
   {
     // Parallel case, sort on global indices
-    GlobalSort global_sort(global_vertex_indices);
+    GlobalSort global_sort(*global_vertex_indices);
     std::sort(vertices, vertices + num_vertices, global_sort);
   }
 }
@@ -187,7 +201,7 @@ bool CellType::increasing(uint num_vertices, const uint* vertices,
   // Two cases here, either check vertices directly (when running in serial)
   // or check based on the global indices (when running in parallel)
 
-  if (global_vertex_indices == 0)
+  if (!global_vertex_indices)
   {
     for (uint v = 1; v < num_vertices; v++)
       if (vertices[v - 1] >= vertices[v])
@@ -196,8 +210,7 @@ bool CellType::increasing(uint num_vertices, const uint* vertices,
   else
   {
     for (uint v = 1; v < num_vertices; v++)
-      if ((*global_vertex_indices)[vertices[v - 1]] >=
-          (*global_vertex_indices)[vertices[v]])
+      if ((*global_vertex_indices)[vertices[v - 1]] >= (*global_vertex_indices)[vertices[v]])
         return false;
   }
 
@@ -249,7 +262,7 @@ bool CellType::increasing(uint n0, const uint* v0,
       }
     }
 
-  if (!incident)
+    if (!incident)
       w1[k++] = v;
   }
   assert(k == num_non_incident);
@@ -257,7 +270,7 @@ bool CellType::increasing(uint n0, const uint* v0,
   // Compare lexicographic ordering of w0 and w1
   for (uint k = 0; k < num_non_incident; k++)
   {
-    if (global_vertex_indices == 0)
+    if (!global_vertex_indices)
     {
       if (w0[k] < w1[k])
         return true;
