@@ -1,11 +1,25 @@
-// Copyright (C) 2006-2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2006-2009 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Kristoffer Selim, 2008.
 // Modified by Andre Massing, 2009-2010.
 //
 // First added:  2006-06-05
-// Last changed: 2010-02-03
+// Last changed: 2011-03-17
 
 #ifndef __CELL_TYPE_H
 #define __CELL_TYPE_H
@@ -53,10 +67,10 @@ namespace dolfin
     static std::string type2string(Type type);
 
     /// Return type of cell
-    inline Type cell_type() const { return _cell_type; }
+    Type cell_type() const { return _cell_type; }
 
     /// Return type of cell for facets
-    inline Type facet_type() const { return _facet_type; }
+    Type facet_type() const { return _facet_type; }
 
     /// Return topological dimension of cell
     virtual uint dim() const = 0;
@@ -74,7 +88,8 @@ namespace dolfin
     virtual void create_entities(uint** e, uint dim, const uint* v) const = 0;
 
     /// Refine cell uniformly
-    virtual void refine_cell(Cell& cell, MeshEditor& editor, uint& current_cell) const = 0;
+    virtual void refine_cell(Cell& cell, MeshEditor& editor,
+                             uint& current_cell) const = 0;
 
     /// Compute (generalized) volume of mesh entity
     virtual double volume(const MeshEntity& entity) const = 0;
@@ -95,10 +110,12 @@ namespace dolfin
     // FIXME: implementation for all cell types, just as we have for ordered()
 
     /// Order entities locally
-    virtual void order(Cell& cell, const MeshFunction<uint>* global_vertex_indices) const = 0;
+    virtual void order(Cell& cell,
+                    const MeshFunction<uint>* global_vertex_indices) const = 0;
 
     /// Check if entities are ordered
-    bool ordered(const Cell& cell, MeshFunction<uint>* global_vertex_indices) const;
+    bool ordered(const Cell& cell,
+                 const MeshFunction<uint>* global_vertex_indices) const;
 
     /// Return description of cell type
     virtual std::string description(bool plural) const = 0;
