@@ -1,5 +1,19 @@
-// Copyright (C) 2006-2011 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2006-2011 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Johan Hoffman, 2007.
 // Modified by Magnus Vikstrøm, 2007.
@@ -9,7 +23,7 @@
 // Modified by Andre Massing, 2009-2010.
 //
 // First added:  2006-05-08
-// Last changed: 2011-02-07
+// Last changed: 2011-04-13
 
 #ifndef __MESH_H
 #define __MESH_H
@@ -35,9 +49,9 @@ namespace dolfin
   class Function;
   class MeshEntity;
   template <class T> class MeshFunction;
+  class ParallelData;
   class SubDomain;
   class XMLMesh;
-  class ParallelData;
 
   /// A _Mesh_ consists of a set of connected and numbered mesh entities.
   ///
@@ -335,7 +349,7 @@ namespace dolfin
     /// renumbered to improve the locality within each color. It is
     /// assumed that the mesh has already been colored and that only
     /// cell-vertex connectivity exists as part of the mesh.
-    void renumber_by_color();
+    Mesh renumber_by_color() const;
 
     /// Check if mesh is ordered according to the UFC numbering convention.
     ///
@@ -407,7 +421,7 @@ namespace dolfin
 
     /// Color the cells of the mesh such that no two neighboring cells
     /// share the same color. A colored mesh keeps a
-    /// CellFunction<uint> named "cell colors" as mesh data which
+    /// CellFunction<unsigned int> named "cell colors" as mesh data which
     /// holds the colors of the mesh.
     ///
     /// *Arguments*
@@ -417,24 +431,24 @@ namespace dolfin
     ///         "facet".
     ///
     /// *Returns*
-    ///     MeshFunction<uint>
+    ///     MeshFunction<unsigned int>
     ///         The colors as a mesh function over the cells of the mesh.
-    const MeshFunction<uint>& color(std::string coloring_type) const;
+    const MeshFunction<unsigned int>& color(std::string coloring_type) const;
 
     /// Color the cells of the mesh such that no two neighboring cells
     /// share the same color. A colored mesh keeps a
-    /// CellFunction<uint> named "cell colors" as mesh data which
+    /// CellFunction<unsigned int> named "cell colors" as mesh data which
     /// holds the colors of the mesh.
     ///
     /// *Arguments*
-    ///     coloring_type (std::vector<uint>)
+    ///     coloring_type (std::vector<unsigned int>)
     ///         Coloring type given as list of topological dimensions,
     ///         specifying what relation makes two mesh entinties neighbors.
     ///
     /// *Returns*
-    ///     MeshFunction<uint>
+    ///     MeshFunction<unsigned int>
     ///         The colors as a mesh function over entities of the mesh.
-    const MeshFunction<uint>& color(std::vector<uint> coloring_type) const;
+    const MeshFunction<unsigned int>& color(std::vector<unsigned int> coloring_type) const;
 
     /// Compute all ids of all cells which are intersected by the
     /// given point.
@@ -559,7 +573,7 @@ namespace dolfin
     ///     std::pair<_Point_, uint>
     ///         The point inside the mesh and the corresponding cell
     ///         index which is closest to the point query.
-    std::pair<Point,dolfin::uint> closest_point_and_cell(const Point& point) const;
+    std::pair<Point, dolfin::uint> closest_point_and_cell(const Point& point) const;
 
     /// Compute minimum cell diameter.
     ///
@@ -614,7 +628,6 @@ namespace dolfin
     friend class MeshEditor;
     friend class TopologyComputation;
     friend class MeshOrdering;
-    friend class AdaptiveObjects;
     friend class BinaryFile;
 
     // Mesh topology
