@@ -1,5 +1,19 @@
-// Copyright (C) 2008-2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2008-2009 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Niclas Jansson, 2008.
 //
@@ -15,8 +29,8 @@
 
 using namespace dolfin;
 
-typedef std::map<std::string, MeshFunction<dolfin::uint>*>::iterator mf_iterator;
-typedef std::map<std::string, MeshFunction<dolfin::uint>*>::const_iterator mf_const_iterator;
+typedef std::map<std::string, boost::shared_ptr<MeshFunction<unsigned int> > >::iterator mf_iterator;
+typedef std::map<std::string, boost::shared_ptr<MeshFunction<unsigned int> > >::const_iterator mf_const_iterator;
 
 typedef std::map<std::string, std::vector<dolfin::uint>*>::iterator a_iterator;
 typedef std::map<std::string, std::vector<dolfin::uint>*>::const_iterator a_const_iterator;
@@ -46,7 +60,7 @@ const MeshData& MeshData::operator= (const MeshData& data)
   // Copy MeshFunctions
   for (mf_const_iterator it = data.mesh_functions.begin(); it != data.mesh_functions.end(); ++it)
   {
-    MeshFunction<uint> *f = create_mesh_function(it->first, it->second->dim());
+    boost::shared_ptr<MeshFunction<unsigned int> > f = create_mesh_function(it->first, it->second->dim());
     *f = *it->second;
   }
 
@@ -76,8 +90,6 @@ const MeshData& MeshData::operator= (const MeshData& data)
 //-----------------------------------------------------------------------------
 void MeshData::clear()
 {
-  for (mf_iterator it = mesh_functions.begin(); it != mesh_functions.end(); ++it)
-    delete it->second;
   mesh_functions.clear();
 
   for (a_iterator it = arrays.begin(); it != arrays.end(); ++it)
@@ -91,12 +103,9 @@ void MeshData::clear()
   for (mvec_iterator it = vector_mappings.begin(); it != vector_mappings.end(); ++it)
     delete it->second;
   vector_mappings.clear();
-
-  // Remove coloring data
-  coloring.clear();
 }
 //-----------------------------------------------------------------------------
-MeshFunction<dolfin::uint>* MeshData::create_mesh_function(std::string name)
+boost::shared_ptr<MeshFunction<unsigned int> > MeshData::create_mesh_function(std::string name)
 {
   // Check if data already exists
   mf_iterator it = mesh_functions.find(name);
@@ -107,7 +116,7 @@ MeshFunction<dolfin::uint>* MeshData::create_mesh_function(std::string name)
   }
 
   // Create new data
-  MeshFunction<uint>* f = new MeshFunction<uint>(mesh);
+  boost::shared_ptr<MeshFunction<unsigned int> > f(new MeshFunction<uint>(mesh));
   assert(f);
 
   // Add to map
@@ -116,9 +125,9 @@ MeshFunction<dolfin::uint>* MeshData::create_mesh_function(std::string name)
   return f;
 }
 //-----------------------------------------------------------------------------
-MeshFunction<dolfin::uint>* MeshData::create_mesh_function(std::string name, uint dim)
+boost::shared_ptr<MeshFunction<unsigned int> > MeshData::create_mesh_function(std::string name, uint dim)
 {
-  MeshFunction<uint>* f = create_mesh_function(name);
+  boost::shared_ptr<MeshFunction<unsigned int> > f = create_mesh_function(name);
   f->init(dim);
 
   return f;
@@ -187,12 +196,12 @@ std::map<dolfin::uint, std::vector<dolfin::uint> >* MeshData::create_vector_mapp
   return m;
 }
 //-----------------------------------------------------------------------------
-MeshFunction<dolfin::uint>* MeshData::mesh_function(const std::string name) const
+boost::shared_ptr<MeshFunction<unsigned int> > MeshData::mesh_function(const std::string name) const
 {
   // Check if data exists
   mf_const_iterator it = mesh_functions.find(name);
   if (it == mesh_functions.end())
-    return 0;
+    return boost::shared_ptr<MeshFunction<unsigned int> >();
 
   return it->second;
 }
@@ -236,14 +245,9 @@ void MeshData::erase_mesh_function(const std::string name)
 {
   mf_iterator it = mesh_functions.find(name);
   if (it != mesh_functions.end())
-  {
-    delete it->second;
     mesh_functions.erase(it);
-  }
   else
-  {
     warning("Mesh data named \"%s\" doesn't exist.", name.c_str());
-  }
 }
 //-----------------------------------------------------------------------------
 void MeshData::erase_array(const std::string name)
