@@ -1,11 +1,25 @@
-// Copyright (C) 2008-2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2008-2009 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Niclas Jansson, 2008.
 // Modified by Garth N. Wells, 2011.
 //
 // First added:  2008-05-19
-// Last changed: 2011-01-17
+// Last changed: 2011-03-10
 
 #ifndef __MESH_DATA_H
 #define __MESH_DATA_H
@@ -14,6 +28,7 @@
 #include <string>
 #include <utility>
 #include <vector>
+#include <boost/shared_ptr.hpp>
 
 #include <dolfin/common/types.h>
 #include <dolfin/common/Variable.h>
@@ -24,6 +39,8 @@ namespace dolfin
   class Mesh;
   template <class T> class MeshFunction;
 
+  // FIXME: Remove space with underscore in names
+
   /// The class MeshData is a container for auxiliary mesh data,
   /// represented either as MeshFunctions over topological mesh
   /// entities, arrays or maps. Each dataset is identified by a unique
@@ -34,14 +51,16 @@ namespace dolfin
   ///
   /// Boundary indicators
   ///
-  ///   "boundary facet cells"   - Array<uint> of size num_facets
-  ///   "boundary facet numbers" - Array<uint> of size num_facets
-  ///   "boundary indicators"    - Array<uint> of size num_facets
-  ///   "material indicators"    - MeshFunction<uint> of dimension D
+  ///   "boundary_facet_cells"   - Array<uint> of size num_facets
+  ///   "boundary_facet_numbers" - Array<uint> of size num_facets
+  ///   "boundary_indicators"    - Array<uint> of size num_facets
+  ///   "material_indicators"    - MeshFunction<uint> of dimension D
   ///
-  /// Boundary indicators (alternative)
+  /// Subdomain indicators
   ///
-  ///   "exterior facet domains" - MeshFunction<uint> of dimension D - 1
+  ///   "cell_domains"           - MeshFunction<uint> of dimension D
+  ///   "interior_facet_domains" - MeshFunction<uint> of dimension D - 1
+  ///   "exterior_facet_domains" - MeshFunction<uint> of dimension D - 1
   ///
   /// Facet orientation (used for assembly over interior facets)
   ///
@@ -54,10 +73,10 @@ namespace dolfin
   ///
   /// Mesh partitioning
   ///
-  ///   "global entity indices %d" - MeshFunction<uint> of dimension 0, 1, ..., D
-  ///   "exterior facets"          - MeshFunction<uint> of dimension D - 1
-  ///   "num global entities"      - Array<uint> of size D + 1
-  ///   "overlap"                  - vector mapping
+  ///   (moved to ParallelData) "global entity indices %d" - MeshFunction<uint> of dimension 0, 1, ..., D
+  ///   (moved to ParallelData) "exterior facets"          - MeshFunction<uint> of dimension D - 1
+  ///   (moved to ParallelData) "num global entities"      - Array<uint> of size D + 1
+  ///   (moved to ParallelData) "overlap"                  - vector mapping
   ///
   /// Sub meshes
   ///
@@ -88,10 +107,10 @@ namespace dolfin
     //--- Creation of data ---
 
     /// Create MeshFunction with given name (uninitialized)
-    MeshFunction<uint>* create_mesh_function(std::string name);
+    boost::shared_ptr<MeshFunction<unsigned int> > create_mesh_function(std::string name);
 
     /// Create MeshFunction with given name and dimension
-    MeshFunction<uint>* create_mesh_function(std::string name, uint dim);
+    boost::shared_ptr<MeshFunction<unsigned int> > create_mesh_function(std::string name, uint dim);
 
     /// Create empty array (vector) with given name
     std::vector<uint>* create_array(std::string name);
@@ -108,7 +127,7 @@ namespace dolfin
     //--- Retrieval of data ---
 
     /// Return MeshFunction with given name (returning zero if data is not available)
-    MeshFunction<uint>* mesh_function(const std::string name) const;
+    boost::shared_ptr<MeshFunction<unsigned int> > mesh_function(const std::string name) const;
 
     /// Return array with given name (returning zero if data is not available)
     std::vector<uint>* array(const std::string name) const;
@@ -141,16 +160,6 @@ namespace dolfin
     /// Return informal string representation (pretty-print)
     std::string str(bool verbose) const;
 
-    //--- Coloring data ---
-
-    /// First vector is (colored entity dim - dim0 - .. -  colored entity dim).
-    /// MeshFunction stores mesh entity colors and the vector<vector> a list
-    /// of all mesh entity indices of the same color,
-    /// e.g. vector<vector>[color][i] is the index of the ith entity of
-    /// color 'color'.
-    std::map<const std::vector<uint>,
-             std::pair<MeshFunction<uint>, std::vector<std::vector<uint> > > > coloring;
-
     /// Friends
     friend class XMLFile;
     friend class XMLMeshData;
@@ -161,7 +170,7 @@ namespace dolfin
     Mesh& mesh;
 
     // A map from named mesh data to MeshFunctions
-    std::map<std::string, MeshFunction<uint>* > mesh_functions;
+    std::map<std::string, boost::shared_ptr<MeshFunction<uint> > > mesh_functions;
 
     // A map from named mesh data to vector
     std::map<std::string, std::vector<uint>* > arrays;
