@@ -1,8 +1,22 @@
-// Copyright (C) 2006-2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2006-2009 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2006-05-16
-// Last changed: 2011-02-09
+// Last changed: 2011-03-10
 
 #include <dolfin/log/dolfin_log.h>
 #include <dolfin/parameter/dolfin_parameter.h>
@@ -69,17 +83,15 @@ void MeshEditor::open(Mesh& mesh, CellType::Type type, uint tdim, uint gdim)
   mesh._topology.init(tdim);
 
   // Initialize temporary storage for local cell data
-  vertices.reserve(mesh.type().num_vertices(tdim));
-  for (uint i = 0; i < mesh.type().num_vertices(tdim); i++)
-    vertices.push_back(0);
+  vertices.resize(mesh.type().num_vertices(tdim));
+  std::fill(vertices.begin(), vertices.end(), 0);
 
   // in the future, could set a string in MeshGeometry that indicates the type of
   //      higher order mesh... for now we assume P2 triangle!
 
   // Initialize temporary storage for local higher order cell data
-  higher_order_cell_data.reserve(6); // assume P2 triangle!
-  for (uint i = 0; i < 6; i++)
-    higher_order_cell_data.push_back(0);
+  higher_order_cell_data.resize(6); // assume P2 triangle!
+  std::fill(higher_order_cell_data.begin(), higher_order_cell_data.end(), 0);
 }
 //-----------------------------------------------------------------------------
 void MeshEditor::open(Mesh& mesh, std::string type, uint tdim, uint gdim)
@@ -401,13 +413,11 @@ void MeshEditor::add_cell_common(uint c, uint tdim)
 
   // Check that the dimension matches
   if (tdim != this->tdim)
-    error("Illegal dimension for cell: %d (should be %d).",
-          tdim, this->tdim);
+    error("Illegal dimension for cell: %d (should be %d).", tdim, this->tdim);
 
   // Check value of cell index
   if (c >= num_cells)
-    error("Cell index (%d) out of range [0, %d].",
-          c, num_cells - 1);
+    error("Cell index (%d) out of range [0, %d].", c, num_cells - 1);
 
   // Check if there is room for more cells
   if (next_cell >= num_cells)
@@ -443,14 +453,19 @@ void MeshEditor::add_higher_order_cell_common(uint c, uint tdim)
 //-----------------------------------------------------------------------------
 void MeshEditor::compute_boundary_indicators()
 {
-  // Do nothing if mesh function "exterior facet domains" is present
-  if (mesh->data().mesh_function("exterior facet domains"))
+  // This function is called from close(), which lets a user of
+  // MeshEditor (such as for example VMTK) to attach MeshFunctions for
+  // boundaries before calling close() which then results in the
+  // generation of data named "exterior_facet_domains".
+
+  // Do nothing if mesh function "exterior_facet_domains" is present
+  if (mesh->data().mesh_function("exterior_facet_domains"))
     return;
 
   // Extract data for boundary indicators
-  std::vector<uint>* facet_cells   = mesh->data().array("boundary facet cells");
-  std::vector<uint>* facet_numbers = mesh->data().array("boundary facet numbers");
-  std::vector<uint>* indicators    = mesh->data().array("boundary indicators");
+  std::vector<uint>* facet_cells   = mesh->data().array("boundary_facet_cells");
+  std::vector<uint>* facet_numbers = mesh->data().array("boundary_facet_numbers");
+  std::vector<uint>* indicators    = mesh->data().array("boundary_indicators");
 
   // Do nothing if there are no indicators
   if (!indicators)
@@ -469,8 +484,8 @@ void MeshEditor::compute_boundary_indicators()
   assert(num_facets > 0);
 
   // Create mesh function "exterior_facet_domains"
-  MeshFunction<uint>* exterior_facet_domains =
-    mesh->data().create_mesh_function("exterior facet domains", D - 1);
+  boost::shared_ptr<MeshFunction<unsigned int> > exterior_facet_domains
+    = mesh->data().create_mesh_function("exterior_facet_domains", D - 1);
 
   // Initialize meshfunction to zero
   (*exterior_facet_domains) = 0;
