@@ -1,24 +1,43 @@
-// Copyright (C) 2008-2009 Niclas Jansson, Ola Skavhaug and Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2008-2009 Niclas Jansson, Ola Skavhaug and Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2008-12-01
-// Last changed: 2011-02-03
+// Last changed: 2011-03-17
 
-#include <vector>
 #include <algorithm>
+#include <iterator>
+#include <numeric>
+
 #include <dolfin/log/log.h>
 #include <dolfin/common/MPI.h>
 #include <dolfin/common/Timer.h>
 #include <dolfin/graph/ParMETIS.h>
 #include <dolfin/graph/SCOTCH.h>
 #include <dolfin/parameter/GlobalParameters.h>
+#include "BoundaryMesh.h"
+#include "Facet.h"
 #include "LocalMeshData.h"
+#include "Mesh.h"
+#include "MeshEditor.h"
+#include "MeshEntityIterator.h"
+#include "MeshFunction.h"
+#include "ParallelData.h"
 #include "Point.h"
 #include "Vertex.h"
-#include "BoundaryMesh.h"
-#include "MeshEntityIterator.h"
-#include "MeshEditor.h"
-#include "MeshFunction.h"
 #include "MeshPartitioning.h"
 
 
@@ -42,8 +61,8 @@ template<typename Map> void print_vec_map(std::ostream& ostr, Map map, const cha
 {
   for (typename Map::iterator it = map.begin(); it !=map.end(); ++it)
   {
-    print_container(ostr, (*it).first.begin(), (*it).first.end(), " ");
-    ostr << ": " << (*it).second << delimiter;
+    print_container(ostr, it->first.begin(), it->first.end(), " ");
+    ostr << ": " << it->second << delimiter;
   }
 }
 
@@ -84,12 +103,12 @@ void MeshPartitioning::partition(Mesh& mesh, LocalMeshData& mesh_data)
   distribute_cells(mesh_data, cell_partition);
 
   // Distribute vertices
-  std::map<uint, uint> glob2loc;
-  distribute_vertices(mesh_data, glob2loc);
+  std::map<uint, uint> vertex_global_to_local;
+  distribute_vertices(mesh_data, vertex_global_to_local);
   timer.stop();
 
   // Build mesh
-  build_mesh(mesh, mesh_data, glob2loc);
+  build_mesh(mesh, mesh_data, vertex_global_to_local);
 }
 //-----------------------------------------------------------------------------
 void MeshPartitioning::number_entities(const Mesh& _mesh, uint d)
@@ -104,30 +123,25 @@ void MeshPartitioning::number_entities(const Mesh& _mesh, uint d)
     error("Unable to number entities of dimension 0. Vertex indices must already exist.");
 
   // Return if global entity indices are already calculated
-  std::stringstream mesh_data_name;
-  mesh_data_name << "global entity indices " << d;
-  MeshFunction<uint>* global_entity_indices = mesh.data().mesh_function(mesh_data_name.str());
-
-  // Already computed the global entity numbers; do nothing
-  if (global_entity_indices != NULL)
+  if (mesh.parallel_data().have_global_entity_indices(d))
     return;
 
+  // Initialize entities of dimension d
+  mesh.init(d);
+
   // Get number of processes and process number
   const uint num_processes = MPI::num_processes();
   const uint process_number = MPI::process_number();
 
-  // Get global vertex indices and overlap
-  MeshFunction<uint>* global_vertex_indices = mesh.data().mesh_function("global entity indices 0");
-  std::map<uint, std::vector<uint> >* overlap = mesh.data().vector_mapping("overlap");
-  assert(global_vertex_indices);
-  assert(overlap);
+  // Get global vertex indices
+  MeshFunction<unsigned int>& global_vertex_indices = mesh.parallel_data().global_entity_indices(0);
 
-  // Sort overlap
-  for (std::map<uint, std::vector<uint> >::iterator it = (*overlap).begin(); it != (*overlap).end(); ++it)
-    std::sort((*it).second.begin(), (*it).second.end());
+  // Get shared vertices
+  std::map<uint, std::vector<uint> >& shared_vertices = mesh.parallel_data().shared_vertices();
 
-  // Initialize entities of dimension d
-  mesh.init(d);
+  // Sort shared vertices
+  for (std::map<uint, std::vector<uint> >::iterator it = shared_vertices.begin(); it != shared_vertices.end(); ++it)
+    std::sort(it->second.begin(), it->second.end());
 
   // Build entity-to-global-vertex-number information
   std::map<std::vector<uint>, uint> entities;
@@ -135,7 +149,7 @@ void MeshPartitioning::number_entities(const Mesh& _mesh, uint d)
   {
     std::vector<uint> entity;
     for (VertexIterator vertex(*e); !vertex.end(); ++vertex)
-      entity.push_back((*global_vertex_indices)[vertex->index()]);
+      entity.push_back(global_vertex_indices[vertex->index()]);
     std::sort(entity.begin(), entity.end());
     entities[entity] = e->index();
   }
@@ -157,24 +171,173 @@ void MeshPartitioning::number_entities(const Mesh& _mesh, uint d)
   std::map<std::vector<uint>, uint> ignored_entity_indices;
   std::map<std::vector<uint>, std::vector<uint> > ignored_entity_processes;
 
+  compute_preliminary_entity_ownership(entities, shared_vertices,
+                           owned_entity_indices, shared_entity_indices,
+                           shared_entity_processes, ignored_entity_indices,
+                           ignored_entity_processes);
+
+
+
+
+  // Qualify boundary entities. We need to find out if the ignored
+  // (shared with lower ranked process) entities are entities of a
+  // lower ranked process.  If not, this process becomes the lower
+  // ranked process for the entity in question, and is therefore
+  // responsible for communicating values to the higher ranked
+  // processes (if any).
+
+  compute_final_entity_ownership(owned_entity_indices, shared_entity_indices,
+                           shared_entity_processes, ignored_entity_indices,
+                           ignored_entity_processes);
+
+  /// --- Mark exterior facets
+
+  // Create mesh markers for exterior facets
+  if (d == (mesh.topology().dim() - 1))
+  {
+    MeshFunction<bool>& exterior_facets = mesh.parallel_data().exterior_facet();
+    exterior_facets.init(d);
+    mark_nonshared(entities, shared_entity_indices, ignored_entity_indices,
+                   exterior_facets);
+  }
+
+  /// ---- Offset
+
+  // Communicate number of entities to number
+  std::vector<uint> num_entities_to_number(num_processes, 0);
+  num_entities_to_number[process_number] = owned_entity_indices.size() + shared_entity_indices.size();
+  MPI::gather(num_entities_to_number);
+
+  // Compute offset
+  uint offset = std::accumulate(num_entities_to_number.begin(), num_entities_to_number.begin() + process_number, 0);
+
+  // Compute number of global entities
+  const uint num_global = std::accumulate(num_entities_to_number.begin() + process_number, num_entities_to_number.end(), offset);
+
+  /// ---- Numbering
+
+  // Store number of global entities
+  mesh.parallel_data().num_global_entities()[d] = num_global;
+
+  // Prepare list of entity numbers. Check later that nothing is -1
+  std::vector<int> entity_indices(mesh.size(d), -1);
+
+  std::map<std::vector<uint>, uint>::const_iterator it;
+
+  // Number owned entities
+  for (it = owned_entity_indices.begin();  it != owned_entity_indices.end(); ++it)
+    entity_indices[it->second] = offset++;
+
+  // Number shared entities
+  for (it = shared_entity_indices.begin(); it != shared_entity_indices.end(); ++it)
+    entity_indices[it->second] = offset++;
+
+  // Communicate indices for shared entities and get indices for ignored
+  std::vector<uint> values;
+  std::vector<uint> partition;
+  for (it = shared_entity_indices.begin(); it != shared_entity_indices.end(); ++it)
+  {
+    // Get entity index
+    const uint local_entity_index = it->second;
+    const int entity_index = entity_indices[local_entity_index];
+    assert(entity_index != -1);
+
+    // Get entity vertices (global vertex indices)
+    const std::vector<uint>& entity = it->first;
+
+    // Get entity processes (processes sharing the entity)
+    const std::vector<uint>& entity_processes = shared_entity_processes[entity];
+
+    // Prepare data for sending
+    for (uint j = 0; j < entity_processes.size(); ++j)
+    {
+      // Store interleaved: entity index, number of vertices, global vertex indices
+      values.push_back(entity_index);
+      values.push_back(entity.size());
+      values.insert(values.end(), entity.begin(), entity.end());
+      partition.insert(partition.end(), entity.size() + 2, entity_processes[j]);
+    }
+  }
+
+  // Send data
+  MPI::distribute(values, partition);
+
+  // Fill in global entity indices recieved from lower ranked processes
+  for (uint i = 0; i < values.size();)
+  {
+    const uint p = partition[i];
+    const uint global_index = values[i++];
+    const uint entity_size = values[i++];
+    std::vector<uint> entity;
+    for (uint j = 0; j < entity_size; ++j)
+      entity.push_back(values[i++]);
+
+    // Sanity check, should not receive an entity we don't need
+    if (ignored_entity_indices.find(entity) == ignored_entity_indices.end())
+    {
+      std::stringstream msg;
+      msg << "Process " << MPI::process_number() << " received illegal entity given by ";
+      print_container(msg, entity.begin(), entity.end());
+      msg << " with global index " << global_index;
+      msg << " from process " << p;
+      error(msg.str());
+    }
+
+    const uint local_entity_index = ignored_entity_indices.find(entity)->second;
+    assert(entity_indices[local_entity_index] == -1);
+    entity_indices[local_entity_index] = global_index;
+  }
+
+  // Create mesh data
+  MeshFunction<unsigned int>& global_entity_indices = mesh.parallel_data().global_entity_indices(d);
+  for (uint i = 0; i < entity_indices.size(); ++i)
+  {
+    if (entity_indices[i] < 0)
+      log(WARNING, "Missing global number for local entity (%d, %d).", d, i);
+
+    assert(entity_indices[i] >= 0);
+    assert(i < global_entity_indices.size());
+
+    global_entity_indices[i] = static_cast<uint>(entity_indices[i]);
+  }
+}
+//-----------------------------------------------------------------------------
+void MeshPartitioning::compute_preliminary_entity_ownership(const std::map<std::vector<uint>, uint>& entities,
+  const std::map<uint, std::vector<uint> >& shared_vertices,
+  std::map<std::vector<uint>, uint>& owned_entity_indices,
+  std::map<std::vector<uint>, uint>& shared_entity_indices,
+  std::map<std::vector<uint>, std::vector<uint> >& shared_entity_processes,
+  std::map<std::vector<uint>, uint>& ignored_entity_indices,
+  std::map<std::vector<uint>, std::vector<uint> >& ignored_entity_processes)
+{
+  owned_entity_indices.clear();
+  shared_entity_indices.clear();
+  shared_entity_processes.clear();
+  ignored_entity_indices.clear();
+  ignored_entity_processes.clear();
+
+  const uint process_number = MPI::process_number();
+
   // Iterate over all entities
   for (std::map<std::vector<uint>, uint>::const_iterator it = entities.begin(); it != entities.end(); ++it)
   {
-    const std::vector<uint>& entity = (*it).first;
-    const uint local_entity_index = (*it).second;
+    const std::vector<uint>& entity = it->first;
+    const uint local_entity_index = it->second;
 
     // Compute which processes entity is shared with
     std::vector<uint> entity_processes;
-    if (in_overlap(entity, *overlap))
+    if (in_overlap(entity, shared_vertices))
     {
-      std::vector<uint> intersection = (*overlap)[entity[0]];
+      std::vector<uint> intersection = shared_vertices.find(entity[0])->second;
       std::vector<uint>::iterator intersection_end = intersection.end();
 
       for (uint i = 1; i < entity.size(); ++i)
       {
         const uint v = entity[i];
-        intersection_end = std::set_intersection(intersection.begin(), intersection_end,
-                                                 (*overlap)[v].begin(), (*overlap)[v].end(), intersection.begin());
+        const std::vector<uint>& shared_vertices_v = shared_vertices.find(v)->second;
+        intersection_end = std::set_intersection(intersection.begin(),
+                                   intersection_end, shared_vertices_v.begin(),
+                                   shared_vertices_v.end(), intersection.begin());
       }
       entity_processes = std::vector<uint>(intersection.begin(), intersection_end);
     }
@@ -204,25 +367,28 @@ void MeshPartitioning::number_entities(const Mesh& _mesh, uint d)
       shared_entity_processes[entity] = entity_processes;
     }
   }
+}
+//-----------------------------------------------------------------------------
+void MeshPartitioning::compute_final_entity_ownership(std::map<std::vector<uint>, uint>& owned_entity_indices,
+          std::map<std::vector<uint>, uint>& shared_entity_indices,
+          std::map<std::vector<uint>, std::vector<uint> >& shared_entity_processes,
+          std::map<std::vector<uint>, uint>& ignored_entity_indices,
+          std::map<std::vector<uint>, std::vector<uint> >& ignored_entity_processes)
+{
+  const uint process_number = MPI::process_number();
 
-  // Qualify boundary entities. We need to find out if the ignored
-  // (shared with lower ranked process) entities are entities of a
-  // lower ranked process.  If not, this process becomes the lower
-  // ranked process for the entity in question, and is therefore
-  // responsible for communicating values to the higher ranked
-  // processes (if any).
+  std::map<std::vector<uint>, std::vector<uint> >::const_iterator it;
 
   // Communicate common entities, starting with the entities we think should be ignored
   std::vector<uint> common_entity_values;
   std::vector<uint> common_entity_partition;
-  for (std::map<std::vector<uint>, std::vector<uint> >::const_iterator it = ignored_entity_processes.begin();
-       it != ignored_entity_processes.end(); ++it)
+  for (it = ignored_entity_processes.begin(); it != ignored_entity_processes.end(); ++it)
   {
     // Get entity vertices (global vertex indices)
-    const std::vector<uint>& entity = (*it).first;
+    const std::vector<uint>& entity = it->first;
 
     // Get entity processes (processes might sharing the entity)
-    const std::vector<uint>& entity_processes = (*it).second;
+    const std::vector<uint>& entity_processes = it->second;
 
     // Prepare data for sending
     for (uint j = 0; j < entity_processes.size(); ++j)
@@ -235,14 +401,13 @@ void MeshPartitioning::number_entities(const Mesh& _mesh, uint d)
   }
 
   // Communicate common entities, add the entities we think should be shared as well
-  for (std::map<std::vector<uint>, std::vector<uint> >::const_iterator it = shared_entity_processes.begin();
-       it != shared_entity_processes.end(); ++it)
+  for (it = shared_entity_processes.begin(); it != shared_entity_processes.end(); ++it)
   {
     // Get entity vertices (global vertex indices)
-    const std::vector<uint>& entity = (*it).first;
+    const std::vector<uint>& entity = it->first;
 
     // Get entity processes (processes might sharing the entity)
-    const std::vector<uint>& entity_processes = (*it).second;
+    const std::vector<uint>& entity_processes = it->second;
 
     // Prepare data for sending
     for (uint j = 0; j < entity_processes.size(); ++j)
@@ -270,14 +435,17 @@ void MeshPartitioning::number_entities(const Mesh& _mesh, uint d)
     for (uint j = 0; j < entity_size; ++j)
       entity.push_back(common_entity_values[i++]);
 
-    // Check if it is an entity (in which case it will be in ignored or shared entities)
+    // Check if it is an entity (in which case it will be in ignored or
+    // shared entities)
     uint is_entity = 0;
-    if ((ignored_entity_indices.count(entity) > 0 ) || (shared_entity_indices.count(entity) > 0 ))
+    if (ignored_entity_indices.find(entity) != ignored_entity_indices.end()
+          || shared_entity_indices.find(entity) != shared_entity_indices.end())
     {
       is_entity = 1;
     }
 
-    // Add information about entity (whether it's actually an entity) to send to other processes
+    // Add information about entity (whether it's actually an entity) to send
+    // to other processes
     is_entity_values.push_back(entity_size);
     is_entity_partition.push_back(p);
     for (uint j = 0; j < entity_size; ++j)
@@ -289,10 +457,6 @@ void MeshPartitioning::number_entities(const Mesh& _mesh, uint d)
     is_entity_partition.push_back(p);
   }
 
-  // Clean up no longer needed data structures
-  common_entity_values.clear();
-  common_entity_partition.clear();
-
   // Send data back (list of requested entities that are really entities)
   MPI::distribute(is_entity_values, is_entity_partition);
 
@@ -313,17 +477,13 @@ void MeshPartitioning::number_entities(const Mesh& _mesh, uint d)
     }
   }
 
-  // Clean up no longer needed data structures
-  is_entity_values.clear();
-  is_entity_partition.clear();
-
   // Fix the list of entities we ignore (numbered by lower ranked process)
   std::vector<std::vector<uint> > unignore_entities;
   for (std::map<std::vector<uint>, uint>::const_iterator it = ignored_entity_indices.begin(); it != ignored_entity_indices.end(); ++it)
   {
-    const std::vector<uint> entity = (*it).first;
-    const uint local_entity_index = (*it).second;
-    if (entity_processes.count(entity) > 0)
+    const std::vector<uint> entity = it->first;
+    const uint local_entity_index = it->second;
+    if (entity_processes.find(entity) != entity_processes.end())
     {
       std::vector<uint> common_processes = entity_processes[entity];
       assert(common_processes.size() > 0);
@@ -350,20 +510,19 @@ void MeshPartitioning::number_entities(const Mesh& _mesh, uint d)
   }
 
   // Remove ignored entities that should not be ignored
-  for (uint i=0; i < unignore_entities.size(); ++i)
+  for (uint i = 0; i < unignore_entities.size(); ++i)
   {
     ignored_entity_indices.erase(unignore_entities[i]);
     ignored_entity_processes.erase(unignore_entities[i]);
   }
-  unignore_entities.clear();
 
   // Fix the list of entities we share
   std::vector<std::vector<uint> > unshare_entities;
   for (std::map<std::vector<uint>, uint>::const_iterator it = shared_entity_indices.begin(); it != shared_entity_indices.end(); ++it)
   {
-    const std::vector<uint>& entity = (*it).first;
-    const uint local_entity_index = (*it).second;
-    if (entity_processes.count(entity) == 0)
+    const std::vector<uint>& entity = it->first;
+    const uint local_entity_index = it->second;
+    if (entity_processes.find(entity) == entity_processes.end())
     {
       // Move from shared to owned
       owned_entity_indices[entity] = local_entity_index;
@@ -377,136 +536,11 @@ void MeshPartitioning::number_entities(const Mesh& _mesh, uint d)
   }
 
   // Remove shared entities that should not be shared
-  for (uint i=0; i < unshare_entities.size(); ++i)
+  for (uint i = 0; i < unshare_entities.size(); ++i)
   {
     shared_entity_indices.erase(unshare_entities[i]);
     shared_entity_processes.erase(unshare_entities[i]);
   }
-  unshare_entities.clear();
-
-  // Create mesh markers for exterior facets
-  if (d == (mesh.topology().dim() - 1))
-  {
-    mark_nonshared(entities, shared_entity_indices, ignored_entity_indices,
-                   mesh, d, "exterior facets");
-  }
-
-  // Communicate number of entities to number
-  std::vector<uint> num_entities_to_number(num_processes);
-  std::fill(num_entities_to_number.begin(), num_entities_to_number.end(), 0);
-  num_entities_to_number[process_number] = owned_entity_indices.size() + shared_entity_indices.size();
-  MPI::gather(num_entities_to_number);
-
-  // Compute offset
-  uint offset = 0;
-  for (uint i = 0; i < process_number; ++i)
-    offset += num_entities_to_number[i];
-
-  // Compute number of global entities
-  uint num_global = offset;
-  for (uint i = process_number; i < num_processes; ++i)
-    num_global += num_entities_to_number[i];
-
-  // Store number of global entities
-  std::vector<uint>* num_global_entities = mesh.data().array("num global entities");
-  assert(num_global_entities);
-  (*num_global_entities)[d] = num_global;
-
-  // Prepare list of entity numbers. Check later that nothing is -1
-  std::vector<int> entity_indices(mesh.size(d));
-  std::fill(entity_indices.begin(), entity_indices.end(), -1);
-
-  // Number owned entities
-  for (std::map<std::vector<uint>, uint>::const_iterator it = owned_entity_indices.begin();
-      it != owned_entity_indices.end(); ++it)
-  {
-    entity_indices[(*it).second] = offset++;
-  }
-
-  // Number shared entities
-  for (std::map<std::vector<uint>, uint>::const_iterator it = shared_entity_indices.begin();
-        it != shared_entity_indices.end(); ++it)
-  {
-    entity_indices[(*it).second] = offset++;
-  }
-
-  // Communicate indices for shared entities and get indices for ignored
-  std::vector<uint> values;
-  std::vector<uint> partition;
-  for (std::map<std::vector<uint>, uint>::const_iterator it = shared_entity_indices.begin();
-        it != shared_entity_indices.end(); ++it)
-  {
-    // Get entity index
-    const uint local_entity_index = (*it).second;
-    const int entity_index = entity_indices[local_entity_index];
-    assert(entity_index != -1);
-
-    // Get entity vertices (global vertex indices)
-    const std::vector<uint>& entity = (*it).first;
-
-    // Get entity processes (processes sharing the entity)
-    const std::vector<uint>& entity_processes = shared_entity_processes[entity];
-
-    // Prepare data for sending
-    for (uint j = 0; j < entity_processes.size(); ++j)
-    {
-      // Store interleaved: entity index, number of vertices, global vertex indices
-      values.push_back(entity_index);
-      values.push_back(entity.size());
-      values.insert(values.end(), entity.begin(), entity.end());
-      partition.insert(partition.end(), entity.size() + 2, entity_processes[j]);
-    }
-  }
-
-  // Clean up no longer needed data structures
-  entity_processes.clear();
-  shared_entity_indices.clear();
-  shared_entity_processes.clear();
-
-  // Send data
-  MPI::distribute(values, partition);
-
-  // Fill in global entity indices recieved from lower ranked processes
-  for (uint i = 0; i < values.size();)
-  {
-    const uint p = partition[i];
-    const uint global_index = values[i++];
-    const uint entity_size = values[i++];
-    std::vector<uint> entity;
-    for (uint j = 0; j < entity_size; ++j)
-      entity.push_back(values[i++]);
-
-    // Sanity check, should not receive an entity we don't need
-    if (ignored_entity_indices.count(entity) == 0)
-    {
-      std::stringstream msg;
-      msg << "Process " << MPI::process_number() << " received illegal entity given by ";
-      print_container(msg, entity.begin(), entity.end());
-      msg << " with global index " << global_index;
-      msg << " from process " << p;
-      error(msg.str());
-    }
-
-    const uint local_entity_index = ignored_entity_indices[entity];
-    assert(entity_indices[local_entity_index] == -1);
-    entity_indices[local_entity_index] = global_index;
-  }
-
-  // Clean up no longer needed data structures
-  values.clear();
-  partition.clear();
-  ignored_entity_indices.clear();
-  ignored_entity_processes.clear();
-
-  // Create mesh data
-  global_entity_indices = mesh.data().create_mesh_function(mesh_data_name.str(), d);
-  for (uint i = 0; i < entity_indices.size(); ++i)
-  {
-    if (entity_indices[i] < 0)
-      info(WARNING, "Missing global number for local entity (%d, %d).", d, i);
-    assert(entity_indices[i] >= 0);
-    (*global_entity_indices)[i] = static_cast<uint>(entity_indices[i]);
-  }
 }
 //-----------------------------------------------------------------------------
 void MeshPartitioning::distribute_cells(LocalMeshData& mesh_data,
@@ -517,20 +551,22 @@ void MeshPartitioning::distribute_cells(LocalMeshData& mesh_data,
   // process belongs. We use MPI::distribute to redistribute all cells (the
   // global vertex indices of all cells).
 
+  std::vector<uint>& global_cell_indices = mesh_data.global_cell_indices;
+
   // Get dimensions of local mesh_data
-  uint num_local_cells = mesh_data.cell_vertices.size();
-  assert(mesh_data.global_cell_indices.size() == num_local_cells);
+  const uint num_local_cells = mesh_data.cell_vertices.size();
+  assert(global_cell_indices.size() == num_local_cells);
   const uint num_cell_vertices = mesh_data.cell_vertices[0].size();
 
   // Build array of cell-vertex connectivity and partition vector
   // Distribute the global cell number as well
   std::vector<uint> cell_vertices;
   std::vector<uint> cell_vertices_partition;
-  cell_vertices.reserve(num_local_cells*(num_cell_vertices+1));
-  cell_vertices_partition.reserve(num_local_cells*(num_cell_vertices+1));
+  cell_vertices.reserve(num_local_cells*(num_cell_vertices + 1));
+  cell_vertices_partition.reserve(num_local_cells*(num_cell_vertices + 1));
   for (uint i = 0; i < num_local_cells; i++)
   {
-    cell_vertices.push_back(mesh_data.global_cell_indices[i]);
+    cell_vertices.push_back(global_cell_indices[i]);
     cell_vertices_partition.push_back(cell_partition[i]);
     for (uint j = 0; j < num_cell_vertices; j++)
     {
@@ -541,18 +577,22 @@ void MeshPartitioning::distribute_cells(LocalMeshData& mesh_data,
 
   // Distribute cell-vertex connectivity
   MPI::distribute(cell_vertices, cell_vertices_partition);
+  assert(cell_vertices.size() % (num_cell_vertices + 1) == 0);
   cell_vertices_partition.clear();
 
-  // Put mesh_data back into mesh_data.cell_vertices
+  // Clear mesh data
   mesh_data.cell_vertices.clear();
-  mesh_data.global_cell_indices.clear();
-  assert(cell_vertices.size() % (num_cell_vertices + 1) == 0);
-  num_local_cells = cell_vertices.size() / (num_cell_vertices + 1);
-  mesh_data.cell_vertices.reserve(num_local_cells);
-  mesh_data.global_cell_indices.reserve(num_local_cells);
-  for (uint i = 0; i < num_local_cells; ++i)
+  global_cell_indices.clear();
+
+  // Put mesh_data back into mesh_data.cell_vertices
+  const uint num_new_local_cells = cell_vertices.size()/(num_cell_vertices + 1);
+  mesh_data.cell_vertices.reserve(num_new_local_cells);
+  global_cell_indices.reserve(num_new_local_cells);
+
+  // Loop over new cells
+  for (uint i = 0; i < num_new_local_cells; ++i)
   {
-    mesh_data.global_cell_indices.push_back(cell_vertices[i*(num_cell_vertices + 1)]);
+    global_cell_indices.push_back(cell_vertices[i*(num_cell_vertices + 1)]);
     std::vector<uint> cell(num_cell_vertices);
     for (uint j = 0; j < num_cell_vertices; ++j)
       cell[j] = cell_vertices[i*(num_cell_vertices + 1) + j + 1];
@@ -575,24 +615,27 @@ void MeshPartitioning::distribute_vertices(LocalMeshData& mesh_data,
 
   // Compute which vertices we need
   std::set<uint> needed_vertex_indices;
-  std::vector<std::vector<uint> >& cell_vertices = mesh_data.cell_vertices;
-  for (uint i = 0; i < cell_vertices.size(); ++i)
-    for (uint j = 0; j < cell_vertices[i].size(); ++j)
-      needed_vertex_indices.insert(cell_vertices[i][j]);
+  std::vector<std::vector<uint> >::const_iterator vertices;
+  for (vertices = mesh_data.cell_vertices.begin(); vertices != mesh_data.cell_vertices.end(); ++vertices)
+    needed_vertex_indices.insert(vertices->begin(), vertices->end());
 
   // Compute where (process number) the vertices we need are located
   std::vector<uint> vertex_partition;
   std::vector<std::vector<uint> > vertex_location(num_processes);
   std::vector<uint> vertex_indices;
-  std::set<uint>::const_iterator it;
-  for (it = needed_vertex_indices.begin(); it != needed_vertex_indices.end(); ++it)
+
+  std::set<uint>::const_iterator required_vertex;
+  for (required_vertex = needed_vertex_indices.begin(); required_vertex != needed_vertex_indices.end(); ++required_vertex)
   {
-    const uint location = MPI::index_owner(*it, mesh_data.num_global_vertices);
+    // Get process that has required vertex
+    const uint location = MPI::index_owner(*required_vertex, mesh_data.num_global_vertices);
     vertex_partition.push_back(location);
-    vertex_indices.push_back(*it);
-    vertex_location[location].push_back(*it);
+    vertex_indices.push_back(*required_vertex);
+    vertex_location[location].push_back(*required_vertex);
   }
-  needed_vertex_indices.clear();
+
+  // Send required vertices to other proceses, and receive back vertices
+  // required by othe processes.
   MPI::distribute(vertex_indices, vertex_partition);
   assert(vertex_indices.size() == vertex_partition.size());
 
@@ -616,13 +659,14 @@ void MeshPartitioning::distribute_vertices(LocalMeshData& mesh_data,
   MPI::distribute(vertex_coordinates, vertex_coordinates_partition);
 
   // Set index counters to first position in recieve buffers
-  std::vector<uint> index_counters(num_processes);
-  std::fill(index_counters.begin(), index_counters.end(), 0);
+  std::vector<uint> index_counters(num_processes, 0);
 
-  // Store coordinates and construct global to local mapping
+  // Clear data
   mesh_data.vertex_coordinates.clear();
   mesh_data.vertex_indices.clear();
   glob2loc.clear();
+
+  // Store coordinates and construct global to local mapping
   const uint num_local_vertices = vertex_coordinates.size()/vertex_size;
   for (uint i = 0; i < num_local_vertices; ++i)
   {
@@ -630,9 +674,9 @@ void MeshPartitioning::distribute_vertices(LocalMeshData& mesh_data,
     for (uint j = 0; j < vertex_size; ++j)
       vertex[j] = vertex_coordinates[i*vertex_size+j];
     mesh_data.vertex_coordinates.push_back(vertex);
+
     const uint sender_process = vertex_coordinates_partition[i*vertex_size];
-    const uint global_vertex_index
-        = vertex_location[sender_process][index_counters[sender_process]++];
+    const uint global_vertex_index = vertex_location[sender_process][index_counters[sender_process]++];
     glob2loc[global_vertex_index] = i;
   }
 }
@@ -673,44 +717,42 @@ void MeshPartitioning::build_mesh(Mesh& mesh,
   }
 
   // Construct local to global mapping based on the global to local mapping
-  MeshFunction<uint>* global_vertex_indices = mesh.data().create_mesh_function("global entity indices 0", 0);
-  assert(global_vertex_indices);
+  MeshFunction<unsigned int>& global_vertex_indices = mesh.parallel_data().global_entity_indices(0);
   for (std::map<uint, uint>::const_iterator iter = glob2loc.begin(); iter != glob2loc.end(); ++iter)
-    (*global_vertex_indices)[(*iter).second] = (*iter).first;
+    global_vertex_indices[iter->second] = iter->first;
 
   // Construct local to global mapping for cells
-  std::stringstream cell_name;
-  cell_name << "global entity indices " << mesh_data.tdim;
-  MeshFunction<uint>* global_cell_indices = mesh.data().create_mesh_function(cell_name.str(), mesh_data.tdim);
-  assert(global_cell_indices);
+  MeshFunction<unsigned int>& global_cell_indices = mesh.parallel_data().global_entity_indices(mesh_data.tdim);
   const std::vector<uint>& gci = mesh_data.global_cell_indices;
-  for(uint i=0; i < gci.size(); ++i)
-    (*global_cell_indices)[i] = gci[i];
+  assert(global_cell_indices.size() > 0);
+  assert(global_cell_indices.size() == gci.size());
+  for(uint i = 0; i < gci.size(); ++i)
+    global_cell_indices[i] = gci[i];
 
   // Close mesh: Note that this must be done after creating the global vertex map or
   // otherwise the ordering in mesh.close() will be wrong (based on local numbers).
   editor.close();
 
   // Construct array of length topology().dim() that holds the number of global mesh entities
-  std::vector<uint>* num_global_entities = mesh.data().create_array("num global entities", mesh_data.tdim + 1);
-  for (uint d = 0; d <= mesh_data.tdim; ++d)
-    (*num_global_entities)[d] = 0;
-  (*num_global_entities)[0] = mesh_data.num_global_vertices;
-  (*num_global_entities)[mesh_data.tdim] = mesh_data.num_global_cells;
+  std::vector<uint>& num_global_entities = mesh.parallel_data().num_global_entities();
+  num_global_entities.resize(mesh_data.tdim + 1);
+  std::fill(num_global_entities.begin(), num_global_entities.end(), 0);
+
+  num_global_entities[0] = mesh_data.num_global_vertices;
+  num_global_entities[mesh_data.tdim] = mesh_data.num_global_cells;
 
   /// Communicate global number of boundary vertices to all processes
 
   // Construct boundary mesh
   BoundaryMesh bmesh(mesh);
-  MeshFunction<uint>* boundary_vertex_map = bmesh.data().mesh_function("vertex map");
-  assert(boundary_vertex_map);
-  const uint boundary_size = boundary_vertex_map->size();
+  const MeshFunction<unsigned int>& boundary_vertex_map = bmesh.vertex_map();
+  const uint boundary_size = boundary_vertex_map.size();
 
   // Build sorted array of global boundary vertex indices (global numbering)
-  uint global_vertex_send[boundary_size];
+  std::vector<uint> global_vertex_send(boundary_size);
   for (uint i = 0; i < boundary_size; ++i)
-    global_vertex_send[i] = (*global_vertex_indices)[(*boundary_vertex_map)[i]];
-  std::sort(global_vertex_send, global_vertex_send + boundary_size);
+    global_vertex_send[i] = global_vertex_indices[boundary_vertex_map[i]];
+  std::sort(global_vertex_send.begin(), global_vertex_send.end());
 
   // Distribute boundaries' sizes
   std::vector<uint> boundary_sizes(num_processes);
@@ -718,13 +760,14 @@ void MeshPartitioning::build_mesh(Mesh& mesh,
   MPI::gather(boundary_sizes);
 
   // Find largest boundary size (for recv buffer)
-  const uint max_boundary_size = *(std::max_element(boundary_sizes.begin(), boundary_sizes.end()));
+  const uint max_boundary_size = *std::max_element(boundary_sizes.begin(), boundary_sizes.end());
 
   // Recieve buffer
-  uint global_vertex_recv[max_boundary_size];
+  std::vector<uint> global_vertex_recv(max_boundary_size);
 
-  // Create overlap: mapping from shared vertices to list of neighboring processes
-  std::map<uint, std::vector<uint> >* overlap = mesh.data().create_vector_mapping("overlap");
+  // Create shared_vertices data structure: mapping from shared vertices to list of neighboring processes
+  std::map<uint, std::vector<uint> >& shared_vertices = mesh.parallel_data().shared_vertices();
+  shared_vertices.clear();
 
   // Distribute boundaries and build mappings
   for (uint i = 1; i < num_processes; ++i)
@@ -736,48 +779,61 @@ void MeshPartitioning::build_mesh(Mesh& mesh,
     const int q = (process_number + i) % num_processes;
 
     // Send and receive
-    MPI::send_recv(global_vertex_send, boundary_size, p, global_vertex_recv, boundary_sizes[q], q);
+    MPI::send_recv(&global_vertex_send[0], boundary_size, p, &global_vertex_recv[0], boundary_sizes[q], q);
 
     // Compute intersection of global indices
     std::vector<uint> intersection(std::min(boundary_size, boundary_sizes[q]));
     std::vector<uint>::iterator intersection_end = std::set_intersection(
-         global_vertex_send, global_vertex_send + boundary_size,
-         global_vertex_recv, global_vertex_recv + boundary_sizes[q], intersection.begin());
+         global_vertex_send.begin(), global_vertex_send.end(),
+         &global_vertex_recv[0], &global_vertex_recv[0] + boundary_sizes[q],
+         intersection.begin());
 
-    // Fill overlap information
-    for (std::vector<uint>::const_iterator index = intersection.begin();
-        index != intersection_end; ++index)
-    {
-      (*overlap)[*index].push_back(q);
-    }
+    // Fill shared vertices information
+    std::vector<uint>::const_iterator index;
+    for (index = intersection.begin(); index != intersection_end; ++index)
+      shared_vertices[*index].push_back(q);
   }
 }
 //-----------------------------------------------------------------------------
 bool MeshPartitioning::in_overlap(const std::vector<uint>& entity,
-                                  std::map<uint, std::vector<uint> >& overlap)
+                             const std::map<uint, std::vector<uint> >& shared)
 {
-  for (uint i = 0; i < entity.size(); ++i)
-    if (overlap.count(entity[i]) == 0)
+  std::vector<uint>::const_iterator e;
+  for (e = entity.begin(); e != entity.end(); ++e)
+  {
+    if (shared.find(*e) == shared.end())
       return false;
+  }
   return true;
 }
 //-----------------------------------------------------------------------------
 void MeshPartitioning::mark_nonshared(const std::map<std::vector<uint>, uint>& entities,
                const std::map<std::vector<uint>, uint>& shared_entity_indices,
                const std::map<std::vector<uint>, uint>& ignored_entity_indices,
-               Mesh& mesh, uint d, std::string name)
+               MeshFunction<bool>& exterior)
 {
-  // Create mesh markers and mark all
-  MeshFunction<uint>* exterior = 0;
-  exterior = mesh.data().create_mesh_function(name, d);
-  exterior->set_all(1);
+  // Set all to false (not exterior)
+  exterior.set_all(false);
 
-  // Remove all entities in the overlap
+  const Mesh& mesh = exterior.mesh();
+  const uint D = mesh.topology().dim();
+
+  assert(exterior.dim() == D - 1);
+
+  // FIXME: Check that everything is correctly initalised
+
+  // Add facets that are connected to one cell only
+  for (FacetIterator facet(mesh); !facet.end(); ++facet)
+  {
+    if (facet->num_entities(D) == 1)
+      exterior[*facet] = true;
+  }
+
+  // Remove all entities on internal partition boundaries
   std::map<std::vector<uint>, uint>::const_iterator it;
   for (it = shared_entity_indices.begin(); it != shared_entity_indices.end(); ++it)
-    (*exterior)[entities.find(it->first)->second] = 0;
+    exterior[entities.find(it->first)->second] = false;
   for (it = ignored_entity_indices.begin(); it != ignored_entity_indices.end(); ++it)
-    (*exterior)[entities.find(it->first)->second] = 0;
+    exterior[entities.find(it->first)->second] = false;
 }
 //-----------------------------------------------------------------------------
-
