@@ -1,5 +1,19 @@
-// Copyright (C) 2007-2008 Kristian B. Oelgaard.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2007-2008 Kristian B. Oelgaard
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Anders Logg, 2008.
 // Modified by Kristoffer Sleim, 2008.
@@ -9,10 +23,10 @@
 
 #include <dolfin/log/dolfin_log.h>
 #include "Cell.h"
-#include "MeshEditor.h"
 #include "Facet.h"
-#include "PointCell.h"
+#include "MeshEditor.h"
 #include "Vertex.h"
+#include "PointCell.h"
 
 using namespace dolfin;
 
@@ -99,7 +113,7 @@ double PointCell::facet_area(const Cell& cell, uint facet) const
 void PointCell::order(Cell& cell,
                       const MeshFunction<uint>* global_vertex_indices) const
 {
-  //  error("PointCell::order() not defined.");
+  error("PointCell::order() not defined.");
 }
 //-----------------------------------------------------------------------------
 std::string PointCell::description(bool plural) const
