@@ -1,5 +1,19 @@
-// Copyright (C) 2009 Andre Massing 
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2009 Andre Massing
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2009-09-11
 // Last changed: 2010-04-06
@@ -7,6 +21,14 @@
 #ifndef  segment_3_segment_3_intersection_INC
 #define  segment_3_segment_3_intersection_INC
 
+#include <CGAL/version.h>
+
+///@file This file contains some small extension to the CGAL library, for
+//instance unifying their do_intersect functions to also deal with Segment_3
+//and Primitive intersections or some additional intersection collision test.
+// It is not required for CGAL_VERSION >= 3.8
+
+#if CGAL_VERSION_NR < 1030801000
 
 #include <CGAL/Segment_3.h>
 #include <CGAL/Object.h>
@@ -15,10 +37,6 @@
 
 using dolfin::error;
 
-///@file This file contains some small extension to the CGAL library, for
-//instance unifying their do_intersect functions to also deal with Segment_3
-//and Primitive intersections or some additional intersection collision test.
-
 CGAL_BEGIN_NAMESPACE
 
 #if CGAL_VERSION_NR < 1030601000
@@ -29,7 +47,7 @@ namespace internal {
 
 
   template <class K >
-  inline bool do_intersect(const typename K::Segment_3 & s1, 
+  inline bool do_intersect(const typename K::Segment_3 & s1,
                            const typename K::Segment_3 & s2,
                            const K & k)
   {
@@ -41,8 +59,8 @@ namespace internal {
   template <class K>
   inline
   Object
-  intersection(const typename K::Segment_3 &s1, 
-               const typename K::Segment_3 &s2, 
+  intersection(const typename K::Segment_3 &s1,
+               const typename K::Segment_3 &s2,
                const K&)
   {
     //throw exception
@@ -77,4 +95,6 @@ intersection(const Segment_3<K> &s1, const Segment_3<K> &s2)
 CGAL_END_NAMESPACE
 
 
+#endif
+
 #endif   /* ----- #ifndef segment_3_segment_3_intersection_INC  ----- */
