@@ -1,10 +1,24 @@
-// Copyright (C) 2007-2008 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2007-2008 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Niclas Jansson 2009.
 //
 // First added:  2007-04-24
-// Last changed: 2011-01-25
+// Last changed: 2011-03-17
 
 #include <dolfin/common/Array.h>
 #include <dolfin/log/log.h>
@@ -12,8 +26,9 @@
 #include "MeshData.h"
 #include "MeshEntity.h"
 #include "MeshEntityIterator.h"
-#include "SubDomain.h"
+#include "ParallelData.h"
 #include "Vertex.h"
+#include "SubDomain.h"
 
 using namespace dolfin;
 
@@ -41,23 +56,23 @@ void SubDomain::map(const Array<double>& x, Array<double>&) const
 //-----------------------------------------------------------------------------
 /// Set sub domain markers (uint) for given subdomain
 void SubDomain::mark(MeshFunction<uint>& sub_domains, uint sub_domain) const
-{ 
-  mark_meshfunction(sub_domains, sub_domain); 
+{
+  mark_meshfunction(sub_domains, sub_domain);
 }
 //-----------------------------------------------------------------------------
 void SubDomain::mark(MeshFunction<int>& sub_domains, int sub_domain) const
 {
-  mark_meshfunction(sub_domains, sub_domain); 
+  mark_meshfunction(sub_domains, sub_domain);
 }
 //-----------------------------------------------------------------------------
 void SubDomain::mark(MeshFunction<double>& sub_domains, double sub_domain) const
-{ 
-  mark_meshfunction(sub_domains, sub_domain); 
+{
+  mark_meshfunction(sub_domains, sub_domain);
 }
 //-----------------------------------------------------------------------------
 void SubDomain::mark(MeshFunction<bool>& sub_domains, bool sub_domain) const
-{ 
-  mark_meshfunction(sub_domains, sub_domain); 
+{
+  mark_meshfunction(sub_domains, sub_domain);
 }
 //-----------------------------------------------------------------------------
 dolfin::uint SubDomain::geometric_dimension() const
@@ -72,7 +87,7 @@ dolfin::uint SubDomain::geometric_dimension() const
 template<class T>
 void SubDomain::mark_meshfunction(MeshFunction<T>& sub_domains, T sub_domain) const
 {
-  info(TRACE, "Computing sub domain markers for sub domain %d.", sub_domain);
+  log(TRACE, "Computing sub domain markers for sub domain %d.", sub_domain);
 
   // Get the dimension of the entities we are marking
   const uint dim = sub_domains.dim();
@@ -93,7 +108,7 @@ void SubDomain::mark_meshfunction(MeshFunction<T>& sub_domains, T sub_domain) co
   bool on_boundary = false;
 
   // Extract exterior (non shared) facets markers
-  MeshFunction<uint>* exterior = mesh.data().mesh_function("exterior facets");
+  const MeshFunction<bool>& exterior = mesh.parallel_data().exterior_facet();
 
   Array<double> x;
 
@@ -104,8 +119,7 @@ void SubDomain::mark_meshfunction(MeshFunction<T>& sub_domains, T sub_domain) co
     // Check if entity is on the boundary if entity is a facet
     if (dim == D - 1)
     {
-      on_boundary = (entity->num_entities(D) == 1 &&
-		     (!exterior || (((*exterior)[*entity]))));
+      on_boundary = (entity->num_entities(D) == 1 && (exterior.size() == 0 || exterior[*entity]));
     }
 
     // Start by assuming all points are inside
