@@ -1,5 +1,19 @@
-// Copyright (C) 2007-2008 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2007-2008 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2007-04-10
 // Last changed: 2011-01-25
@@ -40,7 +54,7 @@ namespace dolfin
     virtual void snap(Array<double>& x) const {}
 
     /// Set sub domain markers (uint) for given subdomain
-    void mark(MeshFunction<uint>& sub_domains, uint sub_domain) const;
+    void mark(MeshFunction<unsigned int>& sub_domains, unsigned int sub_domain) const;
 
     /// Set sub domain markers (int) for given subdomain
     void mark(MeshFunction<int>& sub_domains, int sub_domain) const;
@@ -57,7 +71,7 @@ namespace dolfin
   private:
 
     /// Set sub domain markers for given subdomain
-    template<class T> 
+    template<class T>
     void mark_meshfunction(MeshFunction<T>& sub_domains, T sub_domain) const;
 
     // Friends
