@@ -1,8 +1,22 @@
-// Copyright (C) 2006-2010 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2006-2010 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2006-06-02
-// Last changed: 2011-02-09
+// Last changed: 2011-03-17
 
 #include <set>
 #include <vector>
@@ -146,7 +160,7 @@ void TopologyComputation::compute_connectivity(Mesh& mesh, uint d0, uint d1)
   // Each of these functions assume a set of preconditions that we
   // need to satisfy.
 
-  info(TRACE, "Requesting connectivity %d - %d.", d0, d1);
+  log(TRACE, "Requesting connectivity %d - %d.", d0, d1);
 
   // Get mesh topology and connectivity
   MeshTopology& topology = mesh.topology();
@@ -212,7 +226,7 @@ void TopologyComputation::compute_from_transpose(Mesh& mesh, uint d0, uint d1)
   //   3. Iterate again over entities of dimension d1 and add connections
   //      for each entity of dimension d0
 
-  info(TRACE, "Computing mesh connectivity %d - %d from transpose.", d0, d1);
+  log(TRACE, "Computing mesh connectivity %d - %d from transpose.", d0, d1);
 
   // Get mesh topology and connectivity
   MeshTopology& topology = mesh.topology();
@@ -249,8 +263,8 @@ void TopologyComputation::compute_from_transpose(Mesh& mesh, uint d0, uint d1)
 void TopologyComputation::compute_from_intersection(Mesh& mesh,
                                                     uint d0, uint d1, uint d)
 {
-  info(TRACE, "Computing mesh connectivity %d - %d from intersection %d - %d - %d.",
-       d0, d1, d0, d, d1);
+  log(TRACE, "Computing mesh connectivity %d - %d from intersection %d - %d - %d.",
+      d0, d1, d0, d, d1);
 
   // Get mesh topology
   MeshTopology& topology = mesh.topology();
