@@ -1,5 +1,19 @@
-// Copyright (C) 2005-2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2005-2009 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells 2007.
 // Modified by Kristian B. Oelgaard 2009.
@@ -20,8 +34,11 @@ UnitSquare::UnitSquare(uint nx, uint ny, std::string diagonal) : Mesh()
   // Receive mesh according to parallel policy
   if (MPI::is_receiver()) { MeshPartitioning::partition(*this); return; }
 
-  if (diagonal != "left" && diagonal != "right" && diagonal != "right/left"  && diagonal != "left/right"  && diagonal != "crossed")
+  if (diagonal != "left" && diagonal != "right" && diagonal != "right/left"
+        && diagonal != "left/right"  && diagonal != "crossed")
+  {
     error("Unknown mesh diagonal in UnitSquare. Allowed options are \"left\", \"right\", \"left/right\", \"right/left\" and \"crossed\".");
+  }
 
   if (nx < 1 || ny < 1)
     error("Size of unit square must be at least 1 in each dimension.");
@@ -35,12 +52,12 @@ UnitSquare::UnitSquare(uint nx, uint ny, std::string diagonal) : Mesh()
   // Create vertices and cells:
   if (diagonal == "crossed")
   {
-    editor.init_vertices((nx+1)*(ny+1) + nx*ny);
+    editor.init_vertices((nx + 1)*(ny + 1) + nx*ny);
     editor.init_cells(4*nx*ny);
   }
   else
   {
-    editor.init_vertices((nx+1)*(ny+1));
+    editor.init_vertices((nx + 1)*(ny + 1));
     editor.init_cells(2*nx*ny);
   }
 
