@@ -1,5 +1,19 @@
-// Copyright (C) 2006-2010 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2006-2010 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2006-06-01
 // Last changed: 2010-08-16
@@ -7,6 +21,7 @@
 #ifndef __VERTEX_H
 #define __VERTEX_H
 
+#include "dolfin/common/types.h"
 #include "Mesh.h"
 #include "MeshEntity.h"
 #include "MeshEntityIterator.h"
