@@ -1,8 +1,22 @@
-// Copyright (C) 2005-2008 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2005-2008 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2005-02-02
-// Last changed: 2008-10-06
+// Last changed: 2011-03-17
 
 #ifndef HAS_GMP
 
@@ -14,7 +28,7 @@ using namespace dolfin;
 ComplexODE::ComplexODE(uint n, real T) : ODE(2*n, T), n(n), j(0.0, 1.0),
                                            zvalues(0), fvalues(0), yvalues(0)
 {
-  info(TRACE, "Creating complex ODE of size %d (%d complex components).", N, n);
+  log(TRACE, "Creating complex ODE of size %d (%d complex components).", N, n);
 
   // Initialize complex solution vector and right-hand side
   zvalues = new complex[n];
@@ -28,9 +42,9 @@ ComplexODE::ComplexODE(uint n, real T) : ODE(2*n, T), n(n), j(0.0, 1.0),
 //-----------------------------------------------------------------------------
 ComplexODE::~ComplexODE()
 {
-  if ( zvalues ) delete [] zvalues;
-  if ( fvalues ) delete [] fvalues;
-  if ( yvalues ) delete [] yvalues;
+  delete [] zvalues;
+  delete [] fvalues;
+  delete [] yvalues;
 }
 //-----------------------------------------------------------------------------
 complex ComplexODE::f(const complex z[], real t, uint i)
@@ -76,7 +90,7 @@ bool ComplexODE::update(const complex z[], real t, bool end)
   return true;
 }
 //-----------------------------------------------------------------------------
-void ComplexODE::u0(real* u)
+void ComplexODE::u0(Array<real>& u)
 {
   // Translate initial value from complex to real
   z0(zvalues);
@@ -87,7 +101,7 @@ void ComplexODE::u0(real* u)
   }
 }
 //-----------------------------------------------------------------------------
-real ComplexODE::f(const real* u, real t, uint i)
+real ComplexODE::f(const Array<real>& u, real t, uint i)
 {
   // Translate right-hand side from complex to real, assuming that if
   // u_i depends on u_j, then u_i depends on both the real and
@@ -115,7 +129,7 @@ real ComplexODE::f(const real* u, real t, uint i)
   return ( i % 2 == 0 ? fvalue.real() : fvalue.imag() );
 }
 //-----------------------------------------------------------------------------
-void ComplexODE::f(const real* u, real t, real* y)
+void ComplexODE::f(const Array<real>& u, real t, Array<real>& y)
 {
   // Update zvalues for all components
   for (uint i = 0; i < n; i++)
@@ -136,8 +150,8 @@ void ComplexODE::f(const real* u, real t, real* y)
   }
 }
 //-----------------------------------------------------------------------------
-void ComplexODE::M(const real* x, real* y,
-		   const real* u, real t)
+void ComplexODE::M(const Array<real>& x, Array<real>& y,
+		   const Array<real>& u, real t)
 {
   // Update zvalues and fvalues for all components
   for (uint i = 0; i < n; i++)
@@ -168,8 +182,8 @@ void ComplexODE::M(const real* x, real* y,
   }
 }
 //-----------------------------------------------------------------------------
-void ComplexODE::J(const real* x, real* y,
-		   const real* u, real t)
+void ComplexODE::J(const Array<real>& x, Array<real>& y,
+		   const Array<real>& u, real t)
 {
   // Update zvalues and fvalues for all components
   for (uint i = 0; i < n; i++)
@@ -206,7 +220,7 @@ real ComplexODE::timestep(uint i)
   return k(i / 2);
 }
 //-----------------------------------------------------------------------------
-bool ComplexODE::update(const real* u, real t, bool end)
+bool ComplexODE::update(const Array<real>& u, real t, bool end)
 {
   // Update zvalues for all components
   for (uint i = 0; i < n; i++)
