@@ -1,5 +1,19 @@
-// Copyright (C) 2005-2008 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2005-2008 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2005-02-02
 // Last changed: 2010-08-26
@@ -68,25 +82,25 @@ namespace dolfin
     virtual bool update(const complex z[], real t, bool end);
 
     /// Return initial value for real-valued ODE
-    void u0(real* u);
+    void u0(Array<real>& u);
 
     /// Return right-hand side for real-valued ODE
-    real f(const real* u, real t, uint i);
+    real f(const Array<real>& u, real t, uint i);
 
     /// Evaluate right-hand side for real-valued ODE
-    void f(const real* u, real t, real* y);
+    void f(const Array<real>& u, real t, Array<real>& y);
 
     /// Compute product y = Mx for real-valued ODE
-    void M(const real* x, real* y, const real* u, real t);
+    void M(const Array<real>& x, Array<real>& y, const Array<real>& u, real t);
 
     /// Compute product y = Jx for real-valued ODE
-    void J(const real* x, real* y, const real* u, real t);
+    void J(const Array<real>& x, Array<real>& y, const Array<real>& u, real t);
 
     /// Return time step for real-valued ODE
     real timestep(uint i);
 
     /// Update for real-valued ODE
-    bool update(const real* u, real t, bool end);
+    bool update(const Array<real>& u, real t, bool end);
 
   protected:
 
@@ -127,9 +141,9 @@ namespace dolfin
       warning("ComplexODE not available when DOLFIN is compiled with GMP support.");
     }
 
-    void u0(real* u) {}
+    void u0(Array<real>& u) {}
 
-    void f(const real* u, real t, real* y) {}
+    void f(const Array<real>& u, real t, Array<real>& y) {}
 
   protected:
 
