@@ -1,5 +1,19 @@
-// Copyright (C) 2003-2008 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2003-2008 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Benjamin Kehlet
 //
@@ -46,10 +60,10 @@ namespace dolfin
     ~Dual();
 
     /// Initial value
-    void u0(real* psi);
+    void u0(Array<real>& psi);
 
     /// Right-hand side
-    void f(const real* phi, real t, real* y);
+    void f(const Array<real>& phi, real t, Array<real>& y);
 
     /// Return real time (might be flipped backwards for dual)
     real time(real t) const;
