@@ -1,5 +1,19 @@
-// Copyright (C) 2005-2006 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2005-2006 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2005-01-28
 // Last changed: 2006-07-06
@@ -51,8 +65,8 @@ namespace dolfin
     // FIXME: Maybe we can reuse some other vectors?
 
     // Temporary arrays for storing multiplication
-    mutable real* xx;
-    mutable real* yy;
+    mutable Array<real> xx;
+    mutable Array<real> yy;
 
   };
 
