@@ -1,8 +1,22 @@
-// Copyright (C) 2005-2008 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2005-2008 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2005-01-27
-// Last changed: 2010-04-05
+// Last changed: 2011-03-17
 
 #include <dolfin/common/constants.h>
 #include <dolfin/math/dolfin_math.h>
@@ -37,7 +51,7 @@ MultiAdaptiveJacobian::MultiAdaptiveJacobian(MultiAdaptiveNewtonSolver& newton,
   for (uint pos = 0; pos < sum; pos++)
     Jvalues[pos] = 0.0;
 
-  info(PROGRESS, "Generated Jacobian data structure for %d dependencies.", sum);
+  log(PROGRESS, "Generated Jacobian data structure for %d dependencies.", sum);
 
   // Compute maximum number of dependencies
   uint maxsize = 0;
@@ -83,7 +97,7 @@ void MultiAdaptiveJacobian::init()
 {
   // Compute Jacobian at the beginning of the slab
   double t = to_double(ts.starttime());
-  //info(PROGRESS, "Recomputing Jacobian matrix at t = %f.", t);
+  //log(PROGRESS, "Recomputing Jacobian matrix at t = %f.", t);
 
   // Compute Jacobian
   for (uint i = 0; i < ode.size(); i++)
@@ -96,7 +110,7 @@ void MultiAdaptiveJacobian::init()
   /*
   // Compute Jacobian at the end of the slab
   double t = ts.endtime();
-  //info(PROGRESS, "Recomputing Jacobian matrix at t = %f.", t);
+  //log(PROGRESS, "Recomputing Jacobian matrix at t = %f.", t);
 
   // Compute Jacobian
   for (uint i = 0; i < ode.size(); i++)
@@ -275,7 +289,7 @@ void MultiAdaptiveJacobian::cg_mult(const uBLASVector& x, uBLASVector& y) const
 	// searching, but we were clever enough to pick out the value
 	// before when we had the chance... :-)
 	const double dfdu = Jlookup[dep];
-	//info(DBG, "Looks like df_%d/du_%d = %f", i0, i1, dfdu);
+	//log(DBG, "Looks like df_%d/du_%d = %f", i0, i1, dfdu);
 
 	// Iterate over quadrature points of other element
 	const double tmp0 = k0 * dfdu;
@@ -447,7 +461,7 @@ void MultiAdaptiveJacobian::dg_mult(const uBLASVector& x, uBLASVector& y) const
 	// searching, but we were clever enough to pick out the value
 	// before when we had the chance... :-)
 	const double dfdu = Jlookup[dep];
-	//info(DBG, "Looks like df_%d/du_%d = %f", i0, i1, dfdu);
+	//log(DBG, "Looks like df_%d/du_%d = %f", i0, i1, dfdu);
 
 	// Iterate over quadrature points of other element
 	const double tmp0 = k0 * dfdu;
