@@ -1,10 +1,24 @@
-// Copyright (C) 2005-2008 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2005-2008 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells
 //
 // First added:  2005-01-27
-// Last changed: 2010-06-07
+// Last changed: 2011-03-17
 
 #include <string>
 #include <algorithm>
@@ -24,7 +38,7 @@ MultiAdaptiveTimeSlab::MultiAdaptiveTimeSlab(ODE& ode) :
   TimeSlab(ode),
   sa(0), sb(0), ei(0), es(0), ee(0), ed(0), jx(0), de(0),
   ns(0), ne(0), nj(0), nd(0), solver(0), adaptivity(ode, *method), partition(N),
-  elast(0), f0(0), u(0), emax(0), kmin(0)
+  elast(0), f0(N), u(ode.size()), emax(0), kmin(0)
 {
   // Choose solver
   solver = choose_solver();
@@ -35,15 +49,16 @@ MultiAdaptiveTimeSlab::MultiAdaptiveTimeSlab(ODE& ode) :
     elast[i] = -1;
 
   // Initialize f at left end-point for cG
-  if ( method->type() == Method::cG )
-    f0 = new real[N];
+  //if ( method->type() == Method::cG )
+  //  f0 = new real[N];
 
   // Initialize vector for u
-  u = new real[N];
-  real_zero(N, u);
+  //u = new real[N];
+  //real_zero(N, u);
+  u.zero();
 
   // Initialize transpose of dependencies if necessary
-  info(TRACE, "Computing transpose (inverse) of dependency pattern.");
+  log(TRACE, "Computing transpose (inverse) of dependency pattern.");
   if (ode.dependencies.sparse() && !ode.transpose.sparse())
     ode.transpose.transp(ode.dependencies);
 }
@@ -62,8 +77,6 @@ MultiAdaptiveTimeSlab::~MultiAdaptiveTimeSlab()
   delete solver;
 
   delete [] elast;
-  delete [] f0;
-  delete [] u;
 }
 //-----------------------------------------------------------------------------
 real MultiAdaptiveTimeSlab::build(real a, real b)
@@ -100,7 +113,7 @@ real MultiAdaptiveTimeSlab::build(real a, real b)
 //-----------------------------------------------------------------------------
 bool MultiAdaptiveTimeSlab::solve()
 {
-  //info(TRACE, "Solving time slab system on [%f, %f].", _a, _b);
+  //log(TRACE, "Solving time slab system on [%f, %f].", _a, _b);
 
   // Copy u0 to u. This happens automatically in feval if user has set
   // dependencies correctly, but you never know...
@@ -120,7 +133,7 @@ bool MultiAdaptiveTimeSlab::solve()
   //for (uint i = 0; i < N; i++)
   // {
   //  real endval = jx[elast[i] * method->nsize() + method->nsize() - 1];
-  //  info(DBG, "i = %d: u = %.16e", i, endval);
+  //  log(DBG, "i = %d: u = %.16e", i, endval);
   // }
 }
 //-----------------------------------------------------------------------------
@@ -153,7 +166,7 @@ bool MultiAdaptiveTimeSlab::shift(bool end)
 
   // Write solution at final time if we should
   if ( save_final && end )
-    write(N, u);
+    write(u);
 
   // Let user update ODE
   if ( !ode.update(u, _b, end) )
@@ -418,7 +431,7 @@ void MultiAdaptiveTimeSlab::create_e(uint index, uint subslab, real a, real b)
   // Get next available position
   uint pos = size_e.next++;
 
-  //info(DBG, "  Creating element e = %d for i = %d at [%f, %f]", pos, index, a, b);
+  //log(DBG, "  Creating element e = %d for i = %d at [%f, %f]", pos, index, a, b);
 
   //if ( index == 145 )
   //  cout << "Modified: " << b - a << endl << endl;
@@ -456,7 +469,7 @@ void MultiAdaptiveTimeSlab::create_d(uint i0, uint e0, uint s0, real a0, real b0
   // Add dependencies to elements that depend on the given element if the
   // depending elements use larger time steps
 
-  //info(TRACE, "Checking dependencies to element %d (component %d)", element, index);
+  //log(TRACE, "Checking dependencies to element %d (component %d)", element, index);
 
   // Get list of components depending on current component
   const std::vector<uint>& deps = ode.transpose[i0];
@@ -486,7 +499,7 @@ void MultiAdaptiveTimeSlab::create_d(uint i0, uint e0, uint s0, real a0, real b0
     if ( !within(a0, b0, a1, b1) || s0 == s1 )
       continue;
 
-    //info(DBG, "  Checking element %d (component %d)", e1, i1);
+    //log(DBG, "  Checking element %d (component %d)", e1, i1);
 
     // Iterate over dofs for element
     for (uint n = 0; n < method->nsize(); n++)
@@ -494,7 +507,7 @@ void MultiAdaptiveTimeSlab::create_d(uint i0, uint e0, uint s0, real a0, real b0
       //const uint j = j1 + n;
       const real t = a1 + k1*method->npoint(n);
 
-      //info(DBG, "    Checking dof at t = %f", t);
+      //log(DBG, "    Checking dof at t = %f", t);
 
       // Check if dof is contained in the current element
       if ( within(t, a0, b0) )
@@ -528,7 +541,7 @@ void MultiAdaptiveTimeSlab::alloc_s(uint newsize)
 
   if ( newsize <= size_s.size ) return;
 
-  //info(DBG, "Reallocating: ns = %d", newsize);
+  //log(DBG, "Reallocating: ns = %d", newsize);
 
   Alloc::realloc(&sa, size_s.size, newsize);
   Alloc::realloc(&sb, size_s.size, newsize);
@@ -542,7 +555,7 @@ void MultiAdaptiveTimeSlab::alloc_e(uint newsize)
 
   if ( newsize <= size_e.size ) return;
 
-  //info(DGG, "Reallocating: ne = %d", newsize);
+  //log(DGG, "Reallocating: ne = %d", newsize);
 
   Alloc::realloc(&ei, size_e.size, newsize);
   Alloc::realloc(&es, size_e.size, newsize);
@@ -558,7 +571,7 @@ void MultiAdaptiveTimeSlab::alloc_j(uint newsize)
 
   if ( newsize <= size_j.size ) return;
 
-  //info(DBG, "Reallocating: nj = %d", newsize);
+  //log(DBG, "Reallocating: nj = %d", newsize);
 
   Alloc::realloc(&jx, size_j.size, newsize);
 
@@ -569,9 +582,9 @@ void MultiAdaptiveTimeSlab::alloc_d(uint newsize)
 {
   size_d.next = 0;
 
-  if ( newsize <= size_d.size ) return;
+  if (newsize <= size_d.size) return;
 
-  //info(DBG, "Reallocating: nd = %d", newsize);
+  //log(DBG, "Reallocating: nd = %d", newsize);
 
   Alloc::realloc(&de, size_d.size, newsize);
 
