@@ -1,5 +1,19 @@
-// Copyright (C) 2005-2008 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2005-2008 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2005-01-27
 // Last changed: 2009-09-08
@@ -168,8 +182,8 @@ namespace dolfin
     MultiAdaptivity adaptivity; // Adaptive time step regulation (size 3N)
     Partition partition;        // Time step partitioning (size N)
     int* elast;                 // Last element for each component (size N)
-    real* f0;                 // Right-hand side at left end-point for cG (size N)
-    real* u;                  // The interpolated solution at a given time
+    Array<real> f0;                 // Right-hand side at left end-point for cG (size N)
+    Array<real> u;                  // The interpolated solution at a given time
 
     //--- Auxiliary data ---
     uint emax;                  // Last covered element for sample
