@@ -1,5 +1,19 @@
-// Copyright (C) 2003-2009 Johan Jansson and Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2003-2009 Johan Jansson and Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Benjamin Kehlet 2009
 //
@@ -14,6 +28,7 @@
 #include <dolfin/common/constants.h>
 #include <dolfin/log/Event.h>
 #include <dolfin/parameter/Parameters.h>
+#include <dolfin/common/Array.h>
 #include "Dependencies.h"
 #include "Sample.h"
 
@@ -80,25 +95,25 @@ namespace dolfin
     virtual ~ODE();
 
     /// Set initial values
-    virtual void u0(real* u) = 0;
+    virtual void u0(Array<real>& u) = 0;
 
     /// Evaluate right-hand side y = f(u, t), mono-adaptive version (default, optional)
-    virtual void f(const real* u, real t, real* y);
+    virtual void f(const Array<real>& u, real t, Array<real>& y);
 
     /// Evaluate right-hand side f_i(u, t), multi-adaptive version (optional)
-    virtual real f(const real* u, real t, uint i);
+    virtual real f(const Array<real>& u, real t, uint i);
 
     /// Compute product dy = M dx for implicit system (optional)
-    virtual void M(const real* dx, real* dy, const real* u, real t);
+    virtual void M(const Array<real>& dx, Array<real>& dy, const Array<real>& u, real t);
 
     /// Compute product dy = J dx for Jacobian J (optional)
-    virtual void J(const real* dx, real* dy, const real* u, real t);
+    virtual void J(const Array<real>& dx, Array<real>& dy, const Array<real>& u, real t);
 
     /// Compute product dy = tranpose(J) dx for Jacobian J (optional, for dual problem)
-    virtual void JT(const real* dx, real* dy, const real* u, real t);
+    virtual void JT(const Array<real>& dx, Array<real>& dy, const Array<real>& u, real t);
 
     /// Compute entry of Jacobian (optional)
-    virtual real dfdu(const real* u, real t, uint i, uint j);
+    virtual real dfdu(const Array<real>& u, real t, uint i, uint j);
 
     /// Time step to use for the whole system at a given time t (optional)
     virtual real timestep(real t, real k0) const;
@@ -107,7 +122,7 @@ namespace dolfin
     virtual real timestep(real t, uint i, real k0) const;
 
     /// Update ODE, return false to stop (optional)
-    virtual bool update(const real* u, real t, bool end);
+    virtual bool update(const Array<real>& u, real t, bool end);
 
     /// Save sample (optional)
     virtual void save(Sample& sample);
@@ -162,10 +177,10 @@ namespace dolfin
     void analyze_stability_initial(ODESolution& u);
 
     /// Set state for ODE (only available during interval stepping)
-    void set_state(const real* u);
+    void set_state(const Array<real>& u);
 
     /// Get state for ODE (only available during interval stepping)
-    void get_state(real* u);
+    void get_state(Array<real>& u);
 
     /// Default parameter values
     static Parameters default_parameters()
@@ -266,8 +281,8 @@ namespace dolfin
   private:
 
     // Temporary vectors used for computing Jacobian
-    real* tmp0;
-    real* tmp1;
+    Array<real> tmp0;
+    Array<real> tmp1;
 
     // Events
     Event not_impl_f;
