@@ -1,10 +1,24 @@
-// Copyright (C) 2009 Anders Logg and Ola Skavhaug.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2009 Anders Logg and Ola Skavhaug
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Benjamin Kehlet 2009
 //
 // First added:  2009-02-09
-// Last changed: 2009-09-10
+// Last changed: 2011-03-17
 
 #include "ODECollection.h"
 
@@ -12,12 +26,9 @@ using namespace dolfin;
 
 //-----------------------------------------------------------------------------
 ODECollection::ODECollection(ODE& ode, uint num_systems)
-  : ode(ode), num_systems(num_systems), states(0)
+  : ode(ode), num_systems(num_systems), states(new real[num_systems*ode.size()])
 {
-  info(TRACE, "Creating ODE collection of size %d x %d.", num_systems, ode.size());
-
-  // Allocate state vectors
-  states = new real[num_systems*ode.size()];
+  log(TRACE, "Creating ODE collection of size %d x %d.", num_systems, ode.size());
 }
 //-----------------------------------------------------------------------------
 ODECollection::~ODECollection()
@@ -38,17 +49,20 @@ void ODECollection::solve(real t0, real t1)
     // Compute offset for ODE
     const uint offset = system*ode.size();
 
+    // Wrap relevant part of state array in an Array<real>
+    Array<real> s(ode.size(), states+offset);
+
     // Copy initial state from state vector
-    ode.set_state(states + offset);
+    ode.set_state(s);
 
     // Call user-defined update
-    update(states + offset, t0, system);
+    update(s, t0, system);
 
     // Time-stepping
     ode.solve(t0, t1);
 
     // Copy final state to state vector
-    ode.get_state(states + offset);
+    ode.get_state(s);
 
     end();
   }
@@ -56,33 +70,33 @@ void ODECollection::solve(real t0, real t1)
   end();
 }
 //-----------------------------------------------------------------------------
-void ODECollection::set_state(uint system, const real* u)
+void ODECollection::set_state(uint system, const Array<real>& u)
 {
   const uint offset = system*ode.size();
   for (uint j = 0; j < ode.size(); j++)
     states[offset + j] = u[j];
 }
 //-----------------------------------------------------------------------------
-void ODECollection::set_state(const real* u)
+void ODECollection::set_state(const Array<real>& u)
 {
   for (uint j = 0; j < num_systems*ode.size(); j++)
     states[j] = u[j];
 }
 //-----------------------------------------------------------------------------
-void ODECollection::get_state(uint system, real* u)
+void ODECollection::get_state(uint system, Array<real>& u)
 {
   const uint offset = system*ode.size();
   for (uint j = 0; j < ode.size(); j++)
     u[j] = states[offset + j];
 }
 //-----------------------------------------------------------------------------
-void ODECollection::get_state(real* u)
+void ODECollection::get_state(Array<real>& u)
 {
   for (uint j = 0; j < num_systems*ode.size(); j++)
     u[j] = states[j];
 }
 //-----------------------------------------------------------------------------
-void ODECollection::update(real* u, real t, uint system)
+void ODECollection::update(Array<real>& u, real t, uint system)
 {
   // Do nothing
 }
