@@ -1,10 +1,24 @@
-// Copyright (C) 2003-2009 Johan Jansson and Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2003-2009 Johan Jansson and Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Benjamin Kehlet 2008
 //
 // First added:  2003
-// Last changed: 2010-05-03
+// Last changed: 2011-03-17
 
 #include <dolfin/log/dolfin_log.h>
 #include <dolfin/common/timing.h>
@@ -40,7 +54,7 @@ void ODESolver::solve()
 
   // Report elapsed time
   tt = time() - tt;
-  info(PROGRESS, "ODE solution computed in %.3f seconds.", tt);
+  log(PROGRESS, "ODE solution computed in %.3f seconds.", tt);
 
   end();
 }
@@ -59,7 +73,7 @@ void ODESolver::solve(ODESolution& u)
 
   // Report elapsed time
   tt = time() - tt;
-  info(PROGRESS, "ODE solution computed in %.3f seconds.", tt);
+  log(PROGRESS, "ODE solution computed in %.3f seconds.", tt);
 
   end();
 }
