@@ -1,5 +1,19 @@
 // Copyright (C) 2009 Benjamin Kehlet
-// Licensed under the GNU LGPL Version 2.1.
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2009-07-20
 // Last changed: 2009-09-04
@@ -9,6 +23,7 @@
 
 #include <dolfin/common/types.h>
 #include <dolfin/common/real.h>
+#include <dolfin/common/Array.h>
 
 namespace dolfin
 {
@@ -39,7 +54,7 @@ namespace dolfin
 
   private:
 
-    void get_JT(real* JT, const real* u, real& t);
+    void get_JT(real* JT, const Array<real>& u, real& t);
 
     ODE& ode;
     ODESolution& u;
