@@ -1,10 +1,24 @@
-// Copyright (C) 2003-2008 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2003-2008 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Benjamin Kehlet 2009
 //
 // First added:  2005-05-02
-// Last changed: 2009-03-23
+// Last changed: 2011-03-17
 
 #include <dolfin/common/constants.h>
 #include <dolfin/log/log.h>
@@ -12,8 +26,8 @@
 #include <dolfin/quadrature/LobattoQuadrature.h>
 #include <dolfin/la/uBLASVector.h>
 #include <dolfin/la/uBLASDenseMatrix.h>
+#include <dolfin/la/HighPrecision.h>
 #include <dolfin/ode/ODE.h>
-#include <dolfin/ode/SORSolver.h>
 #include "cGqMethod.h"
 
 using namespace dolfin;
@@ -21,7 +35,7 @@ using namespace dolfin;
 //-----------------------------------------------------------------------------
 cGqMethod::cGqMethod(uint q) : Method(q, q + 1, q)
 {
-  info(TRACE, "Initializing continuous Galerkin method cG(%d).", q);
+  log(TRACE, "Initializing continuous Galerkin method cG(%d).", q);
 
   init();
 
@@ -32,7 +46,7 @@ cGqMethod::cGqMethod(uint q) : Method(q, q + 1, q)
 //-----------------------------------------------------------------------------
 real cGqMethod::ueval(real x0, real values[], real tau) const
 {
-  real sum = x0 * trial->eval(0, tau);
+  real sum = x0*trial->eval(0, tau);
   for (uint i = 0; i < nn; i++)
     sum += values[i] * trial->eval(i + 1, tau);
 
@@ -41,11 +55,11 @@ real cGqMethod::ueval(real x0, real values[], real tau) const
 //-----------------------------------------------------------------------------
 real cGqMethod::residual(real x0, real values[], real f, real k) const
 {
-  real sum = x0 * derivatives[0];
+  real sum = x0*derivatives[0];
   for (uint i = 0; i < nn; i++)
-    sum += values[i] * derivatives[i + 1];
+    sum += values[i]*derivatives[i + 1];
 
-  return sum / k - f;
+  return sum/k - f;
 }
 //-----------------------------------------------------------------------------
 real cGqMethod::timestep(real r, real tol, real k0, real kmax) const
@@ -56,20 +70,19 @@ real cGqMethod::timestep(real r, real tol, real k0, real kmax) const
     return kmax;
 
   const real qq = static_cast<real>(q);
-  return real_pow(tol * real_pow(k0, q) / real_abs(r), 0.5 / qq);
+  return real_pow(tol*real_pow(k0, q)/real_abs(r), 0.5/qq);
 }
 //-----------------------------------------------------------------------------
 real cGqMethod::error(real k, real r) const
 {
   // FIXME: Missing interpolation constant
-  return real_pow(k, static_cast<real>(q)) * real_abs(r);
+  return real_pow(k, static_cast<real>(q))*real_abs(r);
 }
 //-----------------------------------------------------------------------------
-
-void cGqMethod::get_nodal_values(const real& u0, const real* x, real* nodal_values) const
+void cGqMethod::get_nodal_values(const real& u0, const real* x,
+                                 real* nodal_values) const
 {
   nodal_values[0] = u0;
-
   for (uint i = 0; i < nn; i++)
     nodal_values[i+1] = x[i];
 }
@@ -169,15 +182,16 @@ void cGqMethod::compute_weights()
   uBLASDenseMatrix A(q, q);
   ublas_dense_matrix& _A = A.mat();
 
-  real A_real[q*q];
-  //real_zero(q*q, A_real);
+  std::vector<real> A_real(q*q);
 
-  real trial_ddx[nn * nq];
-  real test_eval[nn * nq];
+  std::vector<real> trial_ddx(nn*nq);
+  std::vector<real> test_eval(nn*nq);
 
-  for (uint a = 0; a < nn; ++a) {
-    for (uint b = 0; b < nq; ++b) {
-      trial_ddx[a + nn*b] = trial->ddx(a+1, qpoints[b]);
+  for (uint a = 0; a < nn; ++a)
+  {
+    for (uint b = 0; b < nq; ++b)
+    {
+      trial_ddx[a + nn*b] = trial->ddx(a + 1, qpoints[b]);
       test_eval[a + nn*b] = test->eval(a, qpoints[b]);
     }
   }
@@ -193,12 +207,11 @@ void cGqMethod::compute_weights()
       {
         //real x = qpoints[k];
         //integral += qweights[k] * trial->ddx(j + 1, x) * test->eval(i, x);
-	integral += qweights[k] * trial_ddx[j + nn*k] * test_eval[i + nn*k];
+        integral += qweights[k] * trial_ddx[j + nn*k] * test_eval[i + nn*k];
       }
 
       A_real[i + nn*j] = integral;
       _A(i, j) = to_double(integral);
-
     }
   }
 
@@ -206,14 +219,14 @@ void cGqMethod::compute_weights()
 
   uBLASVector b(q);
   ublas_vector& _b = b.vec();
-  real b_real[q];
+  std::vector<real> b_real(q);
 
   // Compute nodal weights for each degree of freedom (loop over points)
   for (uint i = 0; i < nq; i++)
   {
     // Get nodal point
     //real x = qpoints[i];
-    
+
     // Evaluate test functions at current nodal point
     for (uint j = 0; j < nn; j++)
     {
@@ -224,7 +237,6 @@ void cGqMethod::compute_weights()
     //b.disp();
 
 #ifndef HAS_GMP
-
     uBLASVector w(q);
     ublas_vector& _w = w.vec();
 
@@ -234,23 +246,18 @@ void cGqMethod::compute_weights()
     // Save weights including quadrature
     for (uint j = 0; j < nn; j++)
       nweights[j][i] = qweights[i] * _w[j];
-
 #else
+    std::vector<real> w_real(q);
 
-    real w_real[q];
-    
     uBLASDenseMatrix A_inv(A);
     A_inv.invert();
-    
+
     // Solve system using the double precision invert as preconditioner
-    SORSolver::SOR_precond(q, A_real, w_real, b_real, A_inv, real_epsilon());
+    HighPrecision::real_solve_precond(q, &A_real[0], &w_real[0], &b_real[0], A_inv, real_epsilon());
 
     for (uint j = 0; j < nn; ++j)
       nweights[j][i] = qweights[i] * w_real[j];
 #endif
-
   }
 }
 //-----------------------------------------------------------------------------
-
-
