@@ -1,8 +1,22 @@
-// Copyright (C) 2003-2008 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2003-2008 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // First added:  2005-05-02
-// Last changed: 2009-08-11
+// Last changed: 2011-03-17
 
 #include <dolfin/common/constants.h>
 #include <dolfin/log/dolfin_log.h>
@@ -11,8 +25,8 @@
 #include <dolfin/quadrature/RadauQuadrature.h>
 #include <dolfin/la/uBLASVector.h>
 #include <dolfin/la/uBLASDenseMatrix.h>
+#include <dolfin/la/HighPrecision.h>
 #include <dolfin/ode/ODE.h>
-#include <dolfin/ode/SORSolver.h>
 #include "dGqMethod.h"
 
 using namespace dolfin;
@@ -20,7 +34,7 @@ using namespace dolfin;
 //-----------------------------------------------------------------------------
 dGqMethod::dGqMethod(unsigned int q) : Method(q, q + 1, q + 1)
 {
-  info(TRACE, "Initializing discontinuous Galerkin method dG(%d).", q);
+  log(TRACE, "Initializing discontinuous Galerkin method dG(%d).", q);
 
   init();
 
@@ -61,16 +75,17 @@ real dGqMethod::timestep(real r, real tol, real k0, real kmax) const
   //return pow(tol / fabs(r), 1.0 / static_cast<real>(q+1));
 
   const real qq = static_cast<real>(q);
-  return real_pow(tol * real_pow(k0, q) / real_abs(r), 1.0 / (2.0*qq + 1.0));
+  return real_pow(tol*real_pow(k0, q)/real_abs(r), 1.0/(2.0*qq + 1.0));
 }
 //-----------------------------------------------------------------------------
 real dGqMethod::error(real k, real r) const
 {
   // FIXME: Missing jump term and interpolation constant
-  return real_pow(k, static_cast<real>(q + 1)) * real_abs(r);
+  return real_pow(k, static_cast<real>(q + 1))*real_abs(r);
 }
 //-----------------------------------------------------------------------------
-void dGqMethod::get_nodal_values(const real& x0, const real* x, real* nodal_values) const
+void dGqMethod::get_nodal_values(const real& x0, const real* x,
+                                 real* nodal_values) const
 {
   real_set(nn, nodal_values, x);
 }
@@ -118,9 +133,7 @@ std::string dGqMethod::str(bool verbose) const
     }
   }
   else
-  {
     s << "<dGqMethod for q = " << q << ">";
-  }
 
   return s.str();
 }
@@ -133,13 +146,13 @@ void dGqMethod::compute_quadrature()
   // Get points, rescale from [-1,1] to [0,1], and reverse the points
   for (unsigned int i = 0; i < nq; i++)
   {
-    qpoints[i] = 1.0 - (quadrature.point(nq - 1 - i) + 1.0) / 2.0;
+    qpoints[i] = 1.0 - (quadrature.point(nq - 1 - i) + 1.0)/2.0;
     npoints[i] = qpoints[i];
   }
 
   // Get points, rescale from [-1,1] to [0,1], and reverse the points
   for (unsigned int i = 0; i < nq; i++)
-    qweights[i] = 0.5 * quadrature.weight(nq - 1 - i);
+    qweights[i] = 0.5*quadrature.weight(nq - 1 - i);
 }
 //-----------------------------------------------------------------------------
 void dGqMethod::compute_basis()
@@ -163,20 +176,22 @@ void dGqMethod::compute_weights()
   uBLASDenseMatrix A(nn, nn);
   ublas_dense_matrix& _A = A.mat();
 
-  real A_real[nn*nn];
-  real_zero(nn*nn, A_real);
+  std::vector<real> A_real(nn*nn);
+  real_zero(nn*nn, &A_real[0]);
 
-  real trial_ddx[nn * nq];
-  real test_eval[nn * nq];
+  std::vector<real> trial_ddx(nn*nq);
+  std::vector<real> test_eval(nn*nq);
 
-  real trial_eval_0[nn];
-  real test_eval_0[nn];
+  std::vector<real> trial_eval_0(nn);
+  std::vector<real> test_eval_0(nn);
 
-  for (uint a = 0; a < nn; ++a) {
+  for (uint a = 0; a < nn; ++a)
+  {
     trial_eval_0[a] = trial->eval(a, 0.0);
     test_eval_0[a]  = test->eval(a, 0.0);
 
-    for (uint b = 0; b < nq; ++b) {
+    for (uint b = 0; b < nq; ++b)
+    {
       trial_ddx[a + nq*b] = trial->ddx(a, qpoints[b]);
       test_eval[a + nq*b] = test->eval(a, qpoints[b]);
     }
@@ -194,9 +209,8 @@ void dGqMethod::compute_weights()
         //real x = qpoints[k];
         //integral += qweights[k] * trial->ddx(j, x) * test->eval(i, x);
         integral += qweights[k] * trial_ddx[j + nq*k] * test_eval[i + nq*k];
+      }
 
-      }     
-      
       A_real[i + nn*j] = integral + trial_eval_0[j] * test_eval_0[i];
       _A(i, j) = to_double(A_real[i + nn*j]);
     }
@@ -205,14 +219,14 @@ void dGqMethod::compute_weights()
   uBLASVector b(nn);
   ublas_vector& _b = b.vec();
 
-  real b_real[nn];
+  std::vector<real> b_real(nn);
 
   // Compute nodal weights for each degree of freedom (loop over points)
   for (unsigned int i = 0; i < nq; i++)
   {
     // Get nodal point
     //real x = qpoints[i];
-    
+
     // Evaluate test functions at current nodal point
     for (unsigned int j = 0; j < nn; j++)
     {
@@ -220,7 +234,7 @@ void dGqMethod::compute_weights()
       _b[j] = to_double(b_real[j]);
     }
 
-#ifndef HAS_GMP
+    #ifndef HAS_GMP
     uBLASVector w(nn);
     ublas_vector& _w = w.vec();
 
@@ -230,22 +244,19 @@ void dGqMethod::compute_weights()
     // Save weights including quadrature
     for (uint j = 0; j < nn; j++)
       nweights[j][i] = qweights[i] * _w[j];
+    #else
+    std::vector<real> w_real(nn);
 
-#else 
-    
-    real w_real[nn];
-    
     // Solve system using the double precision invert as preconditioner
     uBLASDenseMatrix A_inv(A);
     A_inv.invert();
-    
-    SORSolver::SOR_precond(nn, A_real, w_real, b_real, A_inv, real_epsilon());
-    
+
+    HighPrecision::real_solve_precond(nn, &A_real[0], &w_real[0], &b_real[0],
+                                      A_inv, real_epsilon());
+
     for (uint j = 0; j < nn; ++j)
       nweights[j][i] = qweights[i] * w_real[j];
-
-#endif
-
+    #endif
   }
 }
 //-----------------------------------------------------------------------------
