@@ -1,11 +1,25 @@
-// Copyright (C) 2009 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2009 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Johan Hake, 2009
 // Modified by Garth N. Wells, 2009
 //
 // First added:  2009-05-08
-// Last changed: 2011-01-24
+// Last changed: 2011-03-29
 
 #include <sstream>
 #include <stdio.h>
@@ -130,7 +144,7 @@ void Parameters::add(std::string key, double value)
 }
 //-----------------------------------------------------------------------------
 void Parameters::add(std::string key, double value,
-                        double min_value, double max_value)
+                     double min_value, double max_value)
 {
   // Add parameter
   add(key, to_real(value));
@@ -214,7 +228,7 @@ void Parameters::add(const Parameters& parameters)
 //-----------------------------------------------------------------------------
 void Parameters::parse(int argc, char* argv[])
 {
-  info(TRACE, "Parsing command-line arguments.");
+  log(TRACE, "Parsing command-line arguments.");
   parse_dolfin(argc, argv);
 }
 //-----------------------------------------------------------------------------
@@ -398,9 +412,9 @@ std::string Parameters::str(bool verbose) const
   }
   else
   {
-    s << "<Parameter set containing "
-      << _parameters.size() << " parameters and "
-      << _parameter_sets.size() << " nested parameter sets>";
+    s << "<Parameter set \"" << name() << "\" containing "
+      << _parameters.size() << " parameter(s) and "
+      << _parameter_sets.size() << " nested parameter set(s)>";
   }
 
   return s.str();
