@@ -1,5 +1,19 @@
-// Copyright (C) 2003-2006 Anders Logg.
-// Licensed under the GNU LGPL Version 2.1.
+// Copyright (C) 2003-2006 Anders Logg
+//
+// This file is part of DOLFIN.
+//
+// DOLFIN is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// DOLFIN is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public License
+// along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
 //
 // Modified by Garth N. Wells
 //
@@ -12,44 +26,30 @@
 using namespace dolfin;
 
 //-----------------------------------------------------------------------------
-Quadrature::Quadrature(unsigned int n)
+Quadrature::Quadrature(unsigned int n, real m) : points(n), weights(n, 0), m(m)
 {
-  this->n = n;
-
-  points = new real[n];
-  weights = new real[n];
-
-  for (unsigned int i = 0; i < n; i++)
-    weights[i] = 0;
-
-  m = 1.0;
+  // Do nothing
 }
 //-----------------------------------------------------------------------------
 Quadrature::~Quadrature()
 {
-  if ( points )
-    delete [] points;
-  points = 0;
-
-  if ( weights )
-    delete [] weights;
-  weights = 0;
+  // Do nothing
 }
 //-----------------------------------------------------------------------------
 int Quadrature::size() const
 {
-  return n;
+  return points.size();
 }
 //-----------------------------------------------------------------------------
 real Quadrature::point(unsigned int i) const
 {
-  assert(i < n);
+  assert(i < points.size());
   return points[i];
 }
 //-----------------------------------------------------------------------------
 real Quadrature::weight(unsigned int i) const
 {
-  assert(i < n);
+  assert(i < points.size());
   return weights[i];
 }
 //-----------------------------------------------------------------------------
