@@ -2,16 +2,28 @@
 #
 # Generate list of include files for SWIG interface file.
 #
-
-__author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2007-04-12 -- 2010-09-03"
-__copyright__ = "Copyright (C) 2007 Anders Logg"
-__license__  = "GNU LGPL Version 2.1"
-
+# Copyright (C) 2007 Anders Logg
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by <aasmund@simula.no>
 # Modified by Johan Hake, 2009
 # Modified by Kristian B. Oelgaard, 2010
-
+#
+# First added:  2007-04-12
 # Last changed: 2010-09-03
 
 import os
