@@ -6,6 +6,9 @@ import dolfin.importhandler
 # Import UFL form language
 from ufl import *
 
+# Remove some unnecessary imports from UFL
+del set_handler, set_level
+
 # Import names from the compiled cpp module
 from dolfin.cppimports import *
 from dolfin.cppimports import __version__, __swigversion__
@@ -21,8 +24,10 @@ except:
     supported_elements_for_plotting = []
 
 # Imports from pure Python modules
-from dolfin.function import *
+from dolfin.functions import *
 from dolfin.common import *
 from dolfin.compilemodules import *
 from dolfin.fem import *
 from dolfin.mesh import *
+
+
