@@ -1,9 +1,23 @@
-__author__ = "Hans Petter Langtangen <hpl@simula.no>"
-__date__ = "2009-12-14"
-__copyright__ = "Copyright (C) 2009 " + __author__
-__license__  = "GNU LGPL Version 2.1"
-
+# Copyright (C) 2009 Hans Petter Langtangen
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Anders Logg, 2009.
+#
+# First added:  2009-12-14
 # Last changed: 2010-02-14
 
 class DoNothing(object):
