@@ -1,5 +1,5 @@
 """The compilemodules module of dolfin"""
-from dolfin.compilemodules.compilemodules import compile_extension_module
+from dolfin.compilemodules.compilemodule import compile_extension_module
 from dolfin.compilemodules.expressions import compile_expressions
 from dolfin.compilemodules.subdomains import compile_subdomains
 from dolfin.compilemodules.jit import jit
