@@ -1,11 +1,26 @@
 "This module provides functionality for compilation of strings as dolfin Expressions."
 
-__author__ = "Martin Sandve Alnes (martinal@simula.no)"
-__date__ = "2008-06-04 -- 2011-01-22"
-__copyright__ = "Copyright (C) 2008-2008 Martin Sandve Alnes"
-__license__  = "GNU LGPL Version 2.1"
-
+# Copyright (C) 2008-2008 Martin Sandve Alnes
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Johan Hake 2008-2009
+#
+# First added:  2008-06-04
+# Last changed: 2011-04-18
 
 import re
 import types
@@ -13,7 +28,7 @@ import hashlib
 import instant
 
 # Import local compile_extension_module
-from dolfin.compilemodules.compilemodules import (compile_extension_module,
+from dolfin.compilemodules.compilemodule import (compile_extension_module,
                                                    expression_to_code_fragments,
                                                    math_header)
 
