@@ -1,12 +1,27 @@
 """This module defines a jit function that wraps the jit function for
 the chosen form compiler."""
 
-__author__ = "Johan Hake (hake@simula.no)"
-__date__ = "2008-12-04 -- 2010-09-11"
-__copyright__ = "Copyright (C) 2008-2009 Johan Hake"
-__license__  = "GNU LGPL Version 2.1"
-
+# Copyright (C) 2008-2009 Johan Hake
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Anders Logg, 2008-2009.
+#
+# First added:  2008-12-04
+# Last changed: 2011-03-15
 
 __all__ = ["jit"]
 
@@ -19,7 +34,7 @@ import ufl
 ufl.set_level(ufl.INFO)
 
 # Import check for correct swig version from instant
-from instant import check_swig_version, get_swig_version
+from instant import check_swig_version, get_swig_version, check_and_set_swig_binary
 
 # Cached swig check
 _swig_version_ok = False
@@ -69,14 +84,20 @@ def jit(form, form_compiler_parameters=None, common_cell=None):
     It uses the jit function from the form compiler registered by
     parameters["form_compiler"]["name"].
     """
-
+    
     global _swig_version_ok
 
+    # Check and set swig binary
+    if not _swig_version_ok and not check_and_set_swig_binary(\
+        parameters["swig_binary"], parameters["swig_path"]):
+        raise OSError, "Could not find swig installation. Pass an existing "\
+              "swig binary or install SWIG version 2.0 or higher.\n"
+    
     # Check that the form compiler will use the same swig version
     # that PyDOLFIN was compiled with
     _swig_version_ok = _swig_version_ok or \
                        check_swig_version(cpp.__swigversion__, same=True)
-
+    
     if not _swig_version_ok:
         raise OSError, """\
 PyDOLFIN was not compiled with the present version of swig.
@@ -105,6 +126,10 @@ Install swig version %s or recompiled PyDOLFIN with present swig
     if form_compiler_parameters:
         p.update(form_compiler_parameters)
 
+    # Set the swig binary and path
+    p["swig_binary"] = parameters["swig_binary"]
+    p["swig_path"] = parameters["swig_path"]
+    
     # Get jit function
     try:
         jit_compile = form_compiler.jit
