@@ -1,16 +1,31 @@
 "This module provides a collection of small but useful utility functions."
 
-__author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2008-10-22 -- 2009-12-11"
-__copyright__ = "Copyright (C) 2009 Anders Logg"
-__license__  = "GNU LGPL Version 2.1"
+# Copyright (C) 2009 Anders Logg
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2008-10-22
+# Last changed: 2009-12-11
 
 __all__ = ["AutoSubDomain", "DirichletBC", "PeriodicBC", "homogenize"]
 
 import types
 
 import dolfin.cpp as cpp
-from dolfin.function.constant import Constant
+from dolfin.functions.constant import Constant
 from dolfin.compilemodules.subdomains import compile_subdomains
 
 class AutoSubDomain(cpp.SubDomain):
@@ -59,7 +74,11 @@ class DirichletBC(cpp.DirichletBC):
             sub_domain = compile_subdomains(args[2])
             args = args[:2] + (sub_domain,) + args[3:]
 
-        # Store domain arguments
+        # Store Expression to avoid scoping issue with SWIG directors
+        if isinstance(args[1], cpp.Expression):
+            self.function_arg = args[1]
+
+        # Store SubDomain to avoid scoping issue with SWIG directors
         self.domain_args = args[2:]
 
         # Initialize base class
