@@ -1,12 +1,27 @@
 """This module defines a Form class that wraps FFC forms and UFC forms
 into a cpp.Form (dolfin::Form)."""
 
-__author__ = "Johan Hake (hake@simula.no)"
-__date__ = "2008-12-04 -- 2009-12-11"
-__copyright__ = "Copyright (C) 2008 Johan Hake"
-__license__  = "GNU LGPL Version 2.1"
-
-# Modified by Anders Logg, 2008
+# Copyright (C) 2008 Johan Hake
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Modified by Anders Logg, 2008-2011
+#
+# First added:  2008-12-04
+# Last changed: 2009-12-11
 
 __all__ = ["Form"]
 
@@ -31,7 +46,10 @@ class Form(cpp.Form):
 
         # Compile form if necessary
         if not hasattr(form, "create_cell_integral"):
-            (self._compiled_form, module, self.form_data) = jit(form, form_compiler_parameters, common_cell)
+            (self._compiled_form, module, self.form_data, prefix) = \
+                jit(form,
+                    form_compiler_parameters,
+                    common_cell)
         else:
             self._compiled_form = form
             self.form_data = None
@@ -48,6 +66,14 @@ class Form(cpp.Form):
         # Initialize base class
         cpp.Form.__init__(self, self._compiled_form, self.function_spaces, self.coefficients)
 
+        # Attach subdomains
+        if form.cell_domains is not None:
+            self.set_cell_domains(form.cell_domains)
+        if form.exterior_facet_domains is not None:
+            self.set_exterior_facet_domains(form.exterior_facet_domains)
+        if form.interior_facet_domains is not None:
+            self.set_interior_facet_domains(form.interior_facet_domains)
+
 def _extract_function_spaces(form_data, compiled_form, given_function_spaces):
     "Extract list of test spaces."
 
