@@ -1,10 +1,25 @@
 """This module provides a simple way to compute the projection of
 a Function (discrete or user-defined) onto a finite element space."""
 
-__author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2008-07-13 -- 2009-12-11"
-__copyright__ = "Copyright (C) 2008-2009 Anders Logg"
-__license__  = "GNU LGPL Version 2.1"
+# Copyright (C) 2008-2009 Anders Logg
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2008-07-13
+# Last changed: 2009-12-11
 
 __all__ = ['project']
 
@@ -13,9 +28,9 @@ import ufl
 import dolfin.cpp as cpp
 
 # Local imports
-from dolfin.function.function import *
-from dolfin.function.expression import *
-from dolfin.function.functionspace import *
+from dolfin.functions.function import *
+from dolfin.functions.expression import *
+from dolfin.functions.functionspace import *
 from dolfin.fem.assemble import *
 
 def project(v, V=None, mesh=None, solver_type="cg", preconditioner_type="default"):
