@@ -2,13 +2,28 @@
 needs special handling and we cannot use the SWIG wrapper directly
 since we need to call the JIT compiler."""
 
-__author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2007-08-15 -- 2011-01-22"
-__copyright__ = "Copyright (C) 2007-2008 Anders Logg"
-__license__  = "GNU LGPL Version 2.1"
-
+# Copyright (C) 2007-2008 Anders Logg
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Johan Hake, 2009
 # Modified by Marie E. Rognes, 2011
+#
+# First added:  2007-08-15
+# Last changed: 2011-01-22
 
 __all__ = ["VariationalProblem"]
 
@@ -23,8 +38,8 @@ import dolfin.cpp as cpp
 # Local imports
 from dolfin.fem.form import *
 from dolfin.fem.assemble import assemble
-from dolfin.function.function import *
-from dolfin.function.functionspace import *
+from dolfin.functions.function import *
+from dolfin.functions.functionspace import *
 
 class VariationalProblem(cpp.VariationalProblem):
 
@@ -34,9 +49,6 @@ class VariationalProblem(cpp.VariationalProblem):
     def __init__(self, a,
                  L=None,
                  bcs=None,
-                 cell_domains=None,
-                 exterior_facet_domains=None,
-                 interior_facet_domains=None,
                  form_compiler_parameters={}):
         "Define a variational problem."
 
@@ -65,10 +77,7 @@ class VariationalProblem(cpp.VariationalProblem):
             self.bcs = bcs
 
         # Initialize base class
-        cpp.VariationalProblem.__init__(self, self.a, self.L, self.bcs,
-                                        cell_domains, exterior_facet_domains,
-                                        interior_facet_domains)
-
+        cpp.VariationalProblem.__init__(self, self.a, self.L, self.bcs)
 
     def solve(self, u=None, tolerance=None, goal=None):
         "Solve variational problem and return solution."
@@ -135,10 +144,14 @@ class VariationalProblem(cpp.VariationalProblem):
         module = __import__("dolfin.fem.formmanipulations")
 
         (a_star, L_star) = generate_dual_forms(forms, u, module)
+        module.assign_domains(fro=bilinear, to=a_star) # FIXME: Check cpp
+        module.assign_domains(fro=goal, to=L_star)
+
         if self.is_linear:
             weak_residual = generate_weak_residual((bilinear, linear), u)
         else:
             weak_residual = generate_weak_residual(linear)
+        module.assign_domains(fro=linear, to=weak_residual) # NB
 
         V = u.function_space()
         mesh = V.mesh()
@@ -147,8 +160,9 @@ class VariationalProblem(cpp.VariationalProblem):
         E = module.increase_order(V)
         Ez_h = Function(E)
 
-        # Generate error estimate (residual) (# FIXME: Add option here)
+        # Generate error estimate (residual)
         eta_h = dolfin.action(weak_residual, Ez_h)
+        module.assign_domains(fro=weak_residual, to=eta_h)
 
         # Define approximation space for cell and facet residuals
         V_h = module.tear(V)
@@ -158,6 +172,7 @@ class VariationalProblem(cpp.VariationalProblem):
         b_T = Function(B)
         b_T.vector()[:] = 1.0
         a_R_T, L_R_T = generate_cell_residual(weak_residual, V_h, b_T, module)
+        module.assign_domains(fro=weak_residual, to=L_R_T)
 
         # Generate facet residual stuff
         R_T = Function(V_h)
@@ -165,6 +180,7 @@ class VariationalProblem(cpp.VariationalProblem):
         b_e = Function(C)
         a_R_dT, L_R_dT = generate_facet_residual(weak_residual, V_h, b_e, R_T,
                                                  module)
+        module.assign_domains(fro=weak_residual, to=L_R_dT)
 
         # Generate error indicators (# FIXME: Add option here)
         R_dT = Function(V_h)
