@@ -1,9 +1,24 @@
-__author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2009-09-16 -- 2009-09-16"
-__copyright__ = "Copyright (C) 2009 Anders Logg"
-__license__  = "GNU LGPL Version 2.1"
-
+# Copyright (C) 2009 Anders Logg
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Johannes Ring, 2009.
+#
+# First added:  2009-09-16
+# Last changed: 2009-09-16
 
 from subprocess import Popen, PIPE, STDOUT
 
