@@ -1,10 +1,23 @@
-__author__ = "Marie E. Rognes (meg@simula.no)"
-__copyright__ = "Copyright (C) 2011 Marie Rognes"
-__license__  = "GNU LGPL version 3 or any later version"
-
+# Copyright (C) 2011 Marie E. Rognes
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Based on original implementation by Martin Alnes and Anders Logg
-
-# Last changed: 2011-02-21
+#
+# Last changed: 2011-03-08
 
 from includes import snippets
 from functionspace import *
@@ -127,7 +140,7 @@ def generate_constructor(form, classname, space_tag, coefficient_tag=None):
     # Construct list of arguments and function space assignments
     name = "V%d"
     if form.rank > 0:
-        arguments = [argument % (name % i) for i in range(form.rank)]
+        arguments = [argument % (name % i) for i in reversed(range(form.rank))]
         assignments = [assign % (i, name % i) for i in range(form.rank)]
     else:
         arguments = [argument]
