@@ -1,9 +1,22 @@
-__author__ = "Marie E. Rognes (meg@simula.no)"
-__copyright__ = "Copyright (C) 2011 Marie Rognes"
-__license__  = "GNU LGPL version 3 or any later version"
-
+# Copyright (C) 2011 Marie E. Rognes
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Based on original implementation by Martin Alnes and Anders Logg
-
+#
 # Last changed: 2011-02-21
 
 from includes import snippets
