@@ -1,10 +1,23 @@
-__author__ = "Marie E. Rognes (meg@simula.no)"
-__copyright__ = "Copyright (C) 2011 Marie Rognes"
-__license__  = "GNU LGPL version 3 or any later version"
-
+# Copyright (C) 2011 Marie E. Rognes
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Based on original implementation by Martin Alnes and Anders Logg
-
-# Last changed: 2011-02-21
+#
+# Last changed: 2011-03-22
 
 import includes as incl
 from functionspace import *
@@ -19,7 +32,8 @@ parameters = {"use_common_coefficient_names": True}
 
 #-------------------------------------------------------------------------------
 def generate_dolfin_code(prefix, header, forms,
-                         common_function_space=False, add_guards=False):
+                         common_function_space=False, add_guards=False,
+                         error_control=False):
     """Generate complete dolfin wrapper code with given generated names.
 
     @param prefix:
@@ -32,10 +46,13 @@ def generate_dolfin_code(prefix, header, forms,
         True if common function space, otherwise False
     @param add_guards:
         True iff guards (ifdefs) should be added
+    @param error_control:
+        True iff adaptivity typedefs (ifdefs) should be added
     """
 
     # Generate dolfin namespace
-    namespace = generate_dolfin_namespace(prefix, forms, common_function_space)
+    namespace = generate_dolfin_namespace(prefix, forms, common_function_space,
+                                          error_control)
 
     # Collect pieces of code
     code = [incl.dolfin_tag, header, incl.stl_includes, incl.dolfin_includes,
@@ -52,7 +69,8 @@ def generate_dolfin_code(prefix, header, forms,
     return "\n".join(code)
 
 #-------------------------------------------------------------------------------
-def generate_dolfin_namespace(prefix, forms, common_function_space=False):
+def generate_dolfin_namespace(prefix, forms, common_function_space=False,
+                              error_control=False):
 
     # Allow forms to represent a single space, and treat separately
     if isinstance(forms, UFCElementNames):
@@ -69,7 +87,8 @@ def generate_dolfin_namespace(prefix, forms, common_function_space=False):
     code += [generate_form(form, "Form_%d"%i) for (i, form) in enumerate(forms)]
 
     # Generate namespace typedefs (Bilinear/Linear & Test/Trial/Function)
-    code += [generate_namespace_typedefs(forms, common_function_space)]
+    code += [generate_namespace_typedefs(forms, common_function_space,
+                                         error_control)]
 
     # Wrap code in namespace block
     code = "\nnamespace %s\n{\n\n%s\n}" % (prefix, "\n".join(code))
@@ -86,7 +105,7 @@ def generate_single_function_space(prefix, space):
     return code
 
 #-------------------------------------------------------------------------------
-def generate_namespace_typedefs(forms, common_function_space):
+def generate_namespace_typedefs(forms, common_function_space, error_control):
 
     # Generate typedefs as (fro, to) pairs of strings
     pairs = []
@@ -103,6 +122,10 @@ def generate_namespace_typedefs(forms, common_function_space):
     if common_function_space and any(form.rank for form in forms):
         pairs += [("Form_0::TestSpace", "FunctionSpace")]
 
+    # Add specialized typedefs when adding error control wrapppers
+    if error_control:
+        pairs += error_control_pairs()
+
     # Combine data to typedef code
     typedefs = "\n".join("typedef %s %s;" % (to, fro) for (to, fro) in pairs)
 
@@ -112,3 +135,7 @@ def generate_namespace_typedefs(forms, common_function_space):
     return "// Class typedefs\n" + typedefs + "\n"
 
 #-------------------------------------------------------------------------------
+def error_control_pairs():
+    return [("Form_8", "BilinearForm"), ("Form_9", "LinearForm"),
+            ("Form_10", "GoalFunctional")]
+
