@@ -1,14 +1,29 @@
 """Run Valgrind on all demos."""
 
-__author__ = "Ilmar Wilbers (ilmarw@simula.no)"
-__date__ = "2008-04-08 -- 2009-05-19"
-__copyright__ = "Copyright (C) 2008 Ilmar Wilbers"
-__license__  = "GNU LGPL Version 2.1"
-
+# Copyright (C) 2008 Ilmar Wilbers
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Anders Logg 2008
 # Modified by Dag Lindbo 2008
 # Modified by Johannes Ring 2008
 # Modified by Johan Hake 2009
+#
+# First added:  2008-04-08
+# Last changed: 2009-05-19
 
 import sys, os, re
 import platform
