@@ -1,13 +1,28 @@
 """Run all demos."""
 
-__author__ = "Ilmar Wilbers (ilmarw@simula.no)"
-__date__ = "2008-04-08 -- 2009-10-11"
-__copyright__ = "Copyright (C) 2008 Ilmar Wilbers"
-__license__  = "GNU LGPL Version 2.1"
-
+# Copyright (C) 2008 Ilmar Wilbers
+#
+# This file is part of DOLFIN.
+#
+# DOLFIN is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DOLFIN is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with DOLFIN.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Anders Logg, 2008-2009.
-# Modified by Johannes Ring, 2009.
+# Modified by Johannes Ring, 2009, 2011.
 # Modified by Johan Hake, 2009.
+#
+# First added:  2008-04-08
+# Last changed: 2011-03-03
 
 import sys, os, re
 import platform
@@ -26,7 +41,8 @@ for dpath, dnames, fnames in os.walk(demodir):
         if os.path.isfile(os.path.join(dpath, 'Makefile')):
             cppdemos.append(dpath)
     elif os.path.basename(dpath) == 'python':
-        if os.path.isfile(os.path.join(dpath, 'demo.py')):
+        tmp = dpath.split(os.path.sep)[-2]
+        if os.path.isfile(os.path.join(dpath, 'demo_' + tmp + '.py')):
             pydemos.append(dpath)
 
 # Set non-interactive
@@ -39,10 +55,6 @@ print "Found %d Python demos" % len(pydemos)
 print ""
 import pprint
 
-# Remove demos that are known not to work (FIXME's)
-#pydemos.remove(os.path.join(demodir, 'undocumented', 'aliev-panfilov', 'python'))
-#pydemos.remove(os.path.join(demodir, 'undocumented', 'lorenz', 'python'))
-
 # Push slow demos to the end
 pyslow = []
 cppslow = []
@@ -53,9 +65,6 @@ for s in cppslow:
     cppdemos.remove(s)
     cppdemos.append(s)
 
-# Remove overly slow demos
-#cppdemos.remove(os.path.join(demodir, 'undocumented', 'elastodynamics', 'cpp'))
-
 # Remove demos that need command-line arguments
 pydemos.remove(os.path.join(demodir,  'undocumented', 'quadrature', 'python'))
 cppdemos.remove(os.path.join(demodir, 'undocumented', 'quadrature', 'cpp'))
@@ -91,14 +100,13 @@ for prefix in prefixes:
         print "----------------------------------------------------------------------"
         print "Running C++ demo %s%s" % (prefix, demo)
         print ""
-        cppdemo_ext = ''
+        cppdemo_executable = 'demo_' + demo.split(os.path.sep)[-2]
         if platform.system() == 'Windows':
-            cppdemo_ext = '.exe'
-        cppdemo_prefix = demo.split(os.path.sep)[-2]
-        if os.path.isfile(os.path.join(demo, cppdemo_prefix + '-demo' + cppdemo_ext)):
+            cppdemo_executable += '.exe'
+        if os.path.isfile(os.path.join(demo, cppdemo_executable)):
             t1 = time()
-            output = getstatusoutput("cd %s && %s .%s%s-demo%s" % \
-                                         (demo, prefix, os.path.sep, cppdemo_prefix, cppdemo_ext))
+            output = getstatusoutput("cd %s && %s .%s%s" % \
+                                     (demo, prefix, os.path.sep, cppdemo_executable))
             t2 = time()
             timing += [(t2 - t1, demo)]
             if output[0] == 0:
@@ -117,9 +125,10 @@ for prefix in prefixes:
         print "----------------------------------------------------------------------"
         print "Running Python demo %s%s" % (prefix, demo)
         print ""
-        if os.path.isfile(os.path.join(demo, 'demo.py')):
+        demofile = 'demo_' + demo.split(os.path.sep)[-2] + '.py'
+        if os.path.isfile(os.path.join(demo, demofile)):
             t1 = time()
-            output = getstatusoutput("cd %s && %s python demo.py" % (demo, prefix))
+            output = getstatusoutput("cd %s && %s python %s" % (demo, prefix, demofile))
             t2 = time()
             timing += [(t2 - t1, demo)]
             if output[0] == 0:
